@@ -1,7 +1,7 @@
 #! /bin/bash -e
-# $Id: search.sh 3212 2014-03-18 13:05:24Z bradbell $
+# $Id: search.sh 3768 2015-12-28 18:58:35Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
@@ -22,21 +22,12 @@ then
 	exit 1
 fi
 pattern="$1"
-dir_list='
-	bin
-	cppad 
-	cppad_ipopt
-	example 
-	introduction
-	multi_thread
-	omh
-	pkgconfig
-	print_for
-	speed
-	test_more 
-'
-#
-grep -l -r  "$pattern" $dir_list | \
-	 sed -e '/\/makefile.in/d' -e '/test_one.exe/d'  -e '/\/new\//d'
-grep -l "$pattern" makefile.am CMakeLists.txt doc.omh | \
-	 sed -e '/\/makefile.in/d' -e '/test_one.exe/d'  -e '/\/new\//d'
+# -----------------------------------------------------------------------------
+list=`bin/list_files.sh | sed \
+	-e '/^configure$/d' \
+	-e '/^makefile.in$/d' \
+	-e '/\/makefile.in$/d' \
+	-e '/^compile/d'`
+grep -l "$pattern" $list
+# ----------------------------------------------------------------------------
+exit 0
