@@ -1,10 +1,10 @@
 #! /bin/bash -e
-# $Id: svn_ignore.sh 2875 2013-07-29 11:56:01Z bradbell $
+# $Id: svn_ignore.sh 3768 2015-12-28 18:58:35Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
-# the terms of the 
+# the terms of the
 #                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
@@ -18,6 +18,7 @@ fi
 # -----------------------------------------------------------------------------
 cat << EOF > bin/svn_ignore.$$
 aclocal.m4
+ar-lib
 autom4te.cache
 build
 check_all.err
@@ -42,4 +43,6 @@ EOF
 svn propset svn:ignore --recursive -F bin/svn_ignore.$$ .
 rm bin/svn_ignore.$$
 #
-exit 0 
+# ----------------------------------------------------------------------------
+echo "$0: OK"
+exit 0
