@@ -1,12 +1,12 @@
-/* $Id: atan_op.hpp 3320 2014-09-11 23:06:21Z bradbell $ */
-# ifndef CPPAD_ATAN_OP_INCLUDED
-# define CPPAD_ATAN_OP_INCLUDED
+// $Id: atan_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_ATAN_OP_HPP
+# define CPPAD_ATAN_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -43,9 +43,9 @@ inline void forward_atan_op(
 	size_t q           ,
 	size_t i_z         ,
 	size_t i_x         ,
-	size_t cap_order   , 
+	size_t cap_order   ,
 	Base*  taylor      )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(AtanOp) == 1 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(AtanOp) == 2 );
@@ -99,9 +99,9 @@ inline void forward_atan_op_dir(
 	size_t r           ,
 	size_t i_z         ,
 	size_t i_x         ,
-	size_t cap_order   , 
+	size_t cap_order   ,
 	Base*  taylor      )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(AtanOp) == 1 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(AtanOp) == 2 );
@@ -145,7 +145,7 @@ template <class Base>
 inline void forward_atan_op_0(
 	size_t i_z         ,
 	size_t i_x         ,
-	size_t cap_order   , 
+	size_t cap_order   ,
 	Base*  taylor      )
 {
 	// check assumptions
@@ -182,7 +182,7 @@ inline void reverse_atan_op(
 	size_t      d            ,
 	size_t      i_z          ,
 	size_t      i_x          ,
-	size_t      cap_order    , 
+	size_t      cap_order    ,
 	const Base* taylor       ,
 	size_t      nc_partial   ,
 	Base*       partial      )
@@ -205,29 +205,31 @@ inline void reverse_atan_op(
 	const Base* b  = z  - cap_order; // called y in documentation
 	Base* pb       = pz - nc_partial;
 
+	Base inv_b0 = Base(1) / b[0];
+
 	// number of indices to access
 	size_t j = d;
 	size_t k;
 	while(j)
 	{	// scale partials w.r.t z[j] and b[j]
-		pz[j] /= b[0];
+		pz[j]  = azmul(pz[j], inv_b0);
 		pb[j] *= Base(2);
 
-		pb[0] -= pz[j] * z[j]; 
-		px[j] += pz[j] + pb[j] * x[0];
-		px[0] += pb[j] * x[j];
+		pb[0] -= azmul(pz[j], z[j]);
+		px[j] += pz[j] + azmul(pb[j], x[0]);
+		px[0] += azmul(pb[j], x[j]);
 
 		// more scaling of partials w.r.t z[j]
 		pz[j] /= Base(j);
 
 		for(k = 1; k < j; k++)
-		{	pb[j-k] -= pz[j] * Base(k) * z[k];
-			pz[k]   -= pz[j] * Base(k) * b[j-k];
-			px[k]   += pb[j] * x[j-k];
+		{	pb[j-k] -= Base(k) * azmul(pz[j], z[k]);
+			pz[k]   -= Base(k) * azmul(pz[j], b[j-k]);
+			px[k]   += azmul(pb[j], x[j-k]);
 		}
 		--j;
 	}
-	px[0] += pz[0] / b[0] + pb[0] * Base(2) * x[0];
+	px[0] += azmul(pz[0], inv_b0) + Base(2) * azmul(pb[0], x[0]);
 }
 
 } // END_CPPAD_NAMESPACE
