@@ -1,12 +1,12 @@
-/* $Id: atomic_base.hpp 3232 2014-04-27 15:38:21Z bradbell $ */
-# ifndef CPPAD_ATOMIC_BASE_INCLUDED
-# define CPPAD_ATOMIC_BASE_INCLUDED
+// $Id: atomic_base.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_ATOMIC_BASE_HPP
+# define CPPAD_ATOMIC_BASE_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -16,7 +16,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <set>
 # include <cppad/local/cppad_assert.hpp>
 // needed before one can use CPPAD_ASSERT_FIRST_CALL_NOT_PARALLEL
-# include <cppad/thread_alloc.hpp>
+# include <cppad/utility/thread_alloc.hpp>
 
 namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 /*!
@@ -28,7 +28,11 @@ template <class Base>
 class atomic_base {
 // ===================================================================
 public:
-	enum option_enum { bool_sparsity_enum, set_sparsity_enum};
+	enum option_enum {
+		pack_sparsity_enum   ,
+		bool_sparsity_enum   ,
+		set_sparsity_enum
+	};
 private:
 	// ------------------------------------------------------
 	// constants
@@ -43,7 +47,7 @@ private:
 	/// (set by constructor and option member functions)
 	option_enum sparsity_;
 
-	/// temporary work space used afun, declared here to avoid memory 
+	/// temporary work space used afun, declared here to avoid memory
 	/// allocation/deallocation for each call to afun
 	vector<bool>  afun_vx_[CPPAD_MAX_NUM_THREADS];
 	vector<bool>  afun_vy_[CPPAD_MAX_NUM_THREADS];
@@ -80,6 +84,7 @@ public:
 /*
 $begin atomic_ctor$$
 $spell
+	enum
 	sq
 	std
 	afun
@@ -92,14 +97,11 @@ $spell
 $$
 
 $section Atomic Function Constructor$$
-$index constructor, atomic function$$
-$index atomic, function constructor$$
-$index function, atomic constructor$$
 
 $head Syntax$$
 $icode%atomic_user afun%(%ctor_arg_list%)
 %$$
-$codei%atomic_base<%Base%>(%name%)
+$codei%atomic_base<%Base%>(%name%, %sparsity%)
 %$$
 
 $head atomic_user$$
@@ -110,26 +112,26 @@ Is a list of arguments for the $icode atomic_user$$ constructor.
 $subhead afun$$
 The object $icode afun$$ must stay in scope for as long
 as the corresponding atomic function is used.
-This includes use by any $cref/ADFun<Base>/ADFun/$$ that 
-has this $icode atomic_user$$ operation in its 
+This includes use by any $cref/ADFun<Base>/ADFun/$$ that
+has this $icode atomic_user$$ operation in its
 $cref/operation sequence/glossary/Operation/Sequence/$$.
 
 $subhead Implementation$$
-The user defined $icode atomic_user$$ class is a publicly derived class of 
+The user defined $icode atomic_user$$ class is a publicly derived class of
 $codei%atomic_base<%Base%>%$$.
 It should be declared as follows:
 $codei%
 	class %atomic_user% : public CppAD::atomic_base<%Base%> {
 	public:
-		%atomic_user%(%ctor_arg_list%) : atomic_base<%Base%>(%name%)
+		%atomic_user%(%ctor_arg_list%) : atomic_base<%Base%>(%name%, %sparsity%)
 	%...%
 	};
 %$$
-where $icode ...$$  
+where $icode ...$$
 denotes the rest of the implementation of the derived class.
 This includes completing the constructor and
-all the virtual functions that have their 
-$code atomic_base$$ implementations replaced by 
+all the virtual functions that have their
+$code atomic_base$$ implementations replaced by
 $icode atomic_user$$ implementations.
 
 $head atomic_base$$
@@ -143,16 +145,36 @@ The template parameter determines the
 $icode Base$$ type for this $codei%AD<%Base%>%$$ atomic operation.
 
 $subhead name$$
-This $icode atomic_base$$ constructor argument has either of the
-following prototypes
+This $code atomic_base$$ constructor argument has the following prototype
 $codei%
-	const char*        %name%
 	const std::string& %name%
 %$$
 It is the name for this atomic function and is used for error reporting.
 The suggested value for $icode name$$ is $icode afun$$ or $icode atomic_user$$,
 i.e., the name of the corresponding atomic object or class.
 
+$subhead sparsity$$
+This $code atomic_base$$ constructor argument has prototype
+$codei%
+	atomic_base<%Base%>::option_enum %sparsity%
+%$$
+The current $icode sparsity$$ for an $code atomic_base$$ object
+determines which type of sparsity patterns it uses
+and its value is one of the following:
+$table
+$icode sparsity$$   $cnext sparsity patterns $rnext
+$codei%atomic_base<%Base%>::pack_sparsity_enum%$$ $pre  $$ $cnext
+	$cref/vectorBool/CppAD_vector/vectorBool/$$
+$rnext
+$codei%atomic_base<%Base%>::bool_sparsity_enum%$$ $pre  $$ $cnext
+	$cref/vector/CppAD_vector/$$$code <bool>$$
+$rnext
+$codei%atomic_base<%Base%>::set_sparsity_enum%$$ $pre  $$ $cnext
+	$cref/vector/CppAD_vector/$$$code <std::set<std::size_t> >$$
+$tend
+There is a default value for $icode sparsity$$ if it is not
+included in the constructor (which may be either the bool or set option).
+
 $head Examples$$
 
 $subhead Define Constructor$$
@@ -191,10 +213,18 @@ Constructor
 
 \param name
 name used for error reporting
+
+\param sparsity [in]
+what type of sparsity patterns are computed by this function,
+bool_sparsity_enum or set_sparsity_enum. Default value is
+bool sparsity patterns.
 */
-atomic_base( const std::string&  name) :
+atomic_base(
+		const std::string&     name,
+		option_enum            sparsity = bool_sparsity_enum
+) :
 index_( class_object().size() )     ,
-sparsity_( set_sparsity_enum )
+sparsity_( sparsity )
 {	CPPAD_ASSERT_KNOWN(
 		! thread_alloc::in_parallel() ,
 		"atomic_base: constructor cannot be called in parallel mode."
@@ -233,57 +263,61 @@ $spell
 $$
 
 $section Set Atomic Function Options$$
-$index atomic, options$$
-$index options, atomic$$
 
 $head Syntax$$
 $icode%afun%.option(%option_value%)%$$
+These settings do not apply to individual $icode afun$$ calls,
+but rather all subsequent uses of the corresponding atomic operation
+in an $cref ADFun$$ object.
 
 $head atomic_sparsity$$
-$index atomic_sparsity$$
-$index sparsity, atomic$$
-You can used this option to set to type used for 
-$icode afun$$ sparsity patterns.
-This does not apply individual calls to $icode afun$$,
-but rather all its uses between when the sparsity pattern is set and when
-it is changed.
-If neither the $code set_sparsity_enum$$ or 
-$code bool_sparsity_enum$$ option is set,
-the type for $icode atomic_sparsity$$ is one of the two choices below
-(and otherwise unspecified).
+Note that, if you use $cref optimize$$, these sparsity patterns are used
+to determine the $cref/dependency/dependency.cpp/$$ relationship between
+argument and result variables.
+
+$subhead pack_sparsity_enum$$
+If $icode option_value$$ is $codei%atomic_base<%Base%>::pack_sparsity_enum%$$,
+then the type used by $icode afun$$ for
+$cref/sparsity patterns/glossary/Sparsity Pattern/$$,
+(after the option is set) will be
+$codei%
+	typedef CppAD::vectorBool %atomic_sparsity%
+%$$
+If $icode r$$ is a sparsity pattern
+for a matrix $latex R \in B^{p \times q}$$:
+$icode%r%.size() == %p% * %q%$$.
 
 $subhead bool_sparsity_enum$$
-$index bool_sparsity_enum$$
-If $icode option_value$$ is $codei%atomic_base<%Base%>::bool_sparsity_enum%$$, 
+If $icode option_value$$ is $codei%atomic_base<%Base%>::bool_sparsity_enum%$$,
 then the type used by $icode afun$$ for
 $cref/sparsity patterns/glossary/Sparsity Pattern/$$,
 (after the option is set) will be
 $codei%
 	typedef CppAD::vector<bool> %atomic_sparsity%
 %$$
-If $icode r$$ is a sparsity pattern 
+If $icode r$$ is a sparsity pattern
 for a matrix $latex R \in B^{p \times q}$$:
 $icode%r%.size() == %p% * %q%$$.
 
 $subhead set_sparsity_enum$$
-$index set_sparsity_enum$$
-If $icode option_value$$ is $icode%atomic_base<%Base%>::set_sparsity_enum%$$, 
+If $icode option_value$$ is $icode%atomic_base<%Base%>::set_sparsity_enum%$$,
 then the type used by $icode afun$$ for
 $cref/sparsity patterns/glossary/Sparsity Pattern/$$,
 (after the option is set) will be
 $codei%
 	typedef CppAD::vector< std::set<size_t> > %atomic_sparsity%
 %$$
-If $icode r$$ is a sparsity pattern 
+If $icode r$$ is a sparsity pattern
 for a matrix $latex R \in B^{p \times q}$$:
 $icode%r%.size() == %p%$$, and for $latex i = 0 , \ldots , p-1$$,
-the elements of $icode%r%[%i%]%$$ are between zero and $latex q-1$$ inclusive. 
+the elements of $icode%r%[%i%]%$$ are between zero and $latex q-1$$ inclusive.
 
 $end
 */
 void option(enum option_enum option_value)
 {	switch( option_value )
-	{	case bool_sparsity_enum:
+	{	case pack_sparsity_enum:
+		case bool_sparsity_enum:
 		case set_sparsity_enum:
 		sparsity_ = option_value;
 		break;
@@ -309,14 +343,13 @@ $spell
 $$
 
 $section Using AD Version of Atomic Function$$
-$index atomic, use function$$
 
 $head Syntax$$
 $icode%afun%(%ax%, %ay%)%$$
 
 $head Purpose$$
 Given $icode ax$$,
-this call computes the corresponding value of $icode ay$$. 
+this call computes the corresponding value of $icode ay$$.
 If $codei%AD<%Base%>%$$ operations are being recorded,
 it enters the computation as an atomic operation in the recording;
 see $cref/start recording/Independent/Start Recording/$$.
@@ -327,9 +360,9 @@ $cref/simple vector class/SimpleVector/$$ with elements of type
 $codei%AD<%Base%>%$$; see $cref/Base/atomic_ctor/atomic_base/Base/$$.
 
 $head afun$$
-is a $cref/atomic_user/atomic_ctor/atomic_user/$$ object 
+is a $cref/atomic_user/atomic_ctor/atomic_user/$$ object
 and this $icode afun$$ function call is implemented by the
-$cref/atomic_base/atomic_ctor/atomic_base/$$ class. 
+$cref/atomic_base/atomic_ctor/atomic_base/$$ class.
 
 $head ax$$
 This argument has prototype
@@ -337,9 +370,9 @@ $codei%
 	const %ADVector%& %ax%
 %$$
 and size must be equal to $icode n$$.
-It specifies vector $latex x \in B^n$$ 
-at which an $codei%AD<%Base%>%$$ version of 
-$latex y = f(x)$$ is to be evaluated; see 
+It specifies vector $latex x \in B^n$$
+at which an $codei%AD<%Base%>%$$ version of
+$latex y = f(x)$$ is to be evaluated; see
 $cref/Base/atomic_ctor/atomic_base/Base/$$.
 
 $head ay$$
@@ -348,13 +381,13 @@ $codei%
 	%ADVector%& %ay%
 %$$
 and size must be equal to $icode m$$.
-The input values of its elements 
+The input values of its elements
 are not specified (must not matter).
-Upon return, it is an $codei%AD<%Base%>%$$ version of 
+Upon return, it is an $codei%AD<%Base%>%$$ version of
 $latex y = f(x)$$.
 
 $head Examples$$
-The following files contain example uses of 
+The following files contain example uses of
 the AD version of atomic functions during recording:
 $cref%get_started.cpp%atomic_get_started.cpp%Use Atomic Function%Recording%$$,
 $cref%norm_sq.cpp%atomic_norm_sq.cpp%Use Atomic Function%Recording%$$,
@@ -416,7 +449,7 @@ void operator()(
 	{	vy.resize(m);
 		ty.resize(m);
 	}
-	// 
+	//
 	// Determine tape corresponding to variables in ax
 	tape_id_t     tape_id  = 0;
 	ADTape<Base>* tape     = CPPAD_NULL;
@@ -432,7 +465,7 @@ void operator()(
 			}
 # ifndef NDEBUG
 			if( tape_id != ax[j].tape_id_ )
-			{	msg += afun_name() + 
+			{	msg += afun_name() +
 				": ax contains variables from different threads.";
 				CPPAD_ASSERT_KNOWN(false, msg.c_str());
 			}
@@ -443,9 +476,9 @@ void operator()(
 	size_t p = 0, q = 0;
 	set_id(id);
 # ifdef NDEBUG
-	forward(p, q, vx, vy, tx, ty);  
+	forward(p, q, vx, vy, tx, ty);
 # else
-	ok = forward(p, q, vx, vy, tx, ty);  
+	ok = forward(p, q, vx, vy, tx, ty);
 	if( ! ok )
 	{	msg += afun_name() + ": ok is false for "
 			"zero order forward mode calculation.";
@@ -468,7 +501,7 @@ void operator()(
 	}
 # ifndef NDEBUG
 	if( record_operation & (tape == CPPAD_NULL) )
-	{	msg += 
+	{	msg +=
 		"all elements of vx are false but vy contains a true element";
 		CPPAD_ASSERT_KNOWN(false, msg.c_str() );
 	}
@@ -482,7 +515,7 @@ void operator()(
 		tape->Rec_.PutArg(index_, id, n, m);
 		tape->Rec_.PutOp(UserOp);
 
-		// Now put n operators, one for each element of arugment vector
+		// Now put n operators, one for each element of argument vector
 		CPPAD_ASSERT_UNKNOWN( NumRes(UsravOp) == 0 );
 		CPPAD_ASSERT_UNKNOWN( NumRes(UsrapOp) == 0 );
 		CPPAD_ASSERT_UNKNOWN( NumArg(UsravOp) == 1 );
@@ -494,7 +527,7 @@ void operator()(
 				tape->Rec_.PutOp(UsravOp);
 			}
 			else
-			{	// information for an arugment that is parameter
+			{	// information for an argument that is parameter
 				addr_t par = tape->Rec_.PutPar(ax[j].value_);
 				tape->Rec_.PutArg(par);
 				tape->Rec_.PutOp(UsrapOp);
@@ -521,7 +554,7 @@ void operator()(
 		// Put a duplicate UserOp at end of UserOp sequence
 		tape->Rec_.PutArg(index_, id, n, m);
 		tape->Rec_.PutOp(UserOp);
-	} 
+	}
 	return;
 }
 /*
@@ -542,9 +575,7 @@ $spell
 $$
 
 $section Atomic Forward Mode$$
-$index atomic, forward callback$$
-$index forward, atomic callback$$
-$index forward, atomic virtual$$
+$mindex callback virtual$$
 
 
 $head Syntax$$
@@ -559,7 +590,7 @@ to compute function vales and derivatives.
 $head Implementation$$
 This virtual function must be defined by the
 $cref/atomic_user/atomic_ctor/atomic_user/$$ class.
-It can just return $icode%ok% == false%$$ 
+It can just return $icode%ok% == false%$$
 (and not compute anything) for values
 of $icode%q% > 0%$$ that are greater than those used by your
 $cref/forward/Forward/$$ mode calculations.
@@ -569,7 +600,7 @@ The argument $icode p$$ has prototype
 $codei%
 	size_t %p%
 %$$
-It specifies the lowest order Taylor coefficient that we are evaluating. 
+It specifies the lowest order Taylor coefficient that we are evaluating.
 During calls to $cref atomic_afun$$, $icode%p% == 0%$$.
 
 $head q$$
@@ -577,7 +608,7 @@ The argument $icode q$$ has prototype
 $codei%
 	size_t %q%
 %$$
-It specifies the highest order Taylor coefficient that we are evaluating. 
+It specifies the highest order Taylor coefficient that we are evaluating.
 During calls to $cref atomic_afun$$, $icode%q% == 0%$$.
 
 $head vx$$
@@ -585,19 +616,19 @@ The $code forward$$ argument $icode vx$$ has prototype
 $codei%
 	const CppAD::vector<bool>& %vx%
 %$$
-The case $icode%vx%.size() > 0%$$ only occurs while evaluating a call to 
+The case $icode%vx%.size() > 0%$$ only occurs while evaluating a call to
 $cref atomic_afun$$.
 In this case,
-$icode%p% == %q% == 0%$$, 
+$icode%p% == %q% == 0%$$,
 $icode%vx%.size() == %n%$$, and
 for $latex j = 0 , \ldots , n-1$$,
 $icode%vx%[%j%]%$$ is true if and only if
-$icode%ax%[%j%]%$$ is a $cref/variable/glossary/Variable/$$ 
-in the corresponding call to 
+$icode%ax%[%j%]%$$ is a $cref/variable/glossary/Variable/$$
+in the corresponding call to
 $codei%
 	%afun%(%ax%, %ay%, %id%)
 %$$
-If $icode%vx%.size() == 0%$$, 
+If $icode%vx%.size() == 0%$$,
 then $icode%vy%.size() == 0%$$ and neither of these vectors
 should be used.
 
@@ -607,9 +638,9 @@ $codei%
 	CppAD::vector<bool>& %vy%
 %$$
 If $icode%vy%.size() == 0%$$, it should not be used.
-Otherwise, 
+Otherwise,
 $icode%q% == 0%$$ and $icode%vy%.size() == %m%$$.
-The input values of the elements of $icode vy$$ 
+The input values of the elements of $icode vy$$
 are not specified (must not matter).
 Upon return, for $latex j = 0 , \ldots , m-1$$,
 $icode%vy%[%i%]%$$ is true if and only if
@@ -664,7 +695,7 @@ to the derivatives of $latex Y(t)$$ at $latex t = 0$$ in the following way:
 $latex \[
 	y_j^k = \frac{1}{ k ! } Y_j^{(k)} (0)
 \] $$
-If $latex p > 0$$, 
+If $latex p > 0$$,
 for $latex i = 0 , \ldots , m-1$$ and $latex k = 0 , \ldots , p-1$$,
 the input of $icode ty$$ satisfies
 $latex \[
@@ -684,24 +715,24 @@ and it component wise Hessian $latex f_i^{(2)} (x)$$.
 Then you can compute $icode ty$$ using the following formulas:
 $latex \[
 \begin{array}{rcl}
-y_i^0 & = & Y(0) 
+y_i^0 & = & Y(0)
         = f_i ( x^0 )
 \\
-y_i^1 & = & Y^{(1)} ( 0 ) 
-        = f_i^{(1)} ( x^0 ) X^{(1)} ( 0 ) 
-        = f_i^{(1)} ( x^0 ) x^1 
+y_i^1 & = & Y^{(1)} ( 0 )
+        = f_i^{(1)} ( x^0 ) X^{(1)} ( 0 )
+        = f_i^{(1)} ( x^0 ) x^1
 \\
-y_i^2 
+y_i^2
 & = & \frac{1}{2 !} Y^{(2)} (0)
 \\
 & = & \frac{1}{2} X^{(1)} (0)^\R{T} f_i^{(2)} ( x^0 ) X^{(1)} ( 0 )
   +   \frac{1}{2} f_i^{(1)} ( x^0 ) X^{(2)} ( 0 )
 \\
-& = & \frac{1}{2} (x^1)^\R{T} f_i^{(2)} ( x^0 ) x^1 
+& = & \frac{1}{2} (x^1)^\R{T} f_i^{(2)} ( x^0 ) x^1
   +    f_i^{(1)} ( x^0 ) x^2
 \end{array}
 \] $$
-For $latex i = 0 , \ldots , m-1$$, and $latex k = 0 , 1 , 2$$, 
+For $latex i = 0 , \ldots , m-1$$, and $latex k = 0 , 1 , 2$$,
 $latex \[
 	ty [ i * (q + 1) + k ] = y_i^k
 \] $$
@@ -724,12 +755,12 @@ $cref%reciprocal.cpp%atomic_reciprocal.cpp%Use Atomic Function%forward%$$,
 $cref%tangent.cpp%atomic_tangent.cpp%Use Atomic Function%forward%$$,
 $cref%mat_mul.cpp%atomic_mat_mul.cpp%Use Atomic Function%forward%$$.
 
- 
+
 $end
 -----------------------------------------------------------------------------
 */
 /*!
-Link from atomic_base to forward mode 
+Link from atomic_base to forward mode
 
 \param p [in]
 lowerest order for this forward mode calculation.
@@ -749,7 +780,7 @@ Taylor coefficients corresponding to \c x for this calculation.
 \param ty [out]
 Taylor coefficient corresponding to \c y for this calculation
 
-See the forward mode in user's documentation for base_atomic 
+See the forward mode in user's documentation for base_atomic
 */
 virtual bool forward(
 	size_t                    p  ,
@@ -775,9 +806,6 @@ $spell
 $$
 
 $section Atomic Reverse Mode$$
-$index atomic, reverse callback$$
-$index reverse, atomic callback$$
-$index reverse, atomic virtual$$
 $spell
 	bool
 $$
@@ -786,7 +814,7 @@ $head Syntax$$
 $icode%ok% = %afun%.reverse(%q%, %tx%, %ty%, %px%, %py%)%$$
 
 $head Purpose$$
-This function is used by $cref/reverse/Reverse/$$ 
+This function is used by $cref/reverse/Reverse/$$
 to compute derivatives.
 
 $head Implementation$$
@@ -794,7 +822,7 @@ If you are using
 $cref/reverse/Reverse/$$ mode,
 this virtual function must be defined by the
 $cref/atomic_user/atomic_ctor/atomic_user/$$ class.
-It can just return $icode%ok% == false%$$ 
+It can just return $icode%ok% == false%$$
 (and not compute anything) for values
 of $icode q$$ that are greater than those used by your
 $cref/reverse/Reverse/$$ mode calculations.
@@ -858,14 +886,14 @@ $latex \[
 
 
 $head F, G, H$$
-We use the notation $latex \{ x_j^k \} \in B^{n \times (q+1)}$$ for 
+We use the notation $latex \{ x_j^k \} \in B^{n \times (q+1)}$$ for
 $latex \[
 	\{ x_j^k \W{:} j = 0 , \ldots , n-1, k = 0 , \ldots , q \}
-\]$$ 
-We use the notation $latex \{ y_i^k \} \in B^{m \times (q+1)}$$ for 
+\]$$
+We use the notation $latex \{ y_i^k \} \in B^{m \times (q+1)}$$ for
 $latex \[
 	\{ y_i^k \W{:} i = 0 , \ldots , m-1, k = 0 , \ldots , q \}
-\]$$ 
+\]$$
 We define the function
 $latex F : B^{n \times (q+1)} \rightarrow B^{m \times (q+1)}$$ by
 $latex \[
@@ -896,7 +924,7 @@ $codei%
 	CppAD::vector<%Base%>& %px%
 %$$
 and $icode%px%.size() == n * (%q%+1)%$$.
-The input values of the elements of $icode px$$ 
+The input values of the elements of $icode px$$
 are not specified (must not matter).
 Upon return,
 for $latex j = 0 , \ldots , n-1$$ and $latex \ell = 0 , \ldots , q$$,
@@ -904,15 +932,15 @@ $latex \[
 \begin{array}{rcl}
 px [ j * (q + 1) + \ell ] & = & \partial H / \partial x_j^\ell
 \\
-& = & 
-( \partial G / \partial \{ y_i^k \} ) 
+& = &
+( \partial G / \partial \{ y_i^k \} )
 	( \partial \{ y_i^k \} / \partial x_j^\ell )
 \\
-& = & 
+& = &
 \sum_{i=0}^{m-1} \sum_{k=0}^q
 ( \partial G / \partial y_i^k ) ( \partial y_i^k / \partial x_j^\ell )
 \\
-& = & 
+& = &
 \sum_{i=0}^{m-1} \sum_{k=\ell}^q
 py[ i * (q + 1 ) + k ] ( \partial F_i^k / \partial x_j^\ell )
 \end{array}
@@ -965,7 +993,7 @@ Partials w.r.t. the \c x Taylor coefficients.
 \param py [in]
 Partials w.r.t. the \c y Taylor coefficients.
 
-See atomic_reverse mode use documentation 
+See atomic_reverse mode use documentation
 */
 virtual bool reverse(
 	size_t                    q  ,
@@ -991,9 +1019,6 @@ $spell
 $$
 
 $section Atomic Forward Jacobian Sparsity Patterns$$
-$index atomic, for_sparse_jac callback$$
-$index for_sparse_jac, atomic callback$$
-$index for_sparse_jac, atomic virtual$$
 
 $head Syntax$$
 $icode%ok% = %afun%.for_sparse_jac(%q%, %r%, %s%)%$$
@@ -1019,16 +1044,16 @@ The argument $icode q$$ has prototype
 $codei%
      size_t %q%
 %$$
-It specifies the number of columns in 
-$latex R \in B^{n \times q}$$ and the Jacobian 
-$latex S(x) \in B^{m \times q}$$. 
+It specifies the number of columns in
+$latex R \in B^{n \times q}$$ and the Jacobian
+$latex S(x) \in B^{m \times q}$$.
 
 $subhead r$$
 This argument has prototype
 $codei%
      const %atomic_sparsity%& %r%
 %$$
-and is a $cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for 
+and is a $cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for
 $latex R \in B^{n \times q}$$.
 
 $subhead s$$
@@ -1036,10 +1061,10 @@ This argument has prototype
 $codei%
 	%atomic_sparsity%& %s%
 %$$
-The input values of its elements 
+The input values of its elements
 are not specified (must not matter).
-Upon return, $icode s$$ is a 
-$cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for 
+Upon return, $icode s$$ is a
+$cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for
 $latex S(x) \in B^{m \times q}$$.
 
 $head ok$$
@@ -1093,6 +1118,11 @@ virtual bool for_sparse_jac(
 	const vector<bool>&                     r  ,
 	      vector<bool>&                     s  )
 {	return false; }
+virtual bool for_sparse_jac(
+	size_t                                  q  ,
+	const vectorBool&                       r  ,
+	      vectorBool&                       s  )
+{	return false; }
 /*
 -------------------------------------- ---------------------------------------
 $begin atomic_rev_sparse_jac$$
@@ -1111,9 +1141,6 @@ $spell
 $$
 
 $section Atomic Reverse Jacobian Sparsity Patterns$$
-$index atomic, rev_sparse_jac callback$$
-$index rev_sparse_jac, atomic callback$$
-$index rev_sparse_jac, atomic virtual$$
 
 $head Syntax$$
 $icode%ok% = %afun%.rev_sparse_jac(%q%, %rt%, %st%)%$$
@@ -1139,16 +1166,16 @@ The argument $icode q$$ has prototype
 $codei%
      size_t %q%
 %$$
-It specifies the number of rows in 
-$latex R \in B^{q \times m}$$ and the Jacobian 
-$latex S(x) \in B^{q \times n}$$. 
+It specifies the number of rows in
+$latex R \in B^{q \times m}$$ and the Jacobian
+$latex S(x) \in B^{q \times n}$$.
 
 $subhead rt$$
 This argument has prototype
 $codei%
      const %atomic_sparsity%& %rt%
 %$$
-and is a 
+and is a
 $cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for
 $latex R^\R{T} \in B^{m \times q}$$.
 
@@ -1157,11 +1184,11 @@ This argument has prototype
 $codei%
 	%atomic_sparsity%& %st%
 %$$
-The input value of its elements 
+The input value of its elements
 are not specified (must not matter).
-Upon return, $icode s$$ is a 
+Upon return, $icode s$$ is a
 $cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for
-$latex S(x)^\R{T} \in B^{n \times q}$$. 
+$latex S(x)^\R{T} \in B^{n \times q}$$.
 
 $head ok$$
 The return value $icode ok$$ has prototype
@@ -1214,6 +1241,11 @@ virtual bool rev_sparse_jac(
 	const vector<bool>&                     rt ,
 	      vector<bool>&                     st )
 {	return false; }
+virtual bool rev_sparse_jac(
+	size_t                                  q  ,
+	const vectorBool&                       rt ,
+	      vectorBool&                       st )
+{	return false; }
 /*
 -------------------------------------- ---------------------------------------
 $begin atomic_rev_sparse_hes$$
@@ -1232,9 +1264,6 @@ $spell
 $$
 
 $section Atomic Reverse Hessian Sparsity Patterns$$
-$index atomic, rev_sparse_hes callback$$
-$index rev_sparse_hes, atomic callback$$
-$index rev_sparse_hes, atomic virtual$$
 
 $head Syntax$$
 $icode%ok% = %afun%.rev_sparse_hes(%vx%, %s%, %t%, %q%, %r%, %u%, %v%)%$$
@@ -1242,9 +1271,9 @@ $icode%ok% = %afun%.rev_sparse_hes(%vx%, %s%, %t%, %q%, %r%, %u%, %v%)%$$
 $head Purpose$$
 This function is used by $cref RevSparseHes$$ to compute
 Hessian sparsity patterns.
-There is an unspecified scalar valued function 
+There is an unspecified scalar valued function
 $latex g : B^m \rightarrow B$$.
-Given a $cref/sparsity pattern/glossary/Sparsity Pattern/$$ for 
+Given a $cref/sparsity pattern/glossary/Sparsity Pattern/$$ for
 $latex R \in B^{n \times q}$$,
 and information about the function $latex z = g(y)$$,
 this routine computes the sparsity pattern for
@@ -1265,8 +1294,8 @@ $codei%
 $icode%vx%.size() == %n%$$, and
 for $latex j = 0 , \ldots , n-1$$,
 $icode%vx%[%j%]%$$ is true if and only if
-$icode%ax%[%j%]%$$ is a $cref/variable/glossary/Variable/$$ 
-in the corresponding call to 
+$icode%ax%[%j%]%$$ is a $cref/variable/glossary/Variable/$$
+in the corresponding call to
 $codei%
 	%afun%(%ax%, %ay%, %id%)
 %$$
@@ -1276,8 +1305,8 @@ The argument $icode s$$ has prototype
 $codei%
      const CppAD:vector<bool>& %s%
 %$$
-and its size is $icode m$$. 
-It is a sparsity pattern for 
+and its size is $icode m$$.
+It is a sparsity pattern for
 $latex S(x) = g^{(1)} (y) \in B^{1 \times m}$$.
 
 $subhead t$$
@@ -1286,10 +1315,10 @@ $codei%
      CppAD:vector<bool>& %t%
 %$$
 and its size is $icode m$$.
-The input values of its elements 
+The input values of its elements
 are not specified (must not matter).
-Upon return, $icode t$$ is a 
-sparsity pattern for 
+Upon return, $icode t$$ is a
+sparsity pattern for
 $latex T(x) \in B^{1 \times n}$$ where
 $latex \[
 	T(x) = (g \circ f)^{(1)} (x) = S(x) * f^{(1)} (x)
@@ -1300,17 +1329,17 @@ The argument $icode q$$ has prototype
 $codei%
      size_t %q%
 %$$
-It specifies the number of columns in 
+It specifies the number of columns in
 $latex R \in B^{n \times q}$$,
 $latex U(x) \in B^{m \times q}$$, and
-$latex V(x) \in B^{n \times q}$$. 
+$latex V(x) \in B^{n \times q}$$.
 
 $subhead r$$
 This argument has prototype
 $codei%
      const %atomic_sparsity%& %r%
 %$$
-and is a $cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for 
+and is a $cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for
 $latex R \in B^{n \times q}$$.
 
 $head u$$
@@ -1318,15 +1347,15 @@ This argument has prototype
 $codei%
      const %atomic_sparsity%& %u%
 %$$
-and is a $cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for 
+and is a $cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for
 $latex U(x) \in B^{m \times q}$$ which is defined by
 $latex \[
 \begin{array}{rcl}
 U(x)
-& = & 
+& = &
 \partial_u \{ \partial_y g[ y + f^{(1)} (x) R u ] \}_{u=0}
 \\
-& = & 
+& = &
 \partial_u \{ g^{(1)} [ y + f^{(1)} (x) R u ] \}_{u=0}
 \\
 & = &
@@ -1339,15 +1368,15 @@ This argument has prototype
 $codei%
      %atomic_sparsity%& %v%
 %$$
-The input value of its elements 
+The input value of its elements
 are not specified (must not matter).
-Upon return, $icode v$$ is a 
-$cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for 
+Upon return, $icode v$$ is a
+$cref/atomic_sparsity/atomic_option/atomic_sparsity/$$ pattern for
 $latex V(x) \in B^{n \times q}$$ which is defined by
 $latex \[
 \begin{array}{rcl}
-V(x) 
-& = & 
+V(x)
+& = &
 \partial_u [ \partial_x (g \circ f) ( x + R u )  ]_{u=0}
 \\
 & = &
@@ -1431,6 +1460,15 @@ virtual bool rev_sparse_hes(
 	const vector<bool>&                     u  ,
 	      vector<bool>&                     v  )
 {	return false; }
+virtual bool rev_sparse_hes(
+	const vector<bool>&                     vx ,
+	const vector<bool>&                     s  ,
+	      vector<bool>&                     t  ,
+	size_t                                  q  ,
+	const vectorBool&                       r  ,
+	const vectorBool&                       u  ,
+	      vectorBool&                       v  )
+{	return false; }
 /*
 ------------------------------------------------------------------------------
 $begin atomic_base_clear$$
@@ -1440,10 +1478,7 @@ $spell
 $$
 
 $section Free Static Variables$$
-$index free, atomic static$$
-$index atomic, free static$$
-$index static, free atomic$$
-$index clear, atomic static$$
+$mindex clear$$
 
 $head Syntax$$
 $codei%atomic_base<%Base%>::clear()%$$
@@ -1454,11 +1489,11 @@ avoid repeated memory allocation calls and thereby increase speed
 (until it is deleted).
 If an the $code atomic_base$$ object is global or static because,
 the it does not get deleted.
-This is a problem when using 
-$code thread_alloc$$ $cref/free_all/ta_free_all/$$ 
-to check that all allocated memory has been freed. 
+This is a problem when using
+$code thread_alloc$$ $cref/free_all/ta_free_all/$$
+to check that all allocated memory has been freed.
 Calling this $code clear$$ function will free all the
-memory currently being held onto by the 
+memory currently being held onto by the
 $codei%atomic_base<%Base%>%$$ class.
 
 $head Future Use$$
@@ -1506,7 +1541,7 @@ Set value of id (used by deprecated old_atomic class)
 This function is called just before calling any of the virtual funcitons
 and has the corresponding id of the corresponding virtual call.
 */
-virtual void set_id(size_t id) 
+virtual void set_id(size_t id)
 { }
 // ---------------------------------------------------------------------------
 };
