@@ -1,21 +1,25 @@
-/* $Id: base_std_math.hpp 3495 2014-12-24 01:16:15Z bradbell $ */
-# ifndef CPPAD_BASE_STD_MATH_INCLUDED
-# define CPPAD_BASE_STD_MATH_INCLUDED
+// $Id: base_std_math.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_BASE_STD_MATH_HPP
+# define CPPAD_BASE_STD_MATH_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
-/* 
+/*
 $begin base_std_math$$
 $spell
+	expm1
+	atanh
+	acosh
+	asinh
 	inline
 	fabs
 	isnan
@@ -34,22 +38,16 @@ $spell
 $$
 
 $section Base Type Requirements for Standard Math Functions$$
-$index math, base require$$
-$index base, math require$$
-$index require, base math$$
 
 $head Purpose$$
 These definitions are required for the user's code to use the type
 $codei%AD<%Base%>%$$:
 
-$head Unary Standard Math$$ 
-$index math, base unary$$
-$index base, unary math$$
-$index unary, base math$$
+$head Unary Standard Math$$
 The type $icode Base$$ must support the following functions
 unary standard math functions (in the CppAD namespace):
 $table
-$bold Syntax$$ $cnext $bold Result$$ 
+$bold Syntax$$ $cnext $bold Result$$
 $rnext
 $icode%y% = abs(%x%)%$$  $cnext absolute value     $rnext
 $icode%y% = acos(%x%)%$$ $cnext inverse cosine     $rnext
@@ -63,7 +61,7 @@ $icode%y% = log(%x%)%$$  $cnext natural logarithm  $rnext
 $icode%y% = sin(%x%)%$$  $cnext sine               $rnext
 $icode%y% = sinh(%x%)%$$ $cnext hyperbolic sine    $rnext
 $icode%y% = sqrt(%x%)%$$ $cnext square root        $rnext
-$icode%y% = tan(%x%)%$$  $cnext tangent           
+$icode%y% = tan(%x%)%$$  $cnext tangent
 $tend
 where the arguments and return value have the prototypes
 $codei%
@@ -75,7 +73,6 @@ $cref/base_alloc/base_alloc.hpp/Unary Standard Math/$$,
 
 
 $head CPPAD_STANDARD_MATH_UNARY$$
-$index CPPAD_STANDARD_MATH_UNARY$$
 The macro invocation, within the CppAD namespace,
 $codei%
 	CPPAD_STANDARD_MATH_UNARY(%Base%, %Fun%)
@@ -86,28 +83,32 @@ $codei%
 %$$
 This macro uses the functions $codei%std::%Fun%$$ which
 must be defined and have the same prototype as $codei%CppAD::%Fun%$$.
-For example, 
+For example,
 $cref/float/base_float.hpp/Unary Standard Math/$$.
 
-$head erf$$
-$index erf, base require$$
-$index base, erf require$$
-$index require, base erf$$
-If the error function is supported by the compiler,
-$cref/CPPAD_COMPILER_HAS_ERF/erf/Method/CPPAD_COMPILER_HAS_ERF/$$
-is one,
-the type $icode Base$$ must support the syntax
+$head erf, asinh, acosh, atanh, expm1, log1p$$
+If this preprocessor symbol
+$code CPPAD_USE_CPLUSPLUS_2011$$ is true ($code 1$$),
+when compiling for c++11, the type
+$code double$$ is supported for the functions listed below.
+In this case, the type $icode Base$$ must also support these functions:
+$table
+$bold Syntax$$ $cnext $bold Result$$
+$rnext
+$icode%y% = erf(%x%)%$$    $cnext error function                $rnext
+$icode%y% = asinh(%x%)%$$  $cnext inverse hyperbolic sin        $rnext
+$icode%y% = acosh(%x%)%$$  $cnext inverse hyperbolic cosine     $rnext
+$icode%y% = atanh(%x%)%$$  $cnext inverse hyperbolic tangent    $rnext
+$icode%y% = expm1(%x%)%$$  $cnext exponential of x minus one    $rnext
+$icode%y% = log1p(%x%)%$$  $cnext logarithm of one plus x
+$tend
+where the arguments and return value have the prototypes
 $codei%
-	%y% = CppAD::erf(%x%)
+	const %Base%& %x%
+	%Base%        %y%
 %$$
-where $icode x$$ and $icode y$$ have the same prototype as above.
-For example, see
-$cref/base_alloc/base_alloc.hpp/erf/$$.
 
 $head sign$$
-$index sign, base require$$
-$index base, sign require$$
-$index require, base sign$$
 The type $icode Base$$ must support the syntax
 $codei%
 	%y% = CppAD::sign(%x%)
@@ -128,9 +129,6 @@ the $code code sign$$ function should generate an assert if it is used; see
 $cref/complex invalid unary math/base_complex.hpp/Invalid Unary Math/$$.
 
 $head pow$$
-$index pow, base require$$
-$index base, pow require$$
-$index require, base pow$$
 The type $icode Base$$ must support the syntax
 $codei%
 	%z% = CppAD::pow(%x%, %y%)
@@ -150,8 +148,6 @@ $cref/base_alloc/base_alloc.hpp/pow/$$.
 
 
 $head isnan$$
-$index isnan, base type$$
-$index base, isnan$$ 
 If $icode Base$$ defines the $code isnan$$ function,
 you may also have to provide a definition in the CppAD namespace
 (to avoid a function ambiguity).
@@ -159,30 +155,6 @@ For example, see
 $cref/base_complex/base_complex.hpp/isnan/$$.
 
 
-$head limits$$
-$index numeric, limits Base$$
-$index limits, numeric Base$$
-$index Base, numeric_limits$$
-The $cref/numeric_limits/limits/$$ functions
-$codei%
-	%Base% CppAD::numeric_limits<%Base%>::epsilon()
-	%Base% CppAD::numeric_limits<%Base%>::min()
-	%Base% CppAD::numeric_limits<%Base%>::max()
-%$$
-must return machine epsilon,
-minimum positive normalize value,
-and maximum finite value for the type $icode Base$$.
-
-$subhead epsilon$$
-The deprecated function $cref epsilon$$ function
-must also be included. It can be implemented using
-$codei%
-namespace CppAD {
-	template <> inline %Base% epsilon<%Base%>(void)
-	{	return numeric_limits<%Base%>::epsilon(); }
-}
-%$$
-
 $end
 -------------------------------------------------------------------------------
 */
