@@ -1,12 +1,12 @@
-/* $Id: bool_valued.hpp 2506 2012-10-24 19:36:49Z bradbell $ */
-# ifndef CPPAD_BOOL_VALUED_INCLUDED
-# define CPPAD_BOOL_VALUED_INCLUDED
+// $Id: bool_valued.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_BOOL_VALUED_HPP
+# define CPPAD_BOOL_VALUED_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-06 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -19,8 +19,6 @@ $spell
 	Bool
 $$
 
-$index operation, AD Bool valued$$
-$index function, AD Bool valued$$
 
 $section Bool Valued Operations and Functions with AD Arguments$$
 
@@ -38,7 +36,7 @@ $rref BoolFun$$
 $rref ParVar$$
 $rref EqualOpSeq$$
 $tend
-	
+
 
 $end
 */
