@@ -1,12 +1,12 @@
-/* $Id: convert.hpp 2691 2012-12-30 23:39:57Z bradbell $ */
-# ifndef CPPAD_CONVERT_INCLUDED
-# define CPPAD_CONVERT_INCLUDED
+// $Id: convert.hpp 3769 2015-12-29 16:13:16Z bradbell $
+# ifndef CPPAD_CONVERT_HPP
+# define CPPAD_CONVERT_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -18,14 +18,14 @@ $begin Convert$$
 $spell
 $$
 
-$index convert, from AD$$
-$index AD, convert from$$
 
 $section Conversion and I/O of AD Objects$$
+$mindex convert from$$
 
 $children%
 	cppad/local/value.hpp%
 	cppad/local/integer.hpp%
+	cppad/local/ad_to_string.hpp%
 	cppad/local/ad_io.hpp%
 	cppad/local/print_for.hpp%
 	cppad/local/var2par.hpp
@@ -37,13 +37,14 @@ $rref ad_output$$
 $rref PrintFor$$
 $rref Var2Par$$
 $tend
-	
+
 
 $end
 */
 
 # include <cppad/local/value.hpp>
 # include <cppad/local/integer.hpp>
+# include <cppad/local/ad_to_string.hpp>
 # include <cppad/local/ad_io.hpp>
 # include <cppad/local/print_for.hpp>
 # include <cppad/local/var2par.hpp>
