@@ -1,12 +1,12 @@
-// $Id: csum_op.hpp 3301 2014-05-24 05:20:21Z bradbell $
-# ifndef CPPAD_CSUM_OP_INCLUDED
-# define CPPAD_CSUM_OP_INCLUDED
+// $Id: csum_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_CSUM_OP_HPP
+# define CPPAD_CSUM_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -22,7 +22,7 @@ Forward, reverse and sparsity calculations for cummulative summation.
 /*!
 Compute forward mode Taylor coefficients for result of op = CsumOp.
 
-This operation is 
+This operation is
 \verbatim
 	z = s + x(1) + ... + x(m) - y(1) - ... - y(n).
 \endverbatim
@@ -43,11 +43,11 @@ variable index corresponding to the result for this operation;
 i.e. the row index in \a taylor corresponding to z.
 
 \param arg
-\a arg[0] 
+\a arg[0]
 is the number of addition variables in this cummulative summation; i.e.,
 <tt>m</tt>.
 \n
-\a arg[1] 
+\a arg[1]
 is the number of subtraction variables in this cummulative summation; i.e.,
 \c m.
 \n
@@ -55,10 +55,10 @@ is the number of subtraction variables in this cummulative summation; i.e.,
 is the parameter value \c s in this cummunative summation.
 \n
 <tt>arg[2+i]</tt>
-for <tt>i = 1 , ... , m</tt> is the variable index of <tt>x(i)</tt>. 
+for <tt>i = 1 , ... , m</tt> is the variable index of <tt>x(i)</tt>.
 \n
 <tt>arg[2+arg[0]+i]</tt>
-for <tt>i = 1 , ... , n</tt> is the variable index of <tt>y(i)</tt>. 
+for <tt>i = 1 , ... , n</tt> is the variable index of <tt>y(i)</tt>.
 
 \param num_par
 is the number of parameters in \a parameter.
@@ -71,12 +71,12 @@ number of colums in the matrix containing all the Taylor coefficients.
 
 \param taylor
 \b Input: <tt>taylor [ arg[2+i] * cap_order + k ]</tt>
-for <tt>i = 1 , ... , m</tt> 
+for <tt>i = 1 , ... , m</tt>
 and <tt>k = 0 , ... , q</tt>
 is the k-th order Taylor coefficient corresponding to <tt>x(i)</tt>
 \n
 \b Input: <tt>taylor [ arg[2+m+i] * cap_order + k ]</tt>
-for <tt>i = 1 , ... , n</tt> 
+for <tt>i = 1 , ... , n</tt>
 and <tt>k = 0 , ... , q</tt>
 is the k-th order Taylor coefficient corresponding to <tt>y(i)</tt>
 \n
@@ -90,8 +90,8 @@ is the \a k-th order Taylor coefficient corresponding to z.
 */
 template <class Base>
 inline void forward_csum_op(
-	size_t        p           , 
-	size_t        q           , 
+	size_t        p           ,
+	size_t        q           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	size_t        num_par     ,
@@ -106,9 +106,9 @@ inline void forward_csum_op(
 	CPPAD_ASSERT_UNKNOWN( q < cap_order );
 	CPPAD_ASSERT_UNKNOWN( p <= q );
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < num_par );
-	CPPAD_ASSERT_UNKNOWN( 
+	CPPAD_ASSERT_UNKNOWN(
 		arg[0] + arg[1] == arg[ arg[0] + arg[1] + 3 ]
-	); 
+	);
 
 	// Taylor coefficients corresponding to result
 	Base* z = taylor + i_z    * cap_order;
@@ -124,20 +124,20 @@ inline void forward_csum_op(
 		x     = taylor + arg[++j] * cap_order;
 		for(k = p; k <= q; k++)
 			z[k] += x[k];
-	}	
+	}
 	i = arg[1];
 	while(i--)
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[j+1]) < i_z );
 		x     = taylor + arg[++j] * cap_order;
 		for(k = p; k <= q; k++)
 			z[k] -= x[k];
-	}	
+	}
 }
 
 /*!
 Multiple direction forward mode Taylor coefficients for op = CsumOp.
 
-This operation is 
+This operation is
 \verbatim
 	z = s + x(1) + ... + x(m) - y(1) - ... - y(n).
 \endverbatim
@@ -158,11 +158,11 @@ variable index corresponding to the result for this operation;
 i.e. the row index in \a taylor corresponding to z.
 
 \param arg
-\a arg[0] 
+\a arg[0]
 is the number of addition variables in this cummulative summation; i.e.,
 <tt>m</tt>.
 \n
-\a arg[1] 
+\a arg[1]
 is the number of subtraction variables in this cummulative summation; i.e.,
 \c m.
 \n
@@ -170,10 +170,10 @@ is the number of subtraction variables in this cummulative summation; i.e.,
 is the parameter value \c s in this cummunative summation.
 \n
 <tt>arg[2+i]</tt>
-for <tt>i = 1 , ... , m</tt> is the variable index of <tt>x(i)</tt>. 
+for <tt>i = 1 , ... , m</tt> is the variable index of <tt>x(i)</tt>.
 \n
 <tt>arg[2+arg[0]+i]</tt>
-for <tt>i = 1 , ... , n</tt> is the variable index of <tt>y(i)</tt>. 
+for <tt>i = 1 , ... , n</tt> is the variable index of <tt>y(i)</tt>.
 
 \param num_par
 is the number of parameters in \a parameter.
@@ -186,20 +186,20 @@ number of colums in the matrix containing all the Taylor coefficients.
 
 \param taylor
 \b Input: <tt>taylor [ arg[2+i]*((cap_order-1)*r + 1) + 0 ]</tt>
-for <tt>i = 1 , ... , m</tt> 
+for <tt>i = 1 , ... , m</tt>
 is the 0-th order Taylor coefficient corresponding to <tt>x(i)</tt> and
 <tt>taylor [ arg[2+i]*((cap_order-1)*r + 1) + (q-1)*r + ell + 1 ]</tt>
 for <tt>i = 1 , ... , m</tt>,
-<tt>ell = 0 , ... , r-1</tt> 
+<tt>ell = 0 , ... , r-1</tt>
 is the q-th order Taylor coefficient corresponding to <tt>x(i)</tt>
 and direction ell.
 \n
 \b Input: <tt>taylor [ arg[2+m+i]*((cap_order-1)*r + 1) + 0 ]</tt>
-for <tt>i = 1 , ... , n</tt> 
+for <tt>i = 1 , ... , n</tt>
 is the 0-th order Taylor coefficient corresponding to <tt>y(i)</tt> and
 <tt>taylor [ arg[2+m+i]*((cap_order-1)*r + 1) + (q-1)*r + ell + 1 ]</tt>
 for <tt>i = 1 , ... , n</tt>,
-<tt>ell = 0 , ... , r-1</tt> 
+<tt>ell = 0 , ... , r-1</tt>
 is the q-th order Taylor coefficient corresponding to <tt>y(i)</tt>
 and direction ell.
 \n
@@ -209,8 +209,8 @@ for direction <tt>ell = 0 , ... , r-1</tt>.
 */
 template <class Base>
 inline void forward_csum_op_dir(
-	size_t        q           , 
-	size_t        r           , 
+	size_t        q           ,
+	size_t        r           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	size_t        num_par     ,
@@ -225,9 +225,9 @@ inline void forward_csum_op_dir(
 	CPPAD_ASSERT_UNKNOWN( q < cap_order );
 	CPPAD_ASSERT_UNKNOWN( 0 < q );
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[2]) < num_par );
-	CPPAD_ASSERT_UNKNOWN( 
+	CPPAD_ASSERT_UNKNOWN(
 		arg[0] + arg[1] == arg[ arg[0] + arg[1] + 3 ]
-	); 
+	);
 
 	// Taylor coefficients corresponding to result
 	size_t num_taylor_per_var = (cap_order-1) * r + 1;
@@ -243,23 +243,23 @@ inline void forward_csum_op_dir(
 		x = taylor + arg[++j] * num_taylor_per_var + m;
 		for(ell = 0; ell < r; ell++)
 			z[ell] += x[ell];
-	}	
+	}
 	i = arg[1];
 	while(i--)
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[j+1]) < i_z );
 		x = taylor + arg[++j] * num_taylor_per_var + m;
 		for(ell = 0; ell < r; ell++)
 			z[ell] -= x[ell];
-	}	
+	}
 }
 
 /*!
 Compute reverse mode Taylor coefficients for result of op = CsumOp.
 
-This operation is 
+This operation is
 \verbatim
 	z = q + x(1) + ... + x(m) - y(1) - ... - y(n).
-	H(y, x, w, ...) = G[ z(x, y), y, x, w, ... ] 
+	H(y, x, w, ...) = G[ z(x, y), y, x, w, ... ]
 \endverbatim
 
 \tparam Base
@@ -276,11 +276,11 @@ variable index corresponding to the result for this operation;
 i.e. the row index in \a taylor corresponding to z.
 
 \param arg
-\a arg[0] 
+\a arg[0]
 is the number of addition variables in this cummulative summation; i.e.,
 <tt>m</tt>.
 \n
-\a arg[1] 
+\a arg[1]
 is the number of subtraction variables in this cummulative summation; i.e.,
 \c m.
 \n
@@ -288,41 +288,41 @@ is the number of subtraction variables in this cummulative summation; i.e.,
 is the parameter value \c q in this cummunative summation.
 \n
 <tt>arg[2+i]</tt>
-for <tt>i = 1 , ... , m</tt> is the value <tt>x(i)</tt>. 
+for <tt>i = 1 , ... , m</tt> is the value <tt>x(i)</tt>.
 \n
 <tt>arg[2+arg[0]+i]</tt>
-for <tt>i = 1 , ... , n</tt> is the value <tt>y(i)</tt>. 
+for <tt>i = 1 , ... , n</tt> is the value <tt>y(i)</tt>.
 
 \param nc_partial
 number of colums in the matrix containing all the partial derivatives.
 
 \param partial
 \b Input: <tt>partial [ arg[2+i] * nc_partial + k ]</tt>
-for <tt>i = 1 , ... , m</tt> 
+for <tt>i = 1 , ... , m</tt>
 and <tt>k = 0 , ... , d</tt>
 is the partial derivative of G(z, y, x, w, ...) with respect to the
 k-th order Taylor coefficient corresponding to <tt>x(i)</tt>
 \n
 \b Input: <tt>partial [ arg[2+m+i] * nc_partial + k ]</tt>
-for <tt>i = 1 , ... , n</tt> 
+for <tt>i = 1 , ... , n</tt>
 and <tt>k = 0 , ... , d</tt>
 is the partial derivative of G(z, y, x, w, ...) with respect to the
 k-th order Taylor coefficient corresponding to <tt>y(i)</tt>
 \n
 \b Input: <tt>partial [ i_z * nc_partial + k ]</tt>
-for <tt>i = 1 , ... , n</tt> 
+for <tt>i = 1 , ... , n</tt>
 and <tt>k = 0 , ... , d</tt>
 is the partial derivative of G(z, y, x, w, ...) with respect to the
 k-th order Taylor coefficient corresponding to \c z.
 \n
 \b Output: <tt>partial [ arg[2+i] * nc_partial + k ]</tt>
-for <tt>i = 1 , ... , m</tt> 
+for <tt>i = 1 , ... , m</tt>
 and <tt>k = 0 , ... , d</tt>
 is the partial derivative of H(y, x, w, ...) with respect to the
 k-th order Taylor coefficient corresponding to <tt>x(i)</tt>
 \n
 \b Output: <tt>partial [ arg[2+m+i] * nc_partial + k ]</tt>
-for <tt>i = 1 , ... , n</tt> 
+for <tt>i = 1 , ... , n</tt>
 and <tt>k = 0 , ... , d</tt>
 is the partial derivative of H(y, x, w, ...) with respect to the
 k-th order Taylor coefficient corresponding to <tt>y(i)</tt>
@@ -330,7 +330,7 @@ k-th order Taylor coefficient corresponding to <tt>y(i)</tt>
 
 template <class Base>
 inline void reverse_csum_op(
-	size_t        d           , 
+	size_t        d           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	size_t        nc_partial  ,
@@ -353,7 +353,7 @@ inline void reverse_csum_op(
 		k = d1;
 		while(k--)
 			px[k] += pz[k];
-	}	
+	}
 	i = arg[1];
 	while(i--)
 	{	CPPAD_ASSERT_UNKNOWN( size_t(arg[j+1]) < i_z );
@@ -361,14 +361,14 @@ inline void reverse_csum_op(
 		k = d1;
 		while(k--)
 			px[k] -= pz[k];
-	}	
+	}
 }
 
 
 /*!
-Forward mode Jacobian sparsity pattern for CSumOp operator. 
+Forward mode Jacobian sparsity pattern for CSumOp operator.
 
-This operation is 
+This operation is
 \verbatim
 	z = q + x(1) + ... + x(m) - y(1) - ... - y(n).
 \endverbatim
@@ -382,11 +382,11 @@ variable index corresponding to the result for this operation;
 i.e. the index in \a sparsity corresponding to z.
 
 \param arg
-\a arg[0] 
+\a arg[0]
 is the number of addition variables in this cummulative summation; i.e.,
 <tt>m + n</tt>.
 \n
-\a arg[1] 
+\a arg[1]
 is the number of subtraction variables in this cummulative summation; i.e.,
 \c m.
 \n
@@ -394,31 +394,31 @@ is the number of subtraction variables in this cummulative summation; i.e.,
 is the parameter value \c q in this cummunative summation.
 \n
 <tt>arg[2+i]</tt>
-for <tt>i = 1 , ... , m</tt> is the value <tt>x(i)</tt>. 
+for <tt>i = 1 , ... , m</tt> is the value <tt>x(i)</tt>.
 \n
 <tt>arg[2+arg[1]+i]</tt>
-for <tt>i = 1 , ... , n</tt> is the value <tt>y(i)</tt>. 
+for <tt>i = 1 , ... , n</tt> is the value <tt>y(i)</tt>.
 
 \param sparsity
-\b Input: 
+\b Input:
 For <tt>i = 1 , ... , m</tt>,
 the set with index \a arg[2+i] in \a sparsity
 is the sparsity bit pattern for <tt>x(i)</tt>.
-This identifies which of the independent variables the variable 
-<tt>x(i)</tt> depends on. 
+This identifies which of the independent variables the variable
+<tt>x(i)</tt> depends on.
 \n
-\b Input: 
+\b Input:
 For <tt>i = 1 , ... , n</tt>,
 the set with index \a arg[2+arg[0]+i] in \a sparsity
 is the sparsity bit pattern for <tt>x(i)</tt>.
-This identifies which of the independent variables the variable 
-<tt>y(i)</tt> depends on. 
+This identifies which of the independent variables the variable
+<tt>y(i)</tt> depends on.
 \n
-\b Output: 
+\b Output:
 The set with index \a i_z in \a sparsity
 is the sparsity bit pattern for z.
 This identifies which of the independent variables the variable z
-depends on. 
+depends on.
 */
 
 template <class Vector_set>
@@ -436,19 +436,19 @@ inline void forward_sparse_jacobian_csum_op(
 		sparsity.binary_union(
 			i_z        , // index in sparsity for result
 			i_z        , // index in sparsity for left operand
-			arg[++j]   , // index for right operand 
+			arg[++j]   , // index for right operand
 			sparsity     // sparsity vector for right operand
 		);
-	}	
+	}
 }
 
 /*!
-Reverse mode Jacobian sparsity pattern for CSumOp operator. 
+Reverse mode Jacobian sparsity pattern for CSumOp operator.
 
-This operation is 
+This operation is
 \verbatim
 	z = q + x(1) + ... + x(m) - y(1) - ... - y(n).
-	H(y, x, w, ...) = G[ z(x, y), y, x, w, ... ] 
+	H(y, x, w, ...) = G[ z(x, y), y, x, w, ... ]
 \endverbatim
 
 \tparam Vector_set
@@ -460,11 +460,11 @@ variable index corresponding to the result for this operation;
 i.e. the index in \a sparsity corresponding to z.
 
 \param arg
-\a arg[0] 
+\a arg[0]
 is the number of addition variables in this cummulative summation; i.e.,
 <tt>m + n</tt>.
 \n
-\a arg[1] 
+\a arg[1]
 is the number of subtraction variables in this cummulative summation; i.e.,
 \c m.
 \n
@@ -472,27 +472,27 @@ is the number of subtraction variables in this cummulative summation; i.e.,
 is the parameter value \c q in this cummunative summation.
 \n
 <tt>arg[2+i]</tt>
-for <tt>i = 1 , ... , m</tt> is the value <tt>x(i)</tt>. 
+for <tt>i = 1 , ... , m</tt> is the value <tt>x(i)</tt>.
 \n
 <tt>arg[2+arg[1]+i]</tt>
-for <tt>i = 1 , ... , n</tt> is the value <tt>y(i)</tt>. 
+for <tt>i = 1 , ... , n</tt> is the value <tt>y(i)</tt>.
 
 \param sparsity
 For <tt>i = 1 , ... , m</tt>,
 the set with index \a arg[2+i] in \a sparsity
 is the sparsity bit pattern for <tt>x(i)</tt>.
-This identifies which of the dependent variables depend on <tt>x(i)</tt>. 
+This identifies which of the dependent variables depend on <tt>x(i)</tt>.
 On input, the sparsity patter corresponds to \c G,
 and on ouput it corresponds to \c H.
 \n
 For <tt>i = 1 , ... , m</tt>,
 the set with index \a arg[2+arg[0]+i] in \a sparsity
 is the sparsity bit pattern for <tt>y(i)</tt>.
-This identifies which of the dependent variables depend on <tt>y(i)</tt>. 
+This identifies which of the dependent variables depend on <tt>y(i)</tt>.
 On input, the sparsity patter corresponds to \c G,
 and on ouput it corresponds to \c H.
 \n
-\b Input: 
+\b Input:
 The set with index \a i_z in \a sparsity
 is the sparsity bit pattern for z.
 On input it corresponds to \c G and on output it is undefined.
@@ -513,18 +513,18 @@ inline void reverse_sparse_jacobian_csum_op(
 		sparsity.binary_union(
 			arg[j]     , // index in sparsity for result
 			arg[j]     , // index in sparsity for left operand
-			i_z        , // index for right operand 
+			i_z        , // index for right operand
 			sparsity     // sparsity vector for right operand
 		);
-	}	
+	}
 }
 /*!
-Reverse mode Hessian sparsity pattern for CSumOp operator. 
+Reverse mode Hessian sparsity pattern for CSumOp operator.
 
-This operation is 
+This operation is
 \verbatim
 	z = q + x(1) + ... + x(m) - y(1) - ... - y(n).
-	H(y, x, w, ...) = G[ z(x, y), y, x, w, ... ] 
+	H(y, x, w, ...) = G[ z(x, y), y, x, w, ... ]
 \endverbatim
 
 \tparam Vector_set
@@ -536,11 +536,11 @@ variable index corresponding to the result for this operation;
 i.e. the index in \a sparsity corresponding to z.
 
 \param arg
-\a arg[0] 
+\a arg[0]
 is the number of addition variables in this cummulative summation; i.e.,
 <tt>m + n</tt>.
 \n
-\a arg[1] 
+\a arg[1]
 is the number of subtraction variables in this cummulative summation; i.e.,
 \c m.
 \n
@@ -548,10 +548,10 @@ is the number of subtraction variables in this cummulative summation; i.e.,
 is the parameter value \c q in this cummunative summation.
 \n
 <tt>arg[2+i]</tt>
-for <tt>i = 1 , ... , m</tt> is the value <tt>x(i)</tt>. 
+for <tt>i = 1 , ... , m</tt> is the value <tt>x(i)</tt>.
 \n
 <tt>arg[2+arg[0]+i]</tt>
-for <tt>i = 1 , ... , n</tt> is the value <tt>y(i)</tt>. 
+for <tt>i = 1 , ... , n</tt> is the value <tt>y(i)</tt>.
 
 \param rev_jacobian
 <tt>rev_jacobian[i_z]</tt>
@@ -559,7 +559,7 @@ is all false (true) if the Jabobian of G with respect to z must be zero
 (may be non-zero).
 \n
 \n
-For <tt>i = 1 , ... , m</tt> 
+For <tt>i = 1 , ... , m</tt>
 <tt>rev_jacobian[ arg[2+i] ]</tt>
 is all false (true) if the Jacobian with respect to <tt>x(i)</tt>
 is zero (may be non-zero).
@@ -567,7 +567,7 @@ On input, it corresponds to the function G,
 and on output it corresponds to the function H.
 \n
 \n
-For <tt>i = 1 , ... , n</tt> 
+For <tt>i = 1 , ... , n</tt>
 <tt>rev_jacobian[ arg[2+arg[0]+i] ]</tt>
 is all false (true) if the Jacobian with respect to <tt>y(i)</tt>
 is zero (may be non-zero).
@@ -580,17 +580,17 @@ is the Hessian sparsity pattern for the fucntion G
 where one of the partials derivative is with respect to z.
 \n
 \n
-For <tt>i = 1 , ... , m</tt> 
+For <tt>i = 1 , ... , m</tt>
 The set with index <tt>arg[2+i]</tt> in \a rev_hes_sparsity
-is the Hessian sparsity pattern 
+is the Hessian sparsity pattern
 where one of the partials derivative is with respect to <tt>x(i)</tt>.
 On input, it corresponds to the function G,
 and on output it corresponds to the function H.
 \n
 \n
-For <tt>i = 1 , ... , n</tt> 
+For <tt>i = 1 , ... , n</tt>
 The set with index <tt>arg[2+arg[0]+i]</tt> in \a rev_hes_sparsity
-is the Hessian sparsity pattern 
+is the Hessian sparsity pattern
 where one of the partials derivative is with respect to <tt>y(i)</tt>.
 On input, it corresponds to the function G,
 and on output it corresponds to the function H.
@@ -612,11 +612,11 @@ inline void reverse_sparse_hessian_csum_op(
 		rev_hes_sparsity.binary_union(
 		arg[j]             , // index in sparsity for result
 		arg[j]             , // index in sparsity for left operand
-		i_z                , // index for right operand 
+		i_z                , // index for right operand
 		rev_hes_sparsity     // sparsity vector for right operand
 		);
 		rev_jacobian[arg[j]] |= rev_jacobian[i_z];
-	}	
+	}
 }
 
 } // END_CPPAD_NAMESPACE
