@@ -1,12 +1,12 @@
-/* $Id: declare_ad.hpp 3476 2014-12-16 17:15:01Z bradbell $ */
-# ifndef CPPAD_DECLARE_AD_INCLUDED
-# define CPPAD_DECLARE_AD_INCLUDED
+// $Id: declare_ad.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_DECLARE_AD_HPP
+# define CPPAD_DECLARE_AD_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -14,13 +14,13 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 # include <cppad/configure.hpp>
-# if CPPAD_HAS_CSTDINT_8_TO_64
+# if CPPAD_USE_CPLUSPLUS_2011
 # include <cstdint>
 # endif
 
 namespace CppAD {
 	// The conditional expression operator enum type
-	enum CompareOp 
+	enum CompareOp
 	{	CompareLt, // less than
 		CompareLe, // less than or equal
 		CompareEq, // equal
@@ -49,7 +49,7 @@ namespace CppAD {
 	// functions with one VecAD<Base> argument
 	template <class Base> bool Parameter         (const VecAD<Base> &u);
 	template <class Base> bool Variable          (const VecAD<Base> &u);
-	
+
 	// functions with one AD<Base> argument
 	template <class Base> int  Integer           (const AD<Base> &u);
 	template <class Base> bool Parameter         (const AD<Base> &u);
@@ -104,6 +104,10 @@ namespace CppAD {
 	template <class Base> AD<Base> pow (
 		const AD<Base> &x, const AD<Base> &y);
 
+	// azmul
+	template <class Base> AD<Base> azmul (
+		const AD<Base> &x, const AD<Base> &y);
+
 	// NearEqual
 	template <class Base> bool NearEqual(
 	const AD<Base> &x, const AD<Base> &y, const Base &r, const Base &a);
@@ -113,30 +117,30 @@ namespace CppAD {
 
 	template <class Base> bool NearEqual(
 	const AD<Base> &x, const Base &y, const Base &r, const Base &a);
-	
+
 	// CondExpOp
 	template <class Base> AD<Base> CondExpOp (
 		enum CompareOp         cop ,
-		const AD<Base>       &left , 
-		const AD<Base>      &right , 
-		const AD<Base>   &trueCase , 
-		const AD<Base>  &falseCase 
+		const AD<Base>       &left ,
+		const AD<Base>      &right ,
+		const AD<Base>   &trueCase ,
+		const AD<Base>  &falseCase
 	);
-	
+
 	// IdenticalEqualPar
-	template <class Base> 
+	template <class Base>
 	bool IdenticalEqualPar (const AD<Base> &u, const AD<Base> &v);
-	
+
 	// EqualOpSeq
-	template <class Base> 
+	template <class Base>
 	bool EqualOpSeq (const AD<Base> &u, const AD<Base> &v);
-	
+
 	// PrintFor
-	template <class Base> 
+	template <class Base>
 	void PrintFor(
 		const AD<Base>&    flag   ,
 		const char*        before ,
-		const AD<Base>&    var    , 
+		const AD<Base>&    var    ,
 		const char*        after
 	);
 
