@@ -1,12 +1,12 @@
-/* $Id: div_op.hpp 3321 2014-09-12 09:50:39Z bradbell $ */
-# ifndef CPPAD_DIV_OP_INCLUDED
-# define CPPAD_DIV_OP_INCLUDED
+// $Id: div_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_DIV_OP_HPP
+# define CPPAD_DIV_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -36,8 +36,8 @@ and the argument \a parameter is not used.
 
 template <class Base>
 inline void forward_divvv_op(
-	size_t        p           , 
-	size_t        q           , 
+	size_t        p           ,
+	size_t        q           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -82,8 +82,8 @@ and the argument \a parameter is not used.
 
 template <class Base>
 inline void forward_divvv_op_dir(
-	size_t        q           , 
-	size_t        r           , 
+	size_t        q           ,
+	size_t        r           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -108,7 +108,7 @@ inline void forward_divvv_op_dir(
 	size_t m = (q-1) * r + 1;
 	for(size_t ell = 0; ell < r; ell++)
 	{	z[m+ell] = x[m+ell] - z[0] * y[m+ell];
-		for(size_t k = 1; k < q; k++)		
+		for(size_t k = 1; k < q; k++)
 			z[m+ell] -= z[(q-k-1)*r+1+ell] * y[(k-1)*r+1+ell];
 		z[m+ell] /= y[0];
 	}
@@ -165,7 +165,7 @@ and the argument \a parameter is not used.
 
 template <class Base>
 inline void reverse_divvv_op(
-	size_t        d           , 
+	size_t        d           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -191,6 +191,7 @@ inline void reverse_divvv_op(
 
 	// Using CondExp, it can make sense to divide by zero
 	// so do not make it an error.
+	Base inv_y0 = Base(1) / y[0];
 
 	size_t k;
 	// number of indices to access
@@ -198,14 +199,14 @@ inline void reverse_divvv_op(
 	while(j)
 	{	--j;
 		// scale partial w.r.t. z[j]
-		pz[j] /= y[0];
+		pz[j] = azmul(pz[j], inv_y0);
 
 		px[j] += pz[j];
 		for(k = 1; k <= j; k++)
-		{	pz[j-k] -= pz[j] * y[k];
-			py[k]   -= pz[j] * z[j-k];
-		}	
-		py[0] -= pz[j] * z[j];
+		{	pz[j-k] -= azmul(pz[j], y[k]  );
+			py[k]   -= azmul(pz[j], z[j-k]);
+		}
+		py[0] -= azmul(pz[j], z[j]);
 	}
 }
 
@@ -225,8 +226,8 @@ this operations is for the case where x is a parameter and y is a variable.
 
 template <class Base>
 inline void forward_divpv_op(
-	size_t        p           , 
-	size_t        q           , 
+	size_t        p           ,
+	size_t        q           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -275,8 +276,8 @@ this operations is for the case where x is a parameter and y is a variable.
 
 template <class Base>
 inline void forward_divpv_op_dir(
-	size_t        q           , 
-	size_t        r           , 
+	size_t        q           ,
+	size_t        r           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -355,7 +356,7 @@ this operations is for the case where x is a parameter and y is a variable.
 
 template <class Base>
 inline void reverse_divpv_op(
-	size_t        d           , 
+	size_t        d           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -380,6 +381,7 @@ inline void reverse_divpv_op(
 
 	// Using CondExp, it can make sense to divide by zero so do not
 	// make it an error.
+	Base inv_y0 = Base(1) / y[0];
 
 	size_t k;
 	// number of indices to access
@@ -387,13 +389,13 @@ inline void reverse_divpv_op(
 	while(j)
 	{	--j;
 		// scale partial w.r.t z[j]
-		pz[j] /= y[0];
+		pz[j] = azmul(pz[j], inv_y0);
 
 		for(k = 1; k <= j; k++)
-		{	pz[j-k] -= pz[j] * y[k];
-			py[k]   -= pz[j] * z[j-k];
-		}	
-		py[0] -= pz[j] * z[j];
+		{	pz[j-k] -= azmul(pz[j], y[k]  );
+			py[k]   -= azmul(pz[j], z[j-k] );
+		}
+		py[0] -= azmul(pz[j], z[j]);
 	}
 }
 
@@ -414,8 +416,8 @@ this operations is for the case where x is a variable and y is a parameter.
 
 template <class Base>
 inline void forward_divvp_op(
-	size_t        p           , 
-	size_t        q           , 
+	size_t        p           ,
+	size_t        q           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -435,7 +437,7 @@ inline void forward_divvp_op(
 	// Parameter value
 	Base y = parameter[ arg[1] ];
 
-	// Using CondExp and multiple levels of AD, it can make sense 
+	// Using CondExp and multiple levels of AD, it can make sense
 	// to divide by zero so do not make it an error.
 	for(size_t d = p; d <= q; d++)
 		z[d] = x[d] / y;
@@ -455,8 +457,8 @@ this operations is for the case where x is a variable and y is a parameter.
 
 template <class Base>
 inline void forward_divvp_op_dir(
-	size_t        q           , 
-	size_t        r           , 
+	size_t        q           ,
+	size_t        r           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -477,7 +479,7 @@ inline void forward_divvp_op_dir(
 	// Parameter value
 	Base y = parameter[ arg[1] ];
 
-	// Using CondExp and multiple levels of AD, it can make sense 
+	// Using CondExp and multiple levels of AD, it can make sense
 	// to divide by zero so do not make it an error.
 	size_t m = (q-1)*r + 1;
 	for(size_t ell = 0; ell < r; ell++)
@@ -535,7 +537,7 @@ this operations is for the case where x is a variable and y is a parameter.
 
 template <class Base>
 inline void reverse_divvp_op(
-	size_t        d           , 
+	size_t        d           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -559,12 +561,13 @@ inline void reverse_divvp_op(
 
 	// Using CondExp, it can make sense to divide by zero
 	// so do not make it an error.
+	Base inv_y = Base(1) / y;
 
 	// number of indices to access
 	size_t j = d + 1;
 	while(j)
 	{	--j;
-		px[j] += pz[j] / y;
+		px[j] += azmul(pz[j], inv_y);
 	}
 }
 
