@@ -1,12 +1,12 @@
-/* $Id: drivers.hpp 2506 2012-10-24 19:36:49Z bradbell $ */
-# ifndef CPPAD_DRIVERS_INCLUDED
-# define CPPAD_DRIVERS_INCLUDED
+// $Id: drivers.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_DRIVERS_HPP
+# define CPPAD_DRIVERS_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-08 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -18,12 +18,9 @@ $begin Drivers$$
 $spell
 $$
 
-$index forward, easy driver$$
-$index reverse, easy driver$$
-$index easy, driver$$
-$index driver, easy$$
 
 $section First and Second Derivatives: Easy Drivers$$
+$mindex forward reverse$$
 
 
 $childtable%
@@ -47,5 +44,5 @@ $end
 # include <cppad/local/rev_two.hpp>
 # include <cppad/local/sparse_jacobian.hpp>
 # include <cppad/local/sparse_hessian.hpp>
- 
+
 # endif
