@@ -1,12 +1,12 @@
-/* $Id: fun_eval.hpp 3174 2014-03-10 01:26:06Z bradbell $ */
-# ifndef CPPAD_FUN_EVAL_INCLUDED
-# define CPPAD_FUN_EVAL_INCLUDED
+// $Id: fun_eval.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_FUN_EVAL_HPP
+# define CPPAD_FUN_EVAL_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -18,8 +18,6 @@ $begin FunEval$$
 $spell
 $$
 
-$index evaluate, ADFun$$
-$index ADFun, evaluate$$
 
 $section Evaluate ADFun Functions, Derivatives, and Sparsity Patterns$$
 
