@@ -1,12 +1,12 @@
-/* $Id: identical.hpp 3232 2014-04-27 15:38:21Z bradbell $ */
-# ifndef CPPAD_IDENTICAL_INCLUDED
-# define CPPAD_IDENTICAL_INCLUDED
+// $Id: identical.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_IDENTICAL_HPP
+# define CPPAD_IDENTICAL_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -23,7 +23,7 @@ Check if certain properties is true for any possible AD tape play back.
 
 // ---------------------------------------------------------------------------
 /*!
-Determine if an AD<Base> object is a parameter, and could never have 
+Determine if an AD<Base> object is a parameter, and could never have
 a different value during any tape playback.
 
 An AD<Base> object \c x is identically a parameter if and only if
@@ -78,7 +78,7 @@ bool IdenticalOne(const AD<Base> &x)
 {	return Parameter(x) && IdenticalOne(x.value_); }
 // Equal ===================================================================
 /*!
-Determine if two AD<Base> objects are equal, 
+Determine if two AD<Base> objects are equal,
 and must be equal during any tape playback.
 
 \param x
@@ -97,7 +97,7 @@ bool IdenticalEqualPar
 (const AD<Base> &x, const AD<Base> &y)
 {	bool parameter;
 	parameter = ( Parameter(x) & Parameter(y) );
-	return parameter  && IdenticalEqualPar(x.value_, y.value_); 
+	return parameter  && IdenticalEqualPar(x.value_, y.value_);
 }
 // ==========================================================================
 
