@@ -1,12 +1,12 @@
-/* $Id: mul_op.hpp 3321 2014-09-12 09:50:39Z bradbell $ */
-# ifndef CPPAD_MUL_OP_INCLUDED
-# define CPPAD_MUL_OP_INCLUDED
+// $Id: mul_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_MUL_OP_HPP
+# define CPPAD_MUL_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -36,8 +36,8 @@ and the argument \a parameter is not used.
 
 template <class Base>
 inline void forward_mulvv_op(
-	size_t        p           , 
-	size_t        q           , 
+	size_t        p           ,
+	size_t        q           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -78,8 +78,8 @@ and the argument \a parameter is not used.
 
 template <class Base>
 inline void forward_mulvv_op_dir(
-	size_t        q           , 
-	size_t        r           , 
+	size_t        q           ,
+	size_t        r           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -101,7 +101,7 @@ inline void forward_mulvv_op_dir(
 	size_t k, ell, m;
 	for(ell = 0; ell < r; ell++)
 	{	m = (q-1)*r + ell + 1;
-		z[m] = x[0] * y[m] + x[m] * y[0]; 
+		z[m] = x[0] * y[m] + x[m] * y[0];
 		for(k = 1; k < q; k++)
 			z[m] += x[(q-k-1)*r + ell + 1] * y[(k-1)*r + ell + 1];
 	}
@@ -157,7 +157,7 @@ and the argument \a parameter is not used.
 
 template <class Base>
 inline void reverse_mulvv_op(
-	size_t        d           , 
+	size_t        d           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -188,9 +188,9 @@ inline void reverse_mulvv_op(
 	while(j)
 	{	--j;
 		for(k = 0; k <= j; k++)
-		{	
-			px[j-k] += pz[j] * y[k];
-			py[k]   += pz[j] * x[j-k];
+		{
+			px[j-k] += azmul(pz[j], y[k]);
+			py[k]   += azmul(pz[j], x[j-k]);
 		}
 	}
 }
@@ -210,8 +210,8 @@ this operations is for the case where x is a parameter and y is a variable.
 
 template <class Base>
 inline void forward_mulpv_op(
-	size_t        p           , 
-	size_t        q           , 
+	size_t        p           ,
+	size_t        q           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -249,8 +249,8 @@ this operations is for the case where x is a parameter and y is a variable.
 
 template <class Base>
 inline void forward_mulpv_op_dir(
-	size_t        q           , 
-	size_t        r           , 
+	size_t        q           ,
+	size_t        r           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -325,7 +325,7 @@ this operations is for the case where x is a parameter and y is a variable.
 
 template <class Base>
 inline void reverse_mulpv_op(
-	size_t        d           , 
+	size_t        d           ,
 	size_t        i_z         ,
 	const addr_t* arg         ,
 	const Base*   parameter   ,
@@ -335,8 +335,8 @@ inline void reverse_mulpv_op(
 	Base*         partial     )
 {
 	// check assumptions
-	CPPAD_ASSERT_UNKNOWN( NumArg(MulvvOp) == 2 );
-	CPPAD_ASSERT_UNKNOWN( NumRes(MulvvOp) == 1 );
+	CPPAD_ASSERT_UNKNOWN( NumArg(MulpvOp) == 2 );
+	CPPAD_ASSERT_UNKNOWN( NumRes(MulpvOp) == 1 );
 	CPPAD_ASSERT_UNKNOWN( d < cap_order );
 	CPPAD_ASSERT_UNKNOWN( d < nc_partial );
 
@@ -351,7 +351,7 @@ inline void reverse_mulpv_op(
 	size_t j = d + 1;
 	while(j)
 	{	--j;
-		py[j] += pz[j] * x;
+		py[j] += azmul(pz[j], x);
 	}
 }
 
