@@ -1,12 +1,12 @@
-/* $Id: num_skip.hpp 3132 2014-03-01 16:55:48Z bradbell $ */
-# ifndef CPPAD_NUM_SKIP_INCLUDED
-# define CPPAD_NUM_SKIP_INCLUDED
+// $Id: num_skip.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_NUM_SKIP_HPP
+# define CPPAD_NUM_SKIP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -21,12 +21,9 @@ $spell
 	taylor_
 $$
 
-$index number_skip$$
-$index number, skip variables$$
-$index skip, number variables$$
-$index variables, skip$$
 
 $section Number of Variables that Can be Skipped$$
+$mindex number_skip$$
 
 $head Syntax$$
 $icode%n% = %f%.number_skip()%$$
@@ -39,13 +36,13 @@ The $cref/conditional expressions/CondExp/$$ use either the
 $cref/if_true/CondExp/$$ or $cref/if_false/CondExp/$$.
 This leads to the fact that some terms only need to be evaluated
 depending on the value of the comparison in the conditional expression.
-The $cref optimize$$ option is capable of detecting some of these 
+The $cref optimize$$ option is capable of detecting some of these
 case and determining variables that can be skipped.
 This routine returns the number such variables.
 
 $head n$$
 The return value $icode n$$ has type $code size_t$$
-is the number of variables that the optimizer has determined can be skipped 
+is the number of variables that the optimizer has determined can be skipped
 (given the independent variable values specified by the previous call to
 $cref/f.Forward/Forward/$$ for order zero).
 
@@ -101,6 +98,6 @@ size_t ADFun<Base>::number_skip(void)
 }
 
 } // END CppAD namespace
-	
+
 
 # endif
