@@ -1,12 +1,12 @@
-/* $Id: op.hpp 3495 2014-12-24 01:16:15Z bradbell $ */
-# ifndef CPPAD_OP_INCLUDED
-# define CPPAD_OP_INCLUDED
+// $Id: op.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_OP_HPP
+# define CPPAD_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -17,12 +17,15 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cppad/local/sparse_pattern.hpp>
 
 // operations
-# include <cppad/local/std_math_ad.hpp>
+# include <cppad/local/std_math_98.hpp>
 # include <cppad/local/abs_op.hpp>
 # include <cppad/local/add_op.hpp>
 # include <cppad/local/acos_op.hpp>
+# include <cppad/local/acosh_op.hpp>
 # include <cppad/local/asin_op.hpp>
+# include <cppad/local/asinh_op.hpp>
 # include <cppad/local/atan_op.hpp>
+# include <cppad/local/atanh_op.hpp>
 # include <cppad/local/comp_op.hpp>
 # include <cppad/local/cond_op.hpp>
 # include <cppad/local/cos_op.hpp>
@@ -33,8 +36,10 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cppad/local/div_op.hpp>
 # include <cppad/local/erf_op.hpp>
 # include <cppad/local/exp_op.hpp>
+# include <cppad/local/expm1_op.hpp>
 # include <cppad/local/load_op.hpp>
 # include <cppad/local/log_op.hpp>
+# include <cppad/local/log1p_op.hpp>
 # include <cppad/local/mul_op.hpp>
 # include <cppad/local/parameter_op.hpp>
 # include <cppad/local/pow_op.hpp>
@@ -49,6 +54,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cppad/local/store_op.hpp>
 # include <cppad/local/tan_op.hpp>
 # include <cppad/local/tanh_op.hpp>
+# include <cppad/local/zmul_op.hpp>
 
 
 # endif
