@@ -1,12 +1,12 @@
-/* $Id: opt_val_hes.hpp 3232 2014-04-27 15:38:21Z bradbell $ */
-# ifndef CPPAD_OPT_VAL_HES_INCLUDED
-# define CPPAD_OPT_VAL_HES_INCLUDED
+// $Id: opt_val_hes.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_OPT_VAL_HES_HPP
+# define CPPAD_OPT_VAL_HES_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -27,16 +27,12 @@ $spell
 $$
 
 
-$index Jacobian$$
-$index Hessian$$
-$index optimal value$$
-$index value$$
-$index opt_val_hes$$
 
 $section Jacobian and Hessian of Optimal Values$$
+$mindex opt_val_hes$$
 
 $head Syntax$$
-$icode%signdet% = opt_val_hes(%x%, %y%, %fun%, %jac%, %hes%)%$$  
+$icode%signdet% = opt_val_hes(%x%, %y%, %fun%, %jac%, %hes%)%$$
 
 $head See Also$$
 $cref BenderQuad$$
@@ -47,26 +43,26 @@ Bradley M. Bell and James V. Burke, Advances in Automatic Differentiation,
 2008, Springer.
 
 $head Purpose$$
-We are given a function 
+We are given a function
 $latex S : \B{R}^n \times \B{R}^m \rightarrow \B{R}^\ell$$
 and we define $latex F : \B{R}^n \times \B{R}^m \rightarrow \B{R}$$
 and $latex V : \B{R}^n \rightarrow \B{R} $$ by
 $latex \[
 \begin{array}{rcl}
-	F(x, y) & = & \sum_{k=0}^{\ell-1} S_k ( x , y) 
+	F(x, y) & = & \sum_{k=0}^{\ell-1} S_k ( x , y)
 	\\
-	V(x)    & = & F [ x , Y(x) ] 
+	V(x)    & = & F [ x , Y(x) ]
 	\\
 	0       & = & \partial_y F [x , Y(x) ]
 \end{array}
 \] $$
-We wish to compute the Jacobian 
+We wish to compute the Jacobian
 and possibly also the Hessian, of $latex V (x)$$.
 
 $head BaseVector$$
-The type $icode BaseVector$$ must be a 
-$cref SimpleVector$$ class. 
-We use $icode Base$$ to refer to the type of the elements of 
+The type $icode BaseVector$$ must be a
+$cref SimpleVector$$ class.
+We use $icode Base$$ to refer to the type of the elements of
 $icode BaseVector$$; i.e.,
 $codei%
 	%BaseVector%::value_type
@@ -78,7 +74,7 @@ $codei%
 	const %BaseVector%& %x%
 %$$
 and its size must be equal to $icode n$$.
-It specifies the point at which we evaluating 
+It specifies the point at which we evaluating
 the Jacobian $latex V^{(1)} (x)$$
 (and possibly the Hessian $latex V^{(2)} (x)$$).
 
@@ -89,14 +85,14 @@ $codei%
 	const %BaseVector%& %y%
 %$$
 and its size must be equal to $icode m$$.
-It must be equal to $latex Y(x)$$; i.e., 
+It must be equal to $latex Y(x)$$; i.e.,
 it must solve the implicit equation
 $latex \[
-	0 = \partial_y F ( x , y) 
+	0 = \partial_y F ( x , y)
 \] $$
 
 $head Fun$$
-The argument $icode fun$$ is an object of type $icode Fun$$ 
+The argument $icode fun$$ is an object of type $icode Fun$$
 which must support the member functions listed below.
 CppAD will may be recording operations of the type $codei%AD<%Base%>%$$
 when these member functions are called.
@@ -104,7 +100,7 @@ These member functions must not stop such a recording; e.g.,
 they must not call $cref/AD<Base>::abort_recording/abort_recording/$$.
 
 $subhead Fun::ad_vector$$
-The type $icode%Fun%::ad_vector%$$ must be a 
+The type $icode%Fun%::ad_vector%$$ must be a
 $cref SimpleVector$$ class with elements of type $codei%AD<%Base%>%$$; i.e.
 $codei%
 	%Fun%::ad_vector::value_type
@@ -125,9 +121,9 @@ the number of terms in the summation.
 $pre
 
 $$
-One can choose $icode ell$$ equal to one, and have 
+One can choose $icode ell$$ equal to one, and have
 $latex S(x,y)$$ the same as $latex F(x, y)$$.
-Each of the functions $latex S_k (x , y)$$, 
+Each of the functions $latex S_k (x , y)$$,
 (in the summation defining $latex F(x, y)$$)
 is differentiated separately using AD.
 For very large problems, breaking $latex F(x, y)$$ into the sum
@@ -195,7 +191,7 @@ and has size $icode n$$ or zero.
 The input values of its elements do not matter.
 If it has size zero, it is not affected. Otherwise, on output
 it contains the Jacobian of $latex V (x)$$; i.e.,
-for $latex j = 0 , \ldots , n-1$$, 
+for $latex j = 0 , \ldots , n-1$$,
 $latex \[
 	jac[ j ] = V^{(1)} (x)_j
 \] $$
@@ -211,7 +207,7 @@ The input values of its elements do not matter.
 If it has size zero, it is not affected. Otherwise, on output
 it contains the Hessian of $latex V (x)$$; i.e.,
 for $latex i = 0 , \ldots , n-1$$, and
-$latex j = 0 , \ldots , n-1$$, 
+$latex j = 0 , \ldots , n-1$$,
 $latex \[
 	hes[ i * n + j ] = V^{(2)} (x)_{i,j}
 \] $$
@@ -222,7 +218,7 @@ If $icode%hes%$$ has size zero, $icode signdet$$ is not defined.
 Otherwise
 the return value $icode signdet$$ is the sign of the determinant for
 $latex \partial_{yy}^2 F(x , y) $$.
-If it is zero, then the matrix is singular and 
+If it is zero, then the matrix is singular and
 the Hessian is not computed ($icode hes$$ is not changed).
 
 $head Example$$
@@ -231,7 +227,7 @@ $children%
 %$$
 The file
 $cref opt_val_hes.cpp$$
-contains an example and test of this operation.   
+contains an example and test of this operation.
 It returns true if it succeeds and false otherwise.
 
 $end
@@ -247,41 +243,41 @@ namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 /*!
 Computing Jabobians and Hessians of Optimal Values
 
-We are given a function 
+We are given a function
 \f$ S : {\rm R}^n \times {\rm R}^m \rightarrow {\rm R}^\ell \f$
-and we define \f$ F : {\rm R}^n \times {\rm R}^m \rightarrow {\rm R} \f$ 
+and we define \f$ F : {\rm R}^n \times {\rm R}^m \rightarrow {\rm R} \f$
 and \f$ V : {\rm R}^n \rightarrow {\rm R}  \f$ by
 \f[
 \begin{array}{rcl}
-	F(x, y) & = & \sum_{k=0}^{\ell-1} S_k ( x , y) 
+	F(x, y) & = & \sum_{k=0}^{\ell-1} S_k ( x , y)
 	\\
-	V(x)    & = & F [ x , Y(x) ] 
+	V(x)    & = & F [ x , Y(x) ]
 	\\
 	0       & = & \partial_y F [x , Y(x) ]
 \end{array}
 \f]
-We wish to compute the Jacobian 
+We wish to compute the Jacobian
 and possibly also the Hessian, of \f$ V (x) \f$.
 
 \tparam BaseVector
-The type \c BaseVector must be a SimpleVector class. 
-We use \c Base to refer to the type of the elements of 
+The type \c BaseVector must be a SimpleVector class.
+We use \c Base to refer to the type of the elements of
 \c BaseVector; i.e.,
 <tt>BaseVector::value_type</tt>.
 
 \param x
 is a vector with size \c n.
-It specifies the point at which we evaluating 
+It specifies the point at which we evaluating
 the Jacobian \f$ V^{(1)} (x) \f$
 (and possibly the Hessian \f$ V^{(2)} (x) \f$).
 
 
 \param y
 is a vector with size \c m.
-It must be equal to \f$ Y(x) \f$; i.e., 
+It must be equal to \f$ Y(x) \f$; i.e.,
 it must solve the implicit equation
 \f[
-	0 = \partial_y F ( x , y) 
+	0 = \partial_y F ( x , y)
 \f]
 
 \param fun
@@ -293,7 +289,7 @@ These member functions must not stop such a recording; e.g.,
 they must not call \c AD<Base>::abort_recording.
 
 \par Fun::ad_vector</tt>
-The type <tt>Fun::ad_vector</tt> must be a 
+The type <tt>Fun::ad_vector</tt> must be a
 SimpleVector class with elements of type  \c AD<Base>; i.e.
 <tt>Fun::ad_vector::value_type</tt>
 is equal to  \c AD<Base>.
@@ -338,7 +334,7 @@ is a vector with size \c n or zero.
 The input values of its elements do not matter.
 If it has size zero, it is not affected. Otherwise, on output
 it contains the Jacobian of \f$ V (x) \f$; i.e.,
-for \f$ j = 0 , \ldots , n-1 \f$, 
+for \f$ j = 0 , \ldots , n-1 \f$,
 \f[
 	jac[ j ] = V^{(1)} (x)_j
 \f] $$
@@ -350,7 +346,7 @@ The input values of its elements do not matter.
 If it has size zero, it is not affected. Otherwise, on output
 it contains the Hessian of \f$ V (x) \f$; i.e.,
 for \f$ i = 0 , \ldots , n-1 \f$, and
-\f$ j = 0 , \ldots , n-1 \f$, 
+\f$ j = 0 , \ldots , n-1 \f$,
 \f[
 	hes[ i * n + j ] = V^{(2)} (x)_{i,j}
 \f]
@@ -367,9 +363,9 @@ to its specified value.
 
 template <class BaseVector, class Fun>
 int opt_val_hes(
-	const BaseVector&   x     , 
-	const BaseVector&   y     , 
-	Fun                 fun   , 
+	const BaseVector&   x     ,
+	const BaseVector&   y     ,
+	Fun                 fun   ,
 	BaseVector&         jac   ,
 	BaseVector&         hes   )
 {	// determine the base type
@@ -410,14 +406,14 @@ int opt_val_hes(
 	// ADFun version of S_k(x, y)
 	ADFun<Base> S_k;
 
-	// AD version of x 
+	// AD version of x
 	ad_vector a_x(n);
 
 	// AD version of y
 	ad_vector a_y(n);
 
 	if( jac.size() > 0  )
-	{	// this is the easy part, computing the V^{(1)} (x) which is equal 
+	{	// this is the easy part, computing the V^{(1)} (x) which is equal
 		// to \partial_x F (x, y) (see Thoerem 2 of the reference).
 
 		// copy x and y to AD version
@@ -442,7 +438,7 @@ int opt_val_hes(
 			BaseVector jac_k = S_k.Jacobian(x);
 			// add \partial_x S_k (x, y) to jac
 			for(j = 0; j < n; j++)
-				jac[j] += jac_k[j];			 
+				jac[j] += jac_k[j];
 		}
 	}
 	// check if we are done
@@ -454,22 +450,22 @@ int opt_val_hes(
 	reference:
 		Y^{(1)}(x) = - F_yy (x, y)^{-1} F_yx (x, y)
 	Using Theorem 2 of the reference:
-		V^{(2)}(x) = F_xx (x, y) + F_xy (x, y)  Y^{(1)}(x) 
+		V^{(2)}(x) = F_xx (x, y) + F_xy (x, y)  Y^{(1)}(x)
 	*/
 	// Base and AD version of xy
 	BaseVector xy(n + m);
 	ad_vector a_xy(n + m);
 	for(j = 0; j < n; j++)
-		a_xy[j] = xy[j] = x[j]; 
+		a_xy[j] = xy[j] = x[j];
 	for(j = 0; j < m; j++)
-		a_xy[n+j] = xy[n+j] = y[j]; 
+		a_xy[n+j] = xy[n+j] = y[j];
 
 	// Initialization summation for Hessian of F
 	size_t nm_sq = (n + m) * (n + m);
 	BaseVector F_hes(nm_sq);
 	for(j = 0; j < nm_sq; j++)
 		F_hes[j] = Base(0.);
-	BaseVector hes_k(nm_sq); 
+	BaseVector hes_k(nm_sq);
 
 	// add in Hessian of S_k to hes
 	for(k = 0; k < ell; k++)
@@ -487,24 +483,24 @@ int opt_val_hes(
 		S_k.Dependent(a_xy, s_k);
 		// when computing the Hessian it pays to optimize the tape
 		S_k.optimize();
-		// compute Hessian of S_k 
+		// compute Hessian of S_k
 		hes_k = S_k.Hessian(xy, 0);
 		// add \partial_x S_k (x, y) to jac
 		for(j = 0; j < nm_sq; j++)
-			F_hes[j] += hes_k[j];			 
+			F_hes[j] += hes_k[j];
 	}
 	// Extract F_yx
 	BaseVector F_yx(m * n);
 	for(i = 0; i < m; i++)
 	{	for(j = 0; j < n; j++)
 			F_yx[i * n + j] = F_hes[ (i+n)*(n+m) + j ];
-	} 
+	}
 	// Extract F_yy
 	BaseVector F_yy(n * m);
 	for(i = 0; i < m; i++)
 	{	for(j = 0; j < m; j++)
 			F_yy[i * m + j] = F_hes[ (i+n)*(n+m) + j + n ];
-	} 
+	}
 
 	// compute - Y^{(1)}(x) = F_yy (x, y)^{-1} F_yx (x, y)
 	BaseVector neg_Y_x(m * n);
@@ -513,7 +509,7 @@ int opt_val_hes(
 	if( signdet == 0 )
 		return signdet;
 
-	// compute hes = F_xx (x, y) + F_xy (x, y)  Y^{(1)}(x) 
+	// compute hes = F_xx (x, y) + F_xy (x, y)  Y^{(1)}(x)
 	for(i = 0; i < n; i++)
 	{	for(j = 0; j < n; j++)
 		{	hes[i * n + j] = F_hes[ i*(n+m) + j ];
