@@ -1,11 +1,11 @@
-/* $Id: parallel_ad.hpp 3619 2015-01-28 14:11:13Z bradbell $ */
-# ifndef CPPAD_PARALLEL_AD_INCLUDED
-# define CPPAD_PARALLEL_AD_INCLUDED
+// $Id: parallel_ad.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_PARALLEL_AD_HPP
+# define CPPAD_PARALLEL_AD_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -29,18 +29,18 @@ The function
 $codei%parallel_ad<%Base%>()%$$
 must be called before any $codei%AD<%Base>%$$ objects are used
 in $cref/parallel/ta_in_parallel/$$ mode.
-In addition, if this routine is called after one is done using 
-parallel mode, it will free extra memory used to keep track of 
+In addition, if this routine is called after one is done using
+parallel mode, it will free extra memory used to keep track of
 the multiple $codei%AD<%Base%>%$$ tapes required for parallel execution.
 
 $head Discussion$$
-By default, for each $codei%AD<%Base%>%$$ class there is only one 
+By default, for each $codei%AD<%Base%>%$$ class there is only one
 tape that records $cref/AD of Base/glossary/AD of Base/$$ operations.
 This tape is a global variable and hence it cannot be used
-by multiple threads at the same time. 
+by multiple threads at the same time.
 The $cref/parallel_setup/ta_parallel_setup/$$ function informs CppAD of the
 maximum number of threads that can be active in parallel mode.
-This routine does extra setup 
+This routine does extra setup
 (and teardown) for the particular $icode Base$$ type.
 
 $head CheckSimpleVector$$
@@ -51,11 +51,11 @@ $codei%
 where $icode Type$$ is $icode Base$$ and $codei%AD<%Base%>%$$.
 
 $head Example$$
-The files 
-$cref team_openmp.cpp$$, 
+The files
+$cref team_openmp.cpp$$,
 $cref team_bthread.cpp$$, and
-$cref team_pthread.cpp$$, 
-contain examples and tests that implement this function.   
+$cref team_pthread.cpp$$,
+contain examples and tests that implement this function.
 
 $head Restriction$$
 This routine cannot be called in parallel mode or while
@@ -71,13 +71,13 @@ $end
 namespace CppAD {
 
 /*!
-Enable parallel execution mode with <code>AD<Base></code> by initializing 
+Enable parallel execution mode with <code>AD<Base></code> by initializing
 static variables that my be used.
 */
 
 template <class Base>
 void parallel_ad(void)
-{	CPPAD_ASSERT_KNOWN( 
+{	CPPAD_ASSERT_KNOWN(
 		! thread_alloc::in_parallel() ,
 		"parallel_ad must be called before entering parallel execution mode."
 	);
@@ -105,7 +105,7 @@ void parallel_ad(void)
 
 	// statics that depend on the value of Base
 	AD<Base>::tape_id_handle(0);
-	AD<Base>::tape_handle(0);	
+	AD<Base>::tape_handle(0);
 	AD<Base>::tape_manage(tape_manage_clear);
 	discrete<Base>::List();
 	CheckSimpleVector< Base, CppAD::vector<Base> >();
