@@ -1,12 +1,12 @@
-/* $Id: parameter_op.hpp 3301 2014-05-24 05:20:21Z bradbell $ */
-# ifndef CPPAD_PARAMETER_OP_INCLUDED
-# define CPPAD_PARAMETER_OP_INCLUDED
+// $Id: parameter_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_PARAMETER_OP_HPP
+# define CPPAD_PARAMETER_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -33,13 +33,13 @@ where some of the components of the vector y are parameters.
 
 \tparam Base
 base type for the operator; i.e., this operation was recorded
-using AD< \a Base > and computations by this routine are done using type 
+using AD< \a Base > and computations by this routine are done using type
 \a Base .
 
 \param i_z
-variable index corresponding to the result for this operation; 
+variable index corresponding to the result for this operation;
 i.e. the row index in \a taylor corresponding to the component of y
-that is a parameter. 
+that is a parameter.
 
 \param arg
 \a arg[0]
@@ -51,19 +51,19 @@ is the number of parameters in \a parameter.
 
 \param parameter
 \b Input: \a parameter[ \a arg[0] ] is the value of a component
-of y that is a parameter. 
+of y that is a parameter.
 
 \param cap_order
 number of colums in the matrix containing all the Taylor coefficients.
 
 \param taylor
-\b Output: \a taylor [ \a i_z * \a cap_order + 0 ] 
-is the zero order Taylor coefficient corresponding to z. 
+\b Output: \a taylor [ \a i_z * \a cap_order + 0 ]
+is the zero order Taylor coefficient corresponding to z.
 
 \par Checked Assertions where op is the unary operator with one result:
 \li NumArg(op) == 1
 \li NumRes(op) == 1
-\li \a size_t(arg[0]) < num_par 
+\li \a size_t(arg[0]) < num_par
 \li \a 0 < \a cap_order
 */
 template <class Base>
@@ -72,9 +72,9 @@ inline void forward_par_op_0(
 	const addr_t* arg         ,
 	size_t        num_par     ,
 	const Base*   parameter   ,
-	size_t        cap_order   , 
+	size_t        cap_order   ,
 	Base*         taylor      )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(ParOp) == 1 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(ParOp) == 1 );
