@@ -1,12 +1,12 @@
-/* $Id: rev_sparse_hes.hpp 3441 2014-12-03 14:46:44Z bradbell $ */
-# ifndef CPPAD_REV_SPARSE_HES_INCLUDED
-# define CPPAD_REV_SPARSE_HES_INCLUDED
+// $Id: rev_sparse_hes.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_REV_SPARSE_HES_HPP
+# define CPPAD_REV_SPARSE_HES_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -27,14 +27,10 @@ $spell
 	Dep
 	proportional
 	var
+	cpp
 $$
 
-$section Hessian Sparsity Pattern: Reverse Mode$$ 
-
-$index RevSparseHes$$
-$index reverse, sparse Hessian$$
-$index sparse, reverse Hessian$$
-$index pattern, reverse Hessian$$
+$section Hessian Sparsity Pattern: Reverse Mode$$
 
 $head Syntax$$
 $icode%h% = %f%.RevSparseHes(%q%, %s%)
@@ -45,22 +41,22 @@ $icode%h% = %f%.RevSparseHes(%q%, %s%, %transpose%)%$$
 $head Purpose$$
 We use $latex F : \B{R}^n \rightarrow \B{R}^m$$ to denote the
 $cref/AD function/glossary/AD Function/$$ corresponding to $icode f$$.
-For a fixed matrix $latex R \in \B{R}^{n \times q}$$ 
+For a fixed matrix $latex R \in \B{R}^{n \times q}$$
 and a fixed vector $latex S \in \B{R}^{1 \times m}$$,
-we define 
+we define
 $latex \[
 \begin{array}{rcl}
-H(x) 
+H(x)
 & = & \partial_x \left[ \partial_u S * F[ x + R * u ] \right]_{u=0}
 \\
 & = & R^\R{T} * (S * F)^{(2)} ( x )
 \\
-H(x)^\R{T} 
+H(x)^\R{T}
 & = & (S * F)^{(2)} ( x ) * R
 \end{array}
 \] $$
 Given a
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for the matrix $latex R$$ and the vector $latex S$$,
 $code RevSparseHes$$ returns a sparsity pattern for the $latex H(x)$$.
 
@@ -82,7 +78,7 @@ $codei%
 %$$
 It specifies the number of columns in $latex R \in \B{R}^{n \times q}$$
 and the number of rows in $latex H(x) \in \B{R}^{q \times n}$$.
-It must be the same value as in the previous $cref ForSparseJac$$ call 
+It must be the same value as in the previous $cref ForSparseJac$$ call
 $codei%
 	%f%.ForSparseJac(%q%, %r%, %r_transpose%)
 %$$
@@ -104,7 +100,7 @@ $codei%
 %$$
 see $cref/r/ForSparseJac/r/$$.
 The type of the elements of
-$cref/VectorSet/RevSparseHes/VectorSet/$$ must be the 
+$cref/VectorSet/RevSparseHes/VectorSet/$$ must be the
 same as the type of the elements of $icode r$$.
 
 $head s$$
@@ -118,8 +114,8 @@ its size is $latex m$$.
 If it has elements of type $code std::set<size_t>$$,
 its size is one and all the elements of $icode%s%[0]%$$
 are between zero and $latex m - 1$$.
-It specifies a 
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+It specifies a
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for the vector $icode S$$.
 
 $head h$$
@@ -135,8 +131,8 @@ its size is $latex q * n$$.
 If it has elements of type $code std::set<size_t>$$,
 its size is $latex q$$ and all the set elements are between
 zero and $icode%n%-1%$$ inclusive.
-It specifies a 
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+It specifies a
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for the matrix $latex H(x)$$.
 
 $subhead transpose true$$
@@ -145,8 +141,8 @@ its size is $latex n * q$$.
 If it has elements of type $code std::set<size_t>$$,
 its size is $latex n$$ and all the set elements are between
 zero and $icode%q%-1%$$ inclusive.
-It specifies a 
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+It specifies a
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for the matrix $latex H(x)^\R{T}$$.
 
 $head VectorSet$$
@@ -156,7 +152,7 @@ $code bool$$ or $code std::set<size_t>$$;
 see $cref/sparsity pattern/glossary/Sparsity Pattern/$$ for a discussion
 of the difference.
 The type of the elements of
-$cref/VectorSet/RevSparseHes/VectorSet/$$ must be the 
+$cref/VectorSet/RevSparseHes/VectorSet/$$ must be the
 same as the type of the elements of $icode r$$.
 
 $head Entire Sparsity Pattern$$
@@ -166,24 +162,29 @@ Further suppose that the $latex S$$ is the $th k$$
 $cref/elementary vector/glossary/Elementary Vector/$$; i.e.
 $latex \[
 S_j = \left\{ \begin{array}{ll}
-	1  & {\rm if} \; j = k 
+	1  & {\rm if} \; j = k
 	\\
 	0  & {\rm otherwise}
-\end{array} \right. 
+\end{array} \right.
 \] $$
 In this case,
-the corresponding value $icode h$$ is a 
+the corresponding value $icode h$$ is a
 sparsity pattern for the Hessian matrix
 $latex F_k^{(2)} (x) \in \B{R}^{n \times n}$$.
 
 $head Example$$
 $children%
 	example/rev_sparse_hes.cpp
+	%example/sparsity_sub.cpp
 %$$
 The file
 $cref rev_sparse_hes.cpp$$
 contains an example and test of this operation.
 It returns true if it succeeds and false otherwise.
+The file
+$cref/sparsity_sub.cpp/sparsity_sub.cpp/RevSparseHes/$$
+contains an example and test of using $code RevSparseHes$$
+to compute the sparsity pattern for a subset of the Hessian.
 
 $end
 -----------------------------------------------------------------------------
@@ -198,6 +199,8 @@ namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 Reverse mode Hessian sparsity patterns.
 */
 
+// ===========================================================================
+// RevSparseHesBool
 /*!
 Calculate Hessian sparsity patterns using reverse mode.
 
@@ -222,8 +225,8 @@ where \f$ F \f$ is the function corresponding to the operation sequence
 and \a x is any argument value.
 
 \param q
-is the value of \a q in the 
-by the previous call of the form 
+is the value of \a q in the
+by the previous call of the form
 \verbatim
 	f.ForSparseJac(q, r)
 \endverbatim
@@ -233,7 +236,7 @@ The value \c r in this call is a sparsity pattern for the matrix \f$ R \f$.
 is a vector with size \c m that specifies the sparsity pattern
 for the vector \f$ S \f$,
 where \c m is the number of dependent variables
-corresponding to the operation sequence stored in \a play. 
+corresponding to the operation sequence stored in \a play.
 
 \param h
 the input value of \a h must be a vector with size \c q*n.
@@ -253,13 +256,13 @@ maps independent variable index
 to the corresponding variable in the tape.
 
 \param play
-is the recording that defines the function we are computing the sparsity 
+is the recording that defines the function we are computing the sparsity
 pattern for.
 
 \param for_jac_sparsity
-is a vector of sets containing the 
-the forward Jacobian sparsity pattern corresponding to 
-$latex R$$ for all of the variables on the tape. 
+is a vector of sets containing the
+the forward Jacobian sparsity pattern corresponding to
+$latex R$$ for all of the variables on the tape.
 */
 
 template <class Base, class VectorSet>
@@ -298,7 +301,7 @@ void RevSparseHesBool(
 	// Array that will hold reverse Jacobian dependency flag.
 	// Initialize as true for the dependent variables.
 	pod_vector<bool> RevJac;
-	RevJac.extend(num_var);	
+	RevJac.extend(num_var);
 	for(i = 0; i < num_var; i++)
 		RevJac[i] = false;
 	for(i = 0; i < m; i++)
@@ -315,7 +318,7 @@ void RevSparseHesBool(
 		n,
 		num_var,
 		&play,
-		for_jac_sparsity, 
+		for_jac_sparsity,
 		RevJac.data(),
 		rev_hes_sparsity
 	);
@@ -323,7 +326,7 @@ void RevSparseHesBool(
 	// return values corresponding to independent variables
 	CPPAD_ASSERT_UNKNOWN( size_t(h.size()) == n * q );
 	for(j = 0; j < n; j++)
-	{	for(i = 0; i < q; i++) 
+	{	for(i = 0; i < q; i++)
 		{	if( transpose )
 				h[ j * q + i ] = false;
 			else	h[ i * n + j ] = false;
@@ -353,6 +356,8 @@ void RevSparseHesBool(
 	return;
 }
 
+// ===========================================================================
+// RevSparseHesSet
 /*!
 Calculate Hessian sparsity patterns using reverse mode.
 
@@ -377,8 +382,8 @@ where \f$ F \f$ is the function corresponding to the operation sequence
 and \a x is any argument value.
 
 \param q
-is the value of \a q in the 
-by the previous call of the form 
+is the value of \a q in the
+by the previous call of the form
 \verbatim
 	f.ForSparseJac(q, r)
 \endverbatim
@@ -388,7 +393,7 @@ The value \c r in this call is a sparsity pattern for the matrix \f$ R \f$.
 is a vector with size \c m that specifies the sparsity pattern
 for the vector \f$ S \f$,
 where \c m is the number of dependent variables
-corresponding to the operation sequence stored in \a play. 
+corresponding to the operation sequence stored in \a play.
 
 \param h
 If \c transpose, the input value of \a h must be a vector with size \a q.
@@ -409,13 +414,13 @@ maps independent variable index
 to the corresponding variable in the tape.
 
 \param play
-is the recording that defines the function we are computing the sparsity 
+is the recording that defines the function we are computing the sparsity
 pattern for.
 
 \param for_jac_sparsity
-is a vector of sets containing the 
-the forward Jacobian sparsity pattern corresponding to 
-$latex R$$ for all of the variables on the tape. 
+is a vector of sets containing the
+the forward Jacobian sparsity pattern corresponding to
+$latex R$$ for all of the variables on the tape.
 */
 
 template <class Base, class VectorSet>
@@ -458,7 +463,7 @@ void RevSparseHesSet(
 	// Array that will hold reverse Jacobian dependency flag.
 	// Initialize as true for the dependent variables.
 	pod_vector<bool> RevJac;
-	RevJac.extend(num_var);	
+	RevJac.extend(num_var);
 	for(i = 0; i < num_var; i++)
 		RevJac[i] = false;
 	itr = s[0].begin();
@@ -483,7 +488,7 @@ void RevSparseHesSet(
 		n,
 		num_var,
 		&play,
-		for_jac_sparsity, 
+		for_jac_sparsity,
 		RevJac.data(),
 		rev_hes_sparsity
 	);
@@ -513,7 +518,8 @@ void RevSparseHesSet(
 	return;
 }
 
-
+// ===========================================================================
+// RevSparseHes
 
 /*!
 User API for Hessian sparsity patterns using reverse mode.
@@ -540,8 +546,8 @@ where \f$ F \f$ is the function corresponding to the operation sequence
 and \a x is any argument value.
 
 \param q
-is the value of \a q in the 
-by the previous call of the form 
+is the value of \a q in the
+by the previous call of the form
 \verbatim
 	f.ForSparseJac(q, r, packed)
 \endverbatim
@@ -553,10 +559,10 @@ must be the same as the type of the elements of \c s.
 is a vector with size \c m that specifies the sparsity pattern
 for the vector \f$ S \f$,
 where \c m is the number of dependent variables
-corresponding to the operation sequence stored in \a play. 
+corresponding to the operation sequence stored in \a play.
 
 \return
-If \c transpose is false (true), 
+If \c transpose is false (true),
 the return vector is a sparsity pattern for \f$ H(x) \f$ (\f$ H(x)^T \f$).
 \f[
 	H(x) = R^T ( S * F)^{(2)} (x)
@@ -585,7 +591,8 @@ VectorSet ADFun<Base>::RevSparseHes(
 
 	return h;
 }
-
+// ===========================================================================
+// RevSparseHesCase
 /*!
 Private helper function for RevSparseHes(q, s).
 
@@ -612,23 +619,23 @@ template <class Base>
 template <class VectorSet>
 void ADFun<Base>::RevSparseHesCase(
 	bool              set_type         ,
-	bool              transpose        ,  
-	size_t            q                ,  
+	bool              transpose        ,
+	size_t            q                ,
 	const VectorSet&  s                ,
 	VectorSet&        h                )
-{	size_t n = Domain(); 	
+{	size_t n = Domain();
 	h.resize(q * n );
 
-	CPPAD_ASSERT_KNOWN( 
+	CPPAD_ASSERT_KNOWN(
 		for_jac_sparse_pack_.n_set() > 0,
 		"RevSparseHes: previous stored call to ForSparseJac did not "
 		"use bool for the elements of r."
 	);
 	CPPAD_ASSERT_UNKNOWN( for_jac_sparse_set_.n_set() == 0 );
 	CPPAD_ASSERT_UNKNOWN( for_jac_sparse_pack_.n_set() == num_var_tape_  );
-	
+
 	// use sparse_pack for the calculation
-	CppAD::RevSparseHesBool( 
+	CppAD::RevSparseHesBool(
 		transpose                ,
 		q                        ,
 		s                        ,
@@ -637,10 +644,9 @@ void ADFun<Base>::RevSparseHesCase(
 		dep_taddr_               ,
 		ind_taddr_               ,
 		play_                    ,
-		for_jac_sparse_pack_ 
+		for_jac_sparse_pack_
 	);
 }
-
 /*!
 Private helper function for RevSparseHes(q, s).
 
@@ -648,7 +654,7 @@ All of the description in the public member function RevSparseHes(q, s)
 applies.
 
 \param set_type
-is a \c std::set<size_t> value. 
+is a \c std::set<size_t> value.
 This argument is used to dispatch to the proper source
 code depending on the vlaue of \c VectorSet::value_type.
 
@@ -668,8 +674,8 @@ template <class Base>
 template <class VectorSet>
 void ADFun<Base>::RevSparseHesCase(
 	const std::set<size_t>&   set_type         ,
-	bool                      transpose        ,  
-	size_t                    q                ,  
+	bool                      transpose        ,
+	size_t                    q                ,
 	const VectorSet&          s                ,
 	VectorSet&                h                )
 {	size_t n = Domain();
@@ -677,16 +683,16 @@ void ADFun<Base>::RevSparseHesCase(
 		h.resize(n);
 	else	h.resize(q);
 
-	CPPAD_ASSERT_KNOWN( 
+	CPPAD_ASSERT_KNOWN(
 		for_jac_sparse_set_.n_set() > 0,
 		"RevSparseHes: previous stored call to ForSparseJac did not "
 		"use std::set<size_t> for the elements of r."
 	);
 	CPPAD_ASSERT_UNKNOWN( for_jac_sparse_pack_.n_set() == 0 );
 	CPPAD_ASSERT_UNKNOWN( for_jac_sparse_set_.n_set() == num_var_tape_  );
-	
+
 	// use sparse_pack for the calculation
-	CppAD::RevSparseHesSet( 
+	CppAD::RevSparseHesSet(
 		transpose                ,
 		q                        ,
 		s                        ,
@@ -695,9 +701,114 @@ void ADFun<Base>::RevSparseHesCase(
 		dep_taddr_               ,
 		ind_taddr_               ,
 		play_                    ,
-		for_jac_sparse_set_ 
+		for_jac_sparse_set_
 	);
 }
+// ===========================================================================
+// RevSparseHesCheckpoint
+/*!
+Hessian sparsity patterns calculation used by checkpoint functions.
+
+\tparam Base
+is the base type for this recording.
+
+\param transpose
+is true (false) h is equal to \f$ H(x) \f$ (\f$ H(x)^T \f$)
+where
+\f[
+	H(x) = R^T (S * F)^{(2)} (x)
+\f]
+where \f$ F \f$ is the function corresponding to the operation sequence
+and \f$ x \f$ is any argument value.
+
+\param q
+is the value of q in the by the previous call of the form
+\verbatim
+	f.ForSparseJac(q, r)
+\endverbatim
+The value r in this call is a sparsity pattern for the matrix \f$ R \f$.
+
+\param s
+is a vector with size m that specifies the sparsity pattern
+for the vector \f$ S \f$,
+where m is the number of dependent variables
+corresponding to the operation sequence stored in play_.
+
+\param h
+The input size and elements of h do not matter.
+On output, h is the sparsity pattern for the matrix \f$ H(x) \f$
+or \f$ H(x)^T \f$ depending on transpose.
+
+\par Assumptions
+The forward jacobian sparsity pattern must be currently stored
+in this ADFUN object.
+*/
+template <class Base>
+void ADFun<Base>::RevSparseHesCheckpoint(
+	size_t                        q         ,
+	vector<bool>&                 s         ,
+	bool                          transpose ,
+	CPPAD_INTERNAL_SPARSE_SET&    h         )
+{	size_t n = Domain();
+	size_t m = Range();
+
+	// checkpoint functions should get this right
+	CPPAD_ASSERT_UNKNOWN( for_jac_sparse_pack_.n_set() == 0 );
+	CPPAD_ASSERT_UNKNOWN( for_jac_sparse_set_.n_set() == num_var_tape_ );
+	CPPAD_ASSERT_UNKNOWN( for_jac_sparse_set_.end()   == q );
+	CPPAD_ASSERT_UNKNOWN( s.size()                    == m );
+
+	// Array that holds the reverse Jacobiain dependcy flags.
+	// Initialize as true for dependent variables, flase for others.
+	pod_vector<bool> RevJac;
+	RevJac.extend(num_var_tape_);
+	for(size_t i = 0; i < num_var_tape_; i++)
+		RevJac[i] = false;
+	for(size_t i = 0; i < m; i++)
+	{	CPPAD_ASSERT_UNKNOWN( dep_taddr_[i] < num_var_tape_ )
+		RevJac[ dep_taddr_[i] ] = s[i];
+	}
+
+	// holds reverse Hessian sparsity pattern for all variables
+	CPPAD_INTERNAL_SPARSE_SET rev_hes_sparsity;
+	rev_hes_sparsity.resize(num_var_tape_, q);
+
+	// compute Hessian sparsity pattern for all variables
+	RevHesSweep(
+		n,
+		num_var_tape_,
+		&play_,
+		for_jac_sparse_set_,
+		RevJac.data(),
+		rev_hes_sparsity
+	);
+
+	// dimension the return value
+	if( transpose )
+		h.resize(n, q);
+	else
+		h.resize(q, n);
+
+	// j is index corresponding to reverse mode partial
+	for(size_t j = 0; j < n; j++)
+	{	CPPAD_ASSERT_UNKNOWN( ind_taddr_[j] < num_var_tape_ );
+
+		// ind_taddr_[j] is operator taddr for j-th independent variable
+		CPPAD_ASSERT_UNKNOWN( ind_taddr_[j] == j + 1 );
+		CPPAD_ASSERT_UNKNOWN( play_.GetOp( ind_taddr_[j] ) == InvOp );
+
+		// extract the result from rev_hes_sparsity
+		CPPAD_ASSERT_UNKNOWN( rev_hes_sparsity.end() == q );
+		rev_hes_sparsity.begin(j + 1);
+		size_t i = rev_hes_sparsity.next_element();
+		while( i < q )
+		{	if( transpose )
+				h.add_element(j,  i);
+			else	h.add_element(i, j);
+			i = rev_hes_sparsity.next_element();
+		}
+	}
+}
 
 } // END_CPPAD_NAMESPACE
 # endif
