@@ -1,12 +1,12 @@
-/* $Id: rev_sparse_jac.hpp 3232 2014-04-27 15:38:21Z bradbell $ */
-# ifndef CPPAD_REV_SPARSE_JAC_INCLUDED
-# define CPPAD_REV_SPARSE_JAC_INCLUDED
+// $Id: rev_sparse_jac.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_REV_SPARSE_JAC_HPP
+# define CPPAD_REV_SPARSE_JAC_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -30,17 +30,14 @@ $spell
 	proportional
 $$
 
-$section Jacobian Sparsity Pattern: Reverse Mode$$ 
+$section Jacobian Sparsity Pattern: Reverse Mode$$
+$mindex RevSparseJac sparse$$
 
-$index RevSparseJac$$
-$index reverse, sparse Jacobian$$
-$index sparse, reverse Jacobian$$
-$index pattern, reverse Jacobian$$
 
 $head Syntax$$
 $icode%s% = %f%.RevSparseJac(%q%, %r%)
 %$$
-$icode%s% = %f%.RevSparseJac(%q%, %r%, %transpose%)%$$
+$icode%s% = %f%.RevSparseJac(%q%, %r%, %transpose%, %dependency%)%$$
 
 $head Purpose$$
 We use $latex F : B^n \rightarrow B^m$$ to denote the
@@ -52,7 +49,7 @@ $latex \[
 	S(x) = R * F^{(1)} ( x )
 \] $$
 Given a
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for $latex R$$,
 $code RevSparseJac$$ returns a sparsity pattern for the $latex S(x)$$.
 
@@ -63,7 +60,7 @@ $codei%
 %$$
 
 $head x$$
-the sparsity pattern is valid for all values of the independent 
+the sparsity pattern is valid for all values of the independent
 variables in $latex x \in B^n$$
 (even if it has $cref CondExp$$ or $cref VecAD$$ operations).
 
@@ -73,8 +70,8 @@ $codei%
 	size_t %q%
 %$$
 It specifies the number of rows in
-$latex R \in B^{q \times m}$$ and the 
-Jacobian $latex S(x) \in B^{q \times n}$$. 
+$latex R \in B^{q \times m}$$ and the
+Jacobian $latex S(x) \in B^{q \times n}$$.
 
 $head transpose$$
 The argument $icode transpose$$ has prototype
@@ -83,22 +80,14 @@ $codei%
 %$$
 The default value $code false$$ is used when $icode transpose$$ is not present.
 
-$head nz_compare$$
-The argument $icode nz_compare$$ has prototype
+$head dependency$$
+The argument $icode dependency$$ has prototype
 $codei%
-	bool %nz_compare%
+	bool %dependency%
 %$$
-If $icode nz_compare$$ is true,
-the derivatives with respect to left and right of the 
-$cref CondExp$$ below are considered to be non-zero:
-$codei%
-	%CondExp%Rel%(%left%, %right%, %if_true%, %if_false%)
-%$$
-This is used by the 
-$cref/optimizer/optimize/$$ with $cref checkpoint$$ functions
-to obtain the correct dependency relations.
-The default value $icode%nz_compare% = false%$$ is used when 
-$icode nz_compare$$ is not present.
+If $icode dependency$$ is true,
+the $cref/dependency pattern/dependency.cpp/Dependency Pattern/$$
+(instead of sparsity pattern) is computed.
 
 $head r$$
 The argument $icode s$$ has prototype
@@ -113,8 +102,8 @@ its size is $latex q * m$$.
 If it has elements of type $code std::set<size_t>$$,
 its size is $icode q$$ and all its set elements are between
 zero and $latex m - 1$$.
-It specifies a 
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+It specifies a
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for the matrix $latex R \in B^{q \times m}$$.
 
 $subhead transpose true$$
@@ -123,8 +112,8 @@ its size is $latex m * q$$.
 If it has elements of type $code std::set<size_t>$$,
 its size is $icode m$$ and all its set elements are between
 zero and $latex q - 1$$.
-It specifies a 
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+It specifies a
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for the matrix $latex R^\R{T} \in B^{m \times q}$$.
 
 $head s$$
@@ -140,8 +129,8 @@ its size is $latex q * n$$.
 If it has elements of type $code std::set<size_t>$$,
 its size is $icode q$$ and all its set elements are between
 zero and $latex n - 1$$.
-It specifies a 
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+It specifies a
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for the matrix $latex S(x) \in {q \times n}$$.
 
 $subhead transpose true$$
@@ -150,8 +139,8 @@ its size is $latex n * q$$.
 If it has elements of type $code std::set<size_t>$$,
 its size is $icode n$$ and all its set elements are between
 zero and $latex q - 1$$.
-It specifies a 
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+It specifies a
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for the matrix $latex S(x)^\R{T} \in {n \times q}$$.
 
 $head VectorSet$$
@@ -164,8 +153,8 @@ of the difference.
 $head Entire Sparsity Pattern$$
 Suppose that $latex q = m$$ and
 $latex R$$ is the $latex m \times m$$ identity matrix.
-In this case, 
-the corresponding value for $icode s$$ is a 
+In this case,
+the corresponding value for $icode s$$ is a
 sparsity pattern for the Jacobian $latex S(x) = F^{(1)} ( x )$$.
 
 $head Example$$
@@ -189,7 +178,8 @@ namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 Reverse mode Jacobian sparsity patterns.
 */
 
-// -------------------------------------------------------------------------
+// =========================================================================
+// RevSparseJacBool
 /*!
 Calculate Jacobian vector of bools sparsity patterns using reverse mode.
 
@@ -207,7 +197,7 @@ is a simple vector class with elements of type \c bool.
 \param transpose
 are the sparsity patterns transposed.
 
-\param nz_compare
+\param dependency
 Are the derivatives with respect to left and right of the expression below
 considered to be non-zero:
 \code
@@ -224,7 +214,7 @@ is a sparsity pattern for the matrix \f$ R \f$.
 \param s
 the input value of \a s must be a vector with size <tt>p*n</tt>
 where \c n is the number of independent variables
-corresponding to the operation sequence stored in \a play. 
+corresponding to the operation sequence stored in \a play.
 The input value of the components of \c s does not matter.
 On output, \a s is the sparsity pattern for the matrix
 \f[
@@ -245,15 +235,15 @@ maps independent variable index
 to the corresponding variable in the tape.
 
 \param play
-is the recording that defines the function we are computing the sparsity 
+is the recording that defines the function we are computing the sparsity
 pattern for.
 */
 
-template <class Base, class VectorSet> 
+template <class Base, class VectorSet>
 void RevSparseJacBool(
 	bool                   transpose        ,
-	bool                   nz_compare       ,
-	size_t                 q                , 
+	bool                   dependency       ,
+	size_t                 q                ,
 	const VectorSet&       r                ,
 	VectorSet&             s                ,
 	size_t                 total_num_var    ,
@@ -289,18 +279,18 @@ void RevSparseJacBool(
 	for(i = 0; i < m; i++)
 	{	CPPAD_ASSERT_UNKNOWN( dep_taddr[i] < total_num_var );
 		if( transpose )
-		{	for(j = 0; j < q; j++) if( r[ j * m + i ] )
+		{	for(j = 0; j < q; j++) if( r[ i * q + j ] )
 				var_sparsity.add_element( dep_taddr[i], j );
 		}
 		else
-		{	for(j = 0; j < q; j++) if( r[ i * q + j ] )
+		{	for(j = 0; j < q; j++) if( r[ j * m + i ] )
 				var_sparsity.add_element( dep_taddr[i], j );
 		}
 	}
 
 	// evaluate the sparsity patterns
 	RevJacSweep(
-		nz_compare,
+		dependency,
 		n,
 		total_num_var,
 		&play,
@@ -321,7 +311,7 @@ void RevSparseJacBool(
 				s[ j * q + i ] = false;
 		}
 		else
-		{	for(i = 0; i < q; i++) 
+		{	for(i = 0; i < q; i++)
 				s[ i * n + j ] = false;
 		}
 		CPPAD_ASSERT_UNKNOWN( var_sparsity.end() == q );
@@ -335,6 +325,8 @@ void RevSparseJacBool(
 		}
 	}
 }
+// =========================================================================
+// RevSparseJacSet
 /*!
 Calculate Jacobian vector of sets sparsity patterns using reverse mode.
 
@@ -352,7 +344,7 @@ is a simple vector class with elements of type \c std::set<size_t>.
 \param transpose
 see \c RevSparseJacBool.
 
-\param nz_compare
+\param dependency
 see \c RevSparseJacBool.
 
 \param q
@@ -376,11 +368,11 @@ see \c RevSparseJacBool.
 \param play
 see \c RevSparseJacBool.
 */
-template <class Base, class VectorSet> 
+template <class Base, class VectorSet>
 void RevSparseJacSet(
 	bool                   transpose        ,
-	bool                   nz_compare       ,
-	size_t                 q                , 
+	bool                   dependency       ,
+	size_t                 q                ,
 	const VectorSet&       r                ,
 	VectorSet&             s                ,
 	size_t                 total_num_var    ,
@@ -423,7 +415,7 @@ void RevSparseJacSet(
 	{	for(i = 0; i < m; i++)
 		{	itr = r[i].begin();
 			while(itr != r[i].end())
-			{	j = *itr++; 
+			{	j = *itr++;
 				CPPAD_ASSERT_KNOWN(
 				j < q,
 				"RevSparseJac: transpose is true and element of the set\n"
@@ -438,7 +430,7 @@ void RevSparseJacSet(
 	{	for(i = 0; i < q; i++)
 		{	itr = r[i].begin();
 			while(itr != r[i].end())
-			{	j = *itr++; 
+			{	j = *itr++;
 				CPPAD_ASSERT_KNOWN(
 				j < m,
 				"RevSparseJac: transpose is false and element of the set\n"
@@ -451,7 +443,7 @@ void RevSparseJacSet(
 	}
 	// evaluate the sparsity patterns
 	RevJacSweep(
-		nz_compare,
+		dependency,
 		n,
 		total_num_var,
 		&play,
@@ -478,12 +470,13 @@ void RevSparseJacSet(
 		}
 	}
 }
-// --------------------------------------------------------------------------
+// =========================================================================
+// RevSparseJacCase
 
 /*!
 Private helper function for \c RevSparseJac(q, r, transpose).
 
-All of the description in the public member function 
+All of the description in the public member function
 \c RevSparseJac(q, r, transpose) apply.
 
 \param set_type
@@ -492,19 +485,19 @@ This argument is used to dispatch to the proper source code
 depending on the value of \c VectorSet::value_type.
 
 \param transpose
-See \c RevSparseJac(q, r, transpose, nz_compare)
+See \c RevSparseJac(q, r, transpose, dependency)
 
-\param nz_compare
-See \c RevSparseJac(q, r, transpose, nz_compare)
+\param dependency
+See \c RevSparseJac(q, r, transpose, dependency)
 
 \param q
-See \c RevSparseJac(q, r, transpose, nz_compare)
+See \c RevSparseJac(q, r, transpose, dependency)
 
 \param r
-See \c RevSparseJac(q, r, transpose, nz_compare)
+See \c RevSparseJac(q, r, transpose, dependency)
 
 \param s
-is the return value for the corresponding call to 
+is the return value for the corresponding call to
 RevSparseJac(q, r, transpose).
 */
 
@@ -513,7 +506,7 @@ template <class VectorSet>
 void ADFun<Base>::RevSparseJacCase(
 	bool                set_type          ,
 	bool                transpose         ,
-	bool                nz_compare        ,
+	bool                dependency        ,
 	size_t              q                 ,
 	const VectorSet&    r                 ,
 	VectorSet&          s                 )
@@ -525,7 +518,7 @@ void ADFun<Base>::RevSparseJacCase(
 	// store results in s
 	RevSparseJacBool(
 		transpose      ,
-		nz_compare     ,
+		dependency     ,
 		q              ,
 		r              ,
 		s              ,
@@ -539,7 +532,7 @@ void ADFun<Base>::RevSparseJacCase(
 /*!
 Private helper function for \c RevSparseJac(q, r, transpose).
 
-All of the description in the public member function 
+All of the description in the public member function
 \c RevSparseJac(q, r, transpose) apply.
 
 \param set_type
@@ -548,16 +541,16 @@ This argument is used to dispatch to the proper source code
 depending on the value of \c VectorSet::value_type.
 
 \param transpose
-See \c RevSparseJac(q, r, transpose, nz_compare)
+See \c RevSparseJac(q, r, transpose, dependency)
 
-\param nz_compare
-See \c RevSparseJac(q, r, transpose, nz_compare)
+\param dependency
+See \c RevSparseJac(q, r, transpose, dependency)
 
 \param q
-See \c RevSparseJac(q, r, transpose, nz_compare)
+See \c RevSparseJac(q, r, transpose, dependency)
 
 \param r
-See \c RevSparseJac(q, r, transpose, nz_compare)
+See \c RevSparseJac(q, r, transpose, dependency)
 
 \param s
 is the return value for the corresponding call to RevSparseJac(q, r, transpose)
@@ -568,7 +561,7 @@ template <class VectorSet>
 void ADFun<Base>::RevSparseJacCase(
 	const std::set<size_t>&      set_type          ,
 	bool                         transpose         ,
-	bool                         nz_compare        ,
+	bool                         dependency        ,
 	size_t                       q                 ,
 	const VectorSet&             r                 ,
 	VectorSet&                   s                 )
@@ -580,7 +573,7 @@ void ADFun<Base>::RevSparseJacCase(
 	// store results in r
 	RevSparseJacSet(
 		transpose      ,
-		nz_compare     ,
+		dependency     ,
 		q              ,
 		r              ,
 		s              ,
@@ -590,13 +583,14 @@ void ADFun<Base>::RevSparseJacCase(
 		play_
 	);
 }
-// --------------------------------------------------------------------------
+// =========================================================================
+// RevSparseJac
 /*!
 User API for Jacobian sparsity patterns using reverse mode.
 
 The C++ source code corresponding to this operation is
 \verbatim
-	s = f.RevSparseJac(q, r, transpose, nz_compare)
+	s = f.RevSparseJac(q, r, transpose, dependency)
 \endverbatim
 
 \tparam Base
@@ -615,7 +609,7 @@ is a sparsity pattern for the matrix \f$ R \f$.
 \param transpose
 are the sparsity patterns for \f$ R \f$ and \f$ S(x) \f$ transposed.
 
-\param nz_compare
+\param dependency
 Are the derivatives with respect to left and right of the expression below
 considered to be non-zero:
 \code
@@ -641,10 +635,10 @@ and with all its elements between zero and \f$ n - 1 \f$ (\f$ q - 1 \f$).
 template <class Base>
 template <class VectorSet>
 VectorSet ADFun<Base>::RevSparseJac(
-	size_t              q          , 
+	size_t              q          ,
 	const VectorSet&    r          ,
 	bool                transpose  ,
-	bool                nz_compare )
+	bool                dependency )
 {
 	VectorSet s;
 	typedef typename VectorSet::value_type Set_type;
@@ -652,13 +646,138 @@ VectorSet ADFun<Base>::RevSparseJac(
 	RevSparseJacCase(
 		Set_type()    ,
 		transpose     ,
-		nz_compare    ,
+		dependency    ,
 		q             ,
 		r             ,
 		s
 	);
 	return s;
 }
+// ===========================================================================
+// RevSparseJacCheckpoint
+/*!
+Reverse mode Jacobian sparsity calculation used by checkpoint functions.
+
+\tparam Base
+is the base type for this recording.
+
+\param transpose
+is true (false) s is equal to \f$ S(x) \f$ (\f$ S(x)^T \f$)
+where
+\f[
+	S(x) = R * F^{(1)} (x)
+\f]
+where \f$ F \f$ is the function corresponding to the operation sequence
+and \f$ x \f$ is any argument value.
+
+\param q
+is the number of rows in the matrix \f$ R \f$.
+
+\param r
+is a sparsity pattern for the matrix \f$ R \f$.
+
+\param transpose
+are the sparsity patterns for \f$ R \f$ and \f$ S(x) \f$ transposed.
+
+\param dependency
+Are the derivatives with respect to left and right of the expression below
+considered to be non-zero:
+\code
+	CondExpRel(left, right, if_true, if_false)
+\endcode
+This is used by the optimizer to obtain the correct dependency relations.
+
+\param s
+The input size and elements of s do not matter.
+On output, s is the sparsity pattern for the matrix \f$ S(x) \f$
+or \f$ S(x)^T \f$ depending on transpose.
+
+*/
+template <class Base>
+void ADFun<Base>::RevSparseJacCheckpoint(
+	size_t                        q          ,
+	CPPAD_INTERNAL_SPARSE_SET&    r          ,
+	bool                          transpose  ,
+	bool                          dependency ,
+	CPPAD_INTERNAL_SPARSE_SET&    s          )
+{	size_t n = Domain();
+	size_t m = Range();
+
+# ifndef NDEBUG
+	if( transpose )
+	{	CPPAD_ASSERT_UNKNOWN( r.n_set() == m );
+		CPPAD_ASSERT_UNKNOWN( r.end()   == q );
+	}
+	else
+	{	CPPAD_ASSERT_UNKNOWN( r.n_set() == q );
+		CPPAD_ASSERT_UNKNOWN( r.end()   == m );
+	}
+	for(size_t i = 0; i < m; i++)
+		CPPAD_ASSERT_UNKNOWN( dep_taddr_[i] < num_var_tape_ );
+# endif
+
+	// holds reverse Jacobian sparsity pattern for all variables
+	CPPAD_INTERNAL_SPARSE_SET var_sparsity;
+	var_sparsity.resize(num_var_tape_, q);
+
+	// set sparsity pattern for dependent variables
+	if( transpose )
+	{	for(size_t i = 0; i < m; i++)
+		{	r.begin(i);
+			size_t j = r.next_element();
+			while( j < q )
+			{	var_sparsity.add_element( dep_taddr_[i], j );
+				j = r.next_element();
+			}
+		}
+	}
+	else
+	{	for(size_t j = 0; j < q; j++)
+		{	r.begin(j);
+			size_t i = r.next_element();
+			while( i < m )
+			{	var_sparsity.add_element( dep_taddr_[i], j );
+				i = r.next_element();
+			}
+		}
+	}
+
+	// evaluate the sparsity pattern for all variables
+	RevJacSweep(
+		dependency,
+		n,
+		num_var_tape_,
+		&play_,
+		var_sparsity
+	);
+
+	// dimension the return value
+	if( transpose )
+		s.resize(n, m);
+	else
+		s.resize(m, n);
+
+	// return values corresponding to independent variables
+	for(size_t j = 0; j < n; j++)
+	{	CPPAD_ASSERT_UNKNOWN( ind_taddr_[j] == (j+1) );
+
+		// ind_taddr_[j] is operator taddr for j-th independent variable
+		CPPAD_ASSERT_UNKNOWN( play_.GetOp( ind_taddr_[j] ) == InvOp );
+
+		// extract the result from var_sparsity
+		CPPAD_ASSERT_UNKNOWN( var_sparsity.end() == q );
+		var_sparsity.begin(j+1);
+		size_t i = var_sparsity.next_element();
+		while( i < q )
+		{	if( transpose )
+				s.add_element(j, i);
+			else
+				s.add_element(i, j);
+			i  = var_sparsity.next_element();
+		}
+	}
+
+}
 
 } // END_CPPAD_NAMESPACE
 # endif
