@@ -1,12 +1,12 @@
-/* $Id: reverse_sweep.hpp 3495 2014-12-24 01:16:15Z bradbell $ */
-# ifndef CPPAD_REVERSE_SWEEP_INCLUDED
-# define CPPAD_REVERSE_SWEEP_INCLUDED
+// $Id: reverse_sweep.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_REVERSE_SWEEP_HPP
+# define CPPAD_REVERSE_SWEEP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -31,7 +31,7 @@ otherwise, it respolves to
 \code
 	user_ok = user_atom->reverse
 \endcode
-This maco is undefined at the end of this file to facillitate is 
+This maco is undefined at the end of this file to facillitate is
 use with a different definition in other files.
 */
 # ifdef NDEBUG
@@ -42,7 +42,7 @@ use with a different definition in other files.
 
 /*!
 \def CPPAD_REVERSE_SWEEP_TRACE
-This value is either zero or one. 
+This value is either zero or one.
 Zero is the normal operational value.
 If it is one, a trace of every reverse_sweep computation is printed.
 */
@@ -53,11 +53,11 @@ Compute derivative of arbitrary order forward mode Taylor coefficients.
 
 \tparam Base
 base type for the operator; i.e., this operation sequence was recorded
-using AD< \a Base > and computations by this routine are done using type 
+using AD< \a Base > and computations by this routine are done using type
 \a Base.
 
 \param d
-is the highest order Taylor coefficients that 
+is the highest order Taylor coefficients that
 we are computing the derivative of.
 
 \param n
@@ -81,27 +81,27 @@ of the form
 <code>
 	f.Forward(k, x_k)
 </code>
-We define 
+We define
 \f$ X : {\bf R}^{n \times d} \rightarrow {\bf R}^n \f$ by
 \f[
 	X(t, u) =  u^{(0)} + u^{(1)} t + \cdots + u^{(d)} t^d
 \f]
-We define 
+We define
 \f$ Y : {\bf R}^{n \times d} \rightarrow {\bf R}^m \f$ by
 \f[
 	Y(t, u) =  F[ X(t, u) ]
 \f]
-We define the function 
+We define the function
 \f$ W : {\bf R}^{n \times d} \rightarrow {\bf R} \f$ by
 \f[
-W(u) 
-= 
-\sum_{k=0}^{d} ( w^{(k)} )^{\rm T} 
+W(u)
+=
+\sum_{k=0}^{d} ( w^{(k)} )^{\rm T}
 	\frac{1}{k !} \frac{\partial^k}{\partial t^k} Y(0, u)
 \f]
 (The matrix \f$ w \in {\bf R}^m \f$,
 is defined below under the heading Partial.)
-Note that the scale factor  1 / k  converts 
+Note that the scale factor  1 / k  converts
 the k-th partial derivative to the k-th order Taylor coefficient.
 This routine computes the derivative of \f$ W(u) \f$
 with respect to all the Taylor coefficients
@@ -112,7 +112,7 @@ The object \a play is effectly constant.
 There is an exception to this,
 while palying back the tape
 the object \a play holds information about the current location
-with in the tape and this changes during palyback. 
+with in the tape and this changes during palyback.
 
 \param J
 Is the number of columns in the coefficient matrix \a Taylor.
@@ -121,7 +121,7 @@ This must be greater than or equal \a d + 1.
 \param Taylor
 For i = 1 , ... , \a numvar, and for k = 0 , ... , \a d,
 \a Taylor [ i * J + k ]
-is the k-th order Taylor coefficient corresponding to 
+is the k-th order Taylor coefficient corresponding to
 variable with index i on the tape.
 The value \f$ u \in {\bf R}^{n \times d} \f$,
 at which the derivative is computed,
@@ -137,22 +137,22 @@ It must be greater than or equal \a d + 1.
 \b Input:
 The last \f$ m \f$ rows of \a Partial are inputs.
 The matrix \f$ w \f$, used to define \f$ W(u) \f$,
-is specified by these rows. 
-For i = 0 , ... , m - 1, 
+is specified by these rows.
+For i = 0 , ... , m - 1,
 for k = 0 , ... , d,
 <code>Partial [ (numvar - m + i ) * K + k ] = w[i,k]</code>.
 \n
 \n
 \b Temporary:
-For i = n+1 , ... , \a numvar - 1 and for k = 0 , ... , d, 
+For i = n+1 , ... , \a numvar - 1 and for k = 0 , ... , d,
 the value of \a Partial [ i * K + k ] is used for temporary work space
-and its output value is not defined. 
+and its output value is not defined.
 \n
 \n
 \b Output:
-For j = 1 , ... , n and for k = 0 , ... , d, 
-\a Partial [ j * K + k ] 
-is the partial derivative of \f$ W( u ) \f$ with 
+For j = 1 , ... , n and for k = 0 , ... , d,
+\a Partial [ j * K + k ]
+is the partial derivative of \f$ W( u ) \f$ with
 respect to \f$ u_j^{(k)} \f$.
 
 \param cskip_op
@@ -169,7 +169,7 @@ the instruction corresponds to a parameter (not variable).
 
 \par Assumptions
 The first operator on the tape is a BeginOp,
-and the next \a n operators are InvOp operations for the 
+and the next \a n operators are InvOp operations for the
 corresponding independent variables.
 */
 template <class Base>
@@ -253,7 +253,7 @@ void ReverseSweep(
 			CPPAD_ASSERT_UNKNOWN( op != CSkipOp );
 			// if( op == CSkipOp )
 			// {	// CSkip has a variable number of arguments
-			// 	play->reverse_cskip(op, arg, i_op, i_var);
+			//	play->reverse_cskip(op, arg, i_op, i_var);
 			// }
 			CPPAD_ASSERT_UNKNOWN( i_op < play->num_op_rec() );
 			play->reverse_next(op, arg, i_op, i_var);
@@ -273,19 +273,19 @@ void ReverseSweep(
 		const Base*  Z_tmp  = Taylor + i_var * J;
 		const Base*  pZ_tmp = Partial + i_var * K;
 		printOp(
-			std::cout, 
+			std::cout,
 			play,
 			i_op,
 			i_tmp,
-			op, 
+			op,
 			arg
 		);
 		if( NumRes(op) > 0 && op != BeginOp ) printOpResult(
-			std::cout, 
-			d + 1, 
-			Z_tmp, 
-			d + 1, 
-			pZ_tmp 
+			std::cout,
+			d + 1,
+			Z_tmp,
+			d + 1,
+			pZ_tmp
 		);
 		std::cout << std::endl;
 # endif
@@ -299,6 +299,26 @@ void ReverseSweep(
 			break;
 			// --------------------------------------------------
 
+			case AcosOp:
+			// sqrt(1 - x * x), acos(x)
+			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
+			reverse_acos_op(
+				d, i_var, arg[0], J, Taylor, K, Partial
+			);
+			break;
+			// --------------------------------------------------
+
+# if CPPAD_USE_CPLUSPLUS_2011
+			case AcoshOp:
+			// sqrt(x * x - 1), acosh(x)
+			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
+			reverse_acosh_op(
+				d, i_var, arg[0], J, Taylor, K, Partial
+			);
+			break;
+# endif
+			// --------------------------------------------------
+
 			case AddvvOp:
 			reverse_addvv_op(
 				d, i_var, arg, parameter, J, Taylor, K, Partial
@@ -314,17 +334,8 @@ void ReverseSweep(
 			break;
 			// --------------------------------------------------
 
-			case AcosOp:
-                        // sqrt(1 - x * x), acos(x)
-			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
-			reverse_acos_op(
-				d, i_var, arg[0], J, Taylor, K, Partial
-			);
-			break;
-			// --------------------------------------------------
-
 			case AsinOp:
-                        // sqrt(1 - x * x), asin(x)
+			// sqrt(1 - x * x), asin(x)
 			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
 			reverse_asin_op(
 				d, i_var, arg[0], J, Taylor, K, Partial
@@ -332,8 +343,19 @@ void ReverseSweep(
 			break;
 			// --------------------------------------------------
 
+# if CPPAD_USE_CPLUSPLUS_2011
+			case AsinhOp:
+			// sqrt(1 + x * x), asinh(x)
+			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
+			reverse_asinh_op(
+				d, i_var, arg[0], J, Taylor, K, Partial
+			);
+			break;
+# endif
+			// --------------------------------------------------
+
 			case AtanOp:
-                        // 1 + x * x, atan(x)
+			// 1 + x * x, atan(x)
 			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
 			reverse_atan_op(
 				d, i_var, arg[0], J, Taylor, K, Partial
@@ -341,6 +363,17 @@ void ReverseSweep(
 			break;
 			// -------------------------------------------------
 
+# if CPPAD_USE_CPLUSPLUS_2011
+			case AtanhOp:
+			// 1 - x * x, atanh(x)
+			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
+			reverse_atanh_op(
+				d, i_var, arg[0], J, Taylor, K, Partial
+			);
+			break;
+# endif
+			// -------------------------------------------------
+
 			case BeginOp:
 			CPPAD_ASSERT_NARG_NRES(op, 1, 1);
 			more_operators = false;
@@ -373,23 +406,19 @@ void ReverseSweep(
 
 			case CExpOp:
 			reverse_cond_op(
-				d, 
-				i_var, 
-				arg, 
-				num_par, 
-				parameter, 
-				J, 
+				d,
+				i_var,
+				arg,
+				num_par,
+				parameter,
+				J,
 				Taylor,
-				K, 
+				K,
 				Partial
 			);
 			break;
 			// --------------------------------------------------
 
-			case ComOp:
-			break;
-			// --------------------------------------------------
-
 			case CosOp:
 			CPPAD_ASSERT_UNKNOWN( i_var < numvar );
 			reverse_cos_op(
@@ -408,7 +437,7 @@ void ReverseSweep(
 
 			case DisOp:
 			// Derivative of discrete operation is zero so no
-			// contribution passes through this operation. 
+			// contribution passes through this operation.
 			break;
 			// --------------------------------------------------
 
@@ -435,7 +464,7 @@ void ReverseSweep(
 			break;
 			// --------------------------------------------------
 
-# if CPPAD_COMPILER_HAS_ERF
+# if CPPAD_USE_CPLUSPLUS_2011
 			case ErfOp:
 			reverse_erf_op(
 				d, i_var, arg, parameter, J, Taylor, K, Partial
@@ -450,24 +479,47 @@ void ReverseSweep(
 			);
 			break;
 			// --------------------------------------------------
+
+# if CPPAD_USE_CPLUSPLUS_2011
+			case Expm1Op:
+			reverse_expm1_op(
+				d, i_var, arg[0], J, Taylor, K, Partial
+			);
+			break;
+# endif
+			// --------------------------------------------------
+
+			case InvOp:
+			break;
+			// --------------------------------------------------
+
 			case LdpOp:
 			reverse_load_op(
-		op, d, i_var, arg, J, Taylor, K, Partial, var_by_load_op.data()
+			op, d, i_var, arg, J, Taylor, K, Partial, var_by_load_op.data()
 			);
 			break;
 			// -------------------------------------------------
 
 			case LdvOp:
 			reverse_load_op(
-		op, d, i_var, arg, J, Taylor, K, Partial, var_by_load_op.data()
+			op, d, i_var, arg, J, Taylor, K, Partial, var_by_load_op.data()
 			);
 			break;
-			// -------------------------------------------------
-
-			case InvOp:
-			break;
 			// --------------------------------------------------
 
+			case EqpvOp:
+			case EqvvOp:
+			case LtpvOp:
+			case LtvpOp:
+			case LtvvOp:
+			case LepvOp:
+			case LevpOp:
+			case LevvOp:
+			case NepvOp:
+			case NevvOp:
+			break;
+			// -------------------------------------------------
+
 			case LogOp:
 			reverse_log_op(
 				d, i_var, arg[0], J, Taylor, K, Partial
@@ -475,11 +527,13 @@ void ReverseSweep(
 			break;
 			// --------------------------------------------------
 
-			case MulvvOp:
-			reverse_mulvv_op(
-				d, i_var, arg, parameter, J, Taylor, K, Partial
+# if CPPAD_USE_CPLUSPLUS_2011
+			case Log1pOp:
+			reverse_log1p_op(
+				d, i_var, arg[0], J, Taylor, K, Partial
 			);
 			break;
+# endif
 			// --------------------------------------------------
 
 			case MulpvOp:
@@ -490,6 +544,13 @@ void ReverseSweep(
 			break;
 			// --------------------------------------------------
 
+			case MulvvOp:
+			reverse_mulvv_op(
+				d, i_var, arg, parameter, J, Taylor, K, Partial
+			);
+			break;
+			// --------------------------------------------------
+
 			case ParOp:
 			break;
 			// --------------------------------------------------
@@ -620,7 +681,7 @@ void ReverseSweep(
 				user_atom  = atomic_base<Base>::class_object(user_index);
 # ifndef NDEBUG
 				if( user_atom == CPPAD_NULL )
-				{	std::string msg = 
+				{	std::string msg =
 						atomic_base<Base>::class_name(user_index)
 						+ ": atomic_base function has been deleted";
 					CPPAD_ASSERT_KNOWN(false, msg.c_str() );
@@ -654,7 +715,7 @@ void ReverseSweep(
 				);
 # ifndef NDEBUG
 				if( ! user_ok )
-				{	std::string msg = 
+				{	std::string msg =
 						atomic_base<Base>::class_name(user_index)
 						+ ": atomic_base.reverse: returned false";
 					CPPAD_ASSERT_KNOWN(false, msg.c_str() );
@@ -680,7 +741,7 @@ void ReverseSweep(
 			user_tx[user_j * user_k1 + 0] = parameter[ arg[0]];
 			for(ell = 1; ell < user_k1; ell++)
 				user_tx[user_j * user_k1 + ell] = Base(0.);
-			
+
 			if( user_j == 0 )
 				user_state = user_start;
 			break;
@@ -732,6 +793,29 @@ void ReverseSweep(
 			break;
 			// ------------------------------------------------------------
 
+			case ZmulpvOp:
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < num_par );
+			reverse_zmulpv_op(
+				d, i_var, arg, parameter, J, Taylor, K, Partial
+			);
+			break;
+			// --------------------------------------------------
+
+			case ZmulvpOp:
+			CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < num_par );
+			reverse_zmulvp_op(
+				d, i_var, arg, parameter, J, Taylor, K, Partial
+			);
+			break;
+			// --------------------------------------------------
+
+			case ZmulvvOp:
+			reverse_zmulvv_op(
+				d, i_var, arg, parameter, J, Taylor, K, Partial
+			);
+			break;
+			// --------------------------------------------------
+
 			default:
 			CPPAD_ASSERT_UNKNOWN(false);
 		}
