@@ -1,12 +1,12 @@
-/* $Id: sin_op.hpp 3320 2014-09-11 23:06:21Z bradbell $ */
-# ifndef CPPAD_SIN_OP_INCLUDED
-# define CPPAD_SIN_OP_INCLUDED
+// $Id: sin_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_SIN_OP_HPP
+# define CPPAD_SIN_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -43,9 +43,9 @@ inline void forward_sin_op(
 	size_t q           ,
 	size_t i_z         ,
 	size_t i_x         ,
-	size_t cap_order   , 
+	size_t cap_order   ,
 	Base*  taylor      )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SinOp) == 1 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SinOp) == 2 );
@@ -100,9 +100,9 @@ inline void forward_sin_op_dir(
 	size_t r           ,
 	size_t i_z         ,
 	size_t i_x         ,
-	size_t cap_order   , 
+	size_t cap_order   ,
 	Base*  taylor      )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(SinOp) == 1 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(SinOp) == 2 );
@@ -152,7 +152,7 @@ template <class Base>
 inline void forward_sin_op_0(
 	size_t i_z         ,
 	size_t i_x         ,
-	size_t cap_order   , 
+	size_t cap_order   ,
 	Base*  taylor      )
 {
 	// check assumptions
@@ -190,7 +190,7 @@ inline void reverse_sin_op(
 	size_t      d            ,
 	size_t      i_z          ,
 	size_t      i_x          ,
-	size_t      cap_order    , 
+	size_t      cap_order    ,
 	const Base* taylor       ,
 	size_t      nc_partial   ,
 	Base*       partial      )
@@ -213,6 +213,7 @@ inline void reverse_sin_op(
 	const Base* c  = s  - cap_order; // called y in documentation
 	Base* pc       = ps - nc_partial;
 
+
 	// rest of this routine is identical for the following cases:
 	// reverse_sin_op, reverse_cos_op, reverse_sinh_op, reverse_cosh_op.
 	size_t j = d;
@@ -223,17 +224,17 @@ inline void reverse_sin_op(
 		pc[j]   /= Base(j);
 		for(k = 1; k <= j; k++)
 		{
-			px[k]   += ps[j] * Base(k) * c[j-k];
-			px[k]   -= pc[j] * Base(k) * s[j-k];
-	
-			ps[j-k] -= pc[j] * Base(k) * x[k];
-			pc[j-k] += ps[j] * Base(k) * x[k];
+			px[k]   += Base(k) * azmul(ps[j], c[j-k]);
+			px[k]   -= Base(k) * azmul(pc[j], s[j-k]);
+
+			ps[j-k] -= Base(k) * azmul(pc[j], x[k]);
+			pc[j-k] += Base(k) * azmul(ps[j], x[k]);
 
 		}
 		--j;
 	}
-	px[0] += ps[0] * c[0];
-	px[0] -= pc[0] * s[0];
+	px[0] += azmul(ps[0], c[0]);
+	px[0] -= azmul(pc[0], s[0]);
 }
 
 } // END_CPPAD_NAMESPACE
