@@ -1,12 +1,12 @@
-/* $Id: sparse.hpp 2506 2012-10-24 19:36:49Z bradbell $ */
-# ifndef CPPAD_SPARSE_INCLUDED
-# define CPPAD_SPARSE_INCLUDED
+// $Id: sparse.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_SPARSE_HPP
+# define CPPAD_SPARSE_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-06 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -18,15 +18,15 @@ $begin Sparse$$
 $spell
 $$
 
-$index sparsity, pattern$$
-$index pattern, sparsity$$
 
 $section Calculating Sparsity Patterns$$
 
 $childtable%
 	cppad/local/for_sparse_jac.hpp%
 	cppad/local/rev_sparse_jac.hpp%
-	cppad/local/rev_sparse_hes.hpp
+	example/dependency.cpp%
+	cppad/local/rev_sparse_hes.hpp%
+	example/bool_sparsity.cpp
 %$$
 
 $end
