@@ -1,11 +1,11 @@
-/* $Id: sparse_binary_op.hpp 3232 2014-04-27 15:38:21Z bradbell $ */
-# ifndef CPPAD_SPARSE_BINARY_OP_INCLUDED
-# define CPPAD_SPARSE_BINARY_OP_INCLUDED
+// $Id: sparse_binary_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_SPARSE_BINARY_OP_HPP
+# define CPPAD_SPARSE_BINARY_OP_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -20,13 +20,13 @@ Forward and reverse mode sparsity patterns for binary operators.
 
 
 /*!
-Forward mode Jacobian sparsity pattern for all binary operators. 
+Forward mode Jacobian sparsity pattern for all binary operators.
 
 The C++ source code corresponding to a binary operation has the form
 \verbatim
 	z = fun(x, y)
 \endverbatim
-where fun is a C++ binary function and both x and y are variables, 
+where fun is a C++ binary function and both x and y are variables,
 or it has the form
 \verbatim
 	z = x op y
@@ -38,8 +38,8 @@ is the type used for vectors of sets. It can be either
 \c sparse_pack, \c sparse_set, or \c sparse_list.
 
 \param i_z
-variable index corresponding to the result for this operation; 
-i.e., z. 
+variable index corresponding to the result for this operation;
+i.e., z.
 
 \param arg
 \a arg[0]
@@ -51,29 +51,29 @@ variable index corresponding to the right operand for this operator;
 i.e., y.
 
 \param sparsity
-\b Input: 
+\b Input:
 The set with index \a arg[0] in \a sparsity
 is the sparsity bit pattern for x.
 This identifies which of the independent variables the variable x
-depends on. 
+depends on.
 \n
 \n
-\b Input: 
+\b Input:
 The set with index \a arg[1] in \a sparsity
 is the sparsity bit pattern for y.
 This identifies which of the independent variables the variable y
-depends on. 
+depends on.
 \n
 \n
-\b Output: 
+\b Output:
 The set with index \a i_z in \a sparsity
 is the sparsity bit pattern for z.
 This identifies which of the independent variables the variable z
-depends on. 
+depends on.
 
 \par Checked Assertions:
-\li \a arg[0] < \a i_z 
-\li \a arg[1] < \a i_z 
+\li \a arg[0] < \a i_z
+\li \a arg[1] < \a i_z
 */
 
 template <class Vector_set>
@@ -81,7 +81,7 @@ inline void forward_sparse_jacobian_binary_op(
 	size_t            i_z           ,
 	const addr_t*     arg           ,
 	Vector_set&       sparsity      )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
@@ -89,16 +89,16 @@ inline void forward_sparse_jacobian_binary_op(
 	sparsity.binary_union(i_z, arg[0], arg[1], sparsity);
 
 	return;
-}	
+}
 
 /*!
-Reverse mode Jacobian sparsity pattern for all binary operators. 
+Reverse mode Jacobian sparsity pattern for all binary operators.
 
 The C++ source code corresponding to a unary operation has the form
 \verbatim
 	z = fun(x, y)
 \endverbatim
-where fun is a C++ unary function and x and y are variables, 
+where fun is a C++ unary function and x and y are variables,
 or it has the form
 \verbatim
 	z = x op y
@@ -107,7 +107,7 @@ where op is a C++ bianry operator and x and y are variables.
 
 This routine is given the sparsity patterns
 for a function G(z, y, x, ... )
-and it uses them to compute the sparsity patterns for 
+and it uses them to compute the sparsity patterns for
 \verbatim
 	H( y, x, w , u , ... ) = G[ z(x,y) , y , x , w , u , ... ]
 \endverbatim
@@ -117,7 +117,7 @@ is the type used for vectors of sets. It can be either
 \c sparse_pack, \c sparse_set, or \c sparse_list.
 
 \param i_z
-variable index corresponding to the result for this operation; 
+variable index corresponding to the result for this operation;
 i.e., z.
 
 \param arg
@@ -131,17 +131,17 @@ variable index corresponding to the right operand for this operator;
 i.e., y.
 
 \param sparsity
-The set with index \a i_z in \a sparsity 
+The set with index \a i_z in \a sparsity
 is the sparsity pattern for z corresponding ot the function G.
 \n
 \n
-The set with index \a arg[0] in \a sparsity 
+The set with index \a arg[0] in \a sparsity
 is the sparsity pattern for x.
 On input, it corresponds to the function G,
 and on output it corresponds to H.
 \n
 \n
-The set with index \a arg[1] in \a sparsity 
+The set with index \a arg[1] in \a sparsity
 is the sparsity pattern for y.
 On input, it corresponds to the function G,
 and on output it corresponds to H.
@@ -149,15 +149,15 @@ and on output it corresponds to H.
 \n
 
 \par Checked Assertions:
-\li \a arg[0] < \a i_z 
-\li \a arg[1] < \a i_z 
+\li \a arg[0] < \a i_z
+\li \a arg[1] < \a i_z
 */
 template <class Vector_set>
 inline void reverse_sparse_jacobian_binary_op(
 	size_t              i_z           ,
 	const addr_t*       arg           ,
 	Vector_set&         sparsity      )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
@@ -166,10 +166,10 @@ inline void reverse_sparse_jacobian_binary_op(
 	sparsity.binary_union(arg[1], arg[1], i_z, sparsity);
 
 	return;
-}	
+}
 
 /*!
-Reverse mode Hessian sparsity pattern for add and subtract operators. 
+Reverse mode Hessian sparsity pattern for add and subtract operators.
 
 The C++ source code corresponding to a unary operation has the form
 \verbatim
@@ -186,7 +186,7 @@ inline void reverse_sparse_hessian_addsub_op(
 	bool*                jac_reverse        ,
 	Vector_set&          for_jac_sparsity   ,
 	Vector_set&          rev_hes_sparsity   )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
@@ -198,10 +198,10 @@ inline void reverse_sparse_hessian_addsub_op(
 	jac_reverse[arg[1]] |= jac_reverse[i_z];
 
 	return;
-}	
+}
 
 /*!
-Reverse mode Hessian sparsity pattern for multiplication operator. 
+Reverse mode Hessian sparsity pattern for multiplication operator.
 
 The C++ source code corresponding to a unary operation has the form
 \verbatim
@@ -218,7 +218,7 @@ inline void reverse_sparse_hessian_mul_op(
 	bool*                jac_reverse        ,
 	Vector_set&          for_jac_sparsity   ,
 	Vector_set&          rev_hes_sparsity   )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
@@ -228,18 +228,18 @@ inline void reverse_sparse_hessian_mul_op(
 
 	if( jac_reverse[i_z] )
 	{	rev_hes_sparsity.binary_union(
-			arg[0], arg[0], arg[1], for_jac_sparsity); 
+			arg[0], arg[0], arg[1], for_jac_sparsity);
 		rev_hes_sparsity.binary_union(
-			arg[1], arg[1], arg[0], for_jac_sparsity); 
+			arg[1], arg[1], arg[0], for_jac_sparsity);
 	}
 
 	jac_reverse[arg[0]] |= jac_reverse[i_z];
 	jac_reverse[arg[1]] |= jac_reverse[i_z];
 	return;
-}	
+}
 
 /*!
-Reverse mode Hessian sparsity pattern for division operator. 
+Reverse mode Hessian sparsity pattern for division operator.
 
 The C++ source code corresponding to a unary operation has the form
 \verbatim
@@ -256,7 +256,7 @@ inline void reverse_sparse_hessian_div_op(
 	bool*                jac_reverse        ,
 	Vector_set&          for_jac_sparsity   ,
 	Vector_set&          rev_hes_sparsity   )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
@@ -266,20 +266,20 @@ inline void reverse_sparse_hessian_div_op(
 
 	if( jac_reverse[i_z] )
 	{	rev_hes_sparsity.binary_union(
-			arg[0], arg[0], arg[1], for_jac_sparsity); 
+			arg[0], arg[0], arg[1], for_jac_sparsity);
 		rev_hes_sparsity.binary_union(
-			arg[1], arg[1], arg[0], for_jac_sparsity); 
+			arg[1], arg[1], arg[0], for_jac_sparsity);
 		rev_hes_sparsity.binary_union(
-			arg[1], arg[1], arg[1], for_jac_sparsity); 
+			arg[1], arg[1], arg[1], for_jac_sparsity);
 	}
 
 	jac_reverse[arg[0]] |= jac_reverse[i_z];
 	jac_reverse[arg[1]] |= jac_reverse[i_z];
 	return;
-}	
+}
 
 /*!
-Reverse mode Hessian sparsity pattern for power function. 
+Reverse mode Hessian sparsity pattern for power function.
 
 The C++ source code corresponding to a unary operation has the form
 \verbatim
@@ -296,7 +296,7 @@ inline void reverse_sparse_hessian_pow_op(
 	bool*                jac_reverse        ,
 	Vector_set&          for_jac_sparsity   ,
 	Vector_set&          rev_hes_sparsity   )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[0]) < i_z );
 	CPPAD_ASSERT_UNKNOWN( size_t(arg[1]) < i_z );
@@ -307,14 +307,14 @@ inline void reverse_sparse_hessian_pow_op(
 	if( jac_reverse[i_z] )
 	{
 		rev_hes_sparsity.binary_union(
-			arg[0], arg[0], arg[0], for_jac_sparsity); 
+			arg[0], arg[0], arg[0], for_jac_sparsity);
 		rev_hes_sparsity.binary_union(
-			arg[0], arg[0], arg[1], for_jac_sparsity); 
+			arg[0], arg[0], arg[1], for_jac_sparsity);
 
 		rev_hes_sparsity.binary_union(
-			arg[1], arg[1], arg[0], for_jac_sparsity); 
+			arg[1], arg[1], arg[0], for_jac_sparsity);
 		rev_hes_sparsity.binary_union(
-			arg[1], arg[1], arg[1], for_jac_sparsity); 
+			arg[1], arg[1], arg[1], for_jac_sparsity);
 	}
 
 	// I cannot think of a case where this is necessary, but it including
@@ -322,7 +322,7 @@ inline void reverse_sparse_hessian_pow_op(
 	jac_reverse[arg[0]] |= jac_reverse[i_z];
 	jac_reverse[arg[1]] |= jac_reverse[i_z];
 	return;
-}	
+}
 
 } // END_CPPAD_NAMESPACE
 # endif
