@@ -1,12 +1,12 @@
-/* $Id: sparse_hessian.hpp 3239 2014-04-28 23:00:17Z bradbell $ */
-# ifndef CPPAD_SPARSE_HESSIAN_INCLUDED
-# define CPPAD_SPARSE_HESSIAN_INCLUDED
+// $Id: sparse_hessian.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_SPARSE_HESSIAN_HPP
+# define CPPAD_SPARSE_HESSIAN_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -16,6 +16,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 /*
 $begin sparse_hessian$$
 $spell
+	jacobian
 	recomputed
 	CppAD
 	valarray
@@ -24,11 +25,13 @@ $spell
 	hes
 	const
 	Taylor
+	cppad
+	cmake
+	colpack
 $$
 
 $section Sparse Hessian: Easy Driver$$
-$index SparseHessian$$
-$index hessian, sparse$$
+$mindex SparseHessian$$
 
 $head Syntax$$
 $icode%hes% = %f%.SparseHessian(%x%, %w%)
@@ -41,10 +44,10 @@ We use $latex n$$ for the $cref/domain/seq_property/Domain/$$ size,
 and $latex m$$ for the $cref/range/seq_property/Range/$$ size of $icode f$$.
 We use $latex F : \B{R}^n \rightarrow \B{R}^m$$ do denote the
 $cref/AD function/glossary/AD Function/$$
-corresponding to $icode f$$. 
-The syntax above sets $icode hes$$ to the Hessian 
+corresponding to $icode f$$.
+The syntax above sets $icode hes$$ to the Hessian
 $latex \[
-	H(x) = \dpow{2}{x} \sum_{i=1}^m w_i F_i (x) 
+	H(x) = \dpow{2}{x} \sum_{i=1}^m w_i F_i (x)
 \] $$
 This routine takes advantage of the sparsity of the Hessian
 in order to reduce the amount of computation necessary.
@@ -69,7 +72,7 @@ $codei%
 	const %VectorBase%& %x%
 %$$
 (see $cref/VectorBase/sparse_hessian/VectorBase/$$ below)
-and its size 
+and its size
 must be equal to $icode n$$, the dimension of the
 $cref/domain/seq_property/Domain/$$ space for $icode f$$.
 It specifies
@@ -81,7 +84,7 @@ $codei%
 	const %VectorBase%& %w%
 %$$
 and size $latex m$$.
-It specifies the value of $latex w_i$$ in the expression 
+It specifies the value of $latex w_i$$ in the expression
 for $icode hes$$.
 The more components of $latex w$$ that are identically zero,
 the more sparse the resulting Hessian may be (and hence the more efficient
@@ -99,14 +102,20 @@ If it has elements of type $code std::set<size_t>$$,
 its size is $latex n$$ and all its set elements are between
 zero and $latex n - 1$$.
 It specifies a
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for the Hessian $latex H(x)$$.
 $pre
 
 $$
-If this sparsity pattern does not change between calls to 
+If this sparsity pattern does not change between calls to
 $codei SparseHessian$$, it should be faster to calculate $icode p$$ once and
 pass this argument to $codei SparseHessian$$.
+Furthermore, if you specify $icode work$$ in the calling sequence,
+it is not necessary to keep the sparsity pattern; see the heading
+$cref/p/sparse_hessian/work/p/$$ under the $icode work$$ description.
+$pre
+
+$$
 In addition,
 if you specify $icode p$$, CppAD will use the same
 type of sparsity representation
@@ -129,7 +138,7 @@ which must also equal the size of $icode row$$ and $icode col$$.
 Furthermore,
 for $latex k = 0 , \ldots , K-1$$, it must hold that
 $latex row[k] < n$$ and $latex col[k] < n$$.
-In addition, 
+In addition,
 all of the $latex (row[k], col[k])$$ pairs must correspond to a true value
 in the sparsity pattern $icode p$$.
 
@@ -141,7 +150,7 @@ $codei%
 In the case where $icode row$$ and $icode col$$ are not present,
 the size of $icode hes$$ is $latex n * n$$ and
 its size is $latex n * n$$.
-In this case, for $latex i = 0 , \ldots , n - 1 $$ 
+In this case, for $latex i = 0 , \ldots , n - 1 $$
 and $latex ell = 0 , \ldots , n - 1$$
 $latex \[
 	hes [ j * n + \ell ] = \DD{ w^{\rm T} F }{ x_j }{ x_\ell } ( x )
@@ -150,7 +159,7 @@ $pre
 
 $$
 In the case where the arguments $icode row$$ and $icode col$$ are present,
-we use $latex K$$ to denote the size of $icode hes$$. 
+we use $latex K$$ to denote the size of $icode hes$$.
 The input value of its elements does not matter.
 Upon return, for $latex k = 0 , \ldots , K - 1$$,
 $latex \[
@@ -169,24 +178,64 @@ $codei%
 %$$
 This object can only be used with the routines $code SparseHessian$$.
 During its the first use, information is stored in $icode work$$.
-This is used to reduce the work done by future calls to $code SparseHessian$$ 
+This is used to reduce the work done by future calls to $code SparseHessian$$
 with the same $icode f$$, $icode p$$, $icode row$$, and $icode col$$.
-If a future call is make where any of these values have changed,
+If a future call is made where any of these values have changed,
 you must first call $icode%work%.clear()%$$
 to inform CppAD that this information needs to be recomputed.
 
+$subhead color_method$$
+The coloring algorithm determines which rows and columns
+can be computed during the same sweep.
+This field has prototype
+$codei%
+	std::string %work%.color_method
+%$$
+This value only matters on the first call to $code sparse_hessian$$ that
+follows the $icode work$$ constructor or a call to
+$icode%work%.clear()%$$.
+$codei%
+
+"cppad.symmetric"
+%$$
+This is the default coloring method (after a constructor or $code clear()$$).
+It takes advantage of the fact that the Hessian matrix
+is symmetric to find a coloring that requires fewer
+$cref/sweeps/sparse_hessian/n_sweep/$$.
+$codei%
+
+"cppad.general"
+%$$
+This is the same as the $code "cppad"$$ method for the
+$cref/sparse_jacobian/sparse_jacobian/work/color_method/$$ calculation.
+$codei%
+
+"colpack.star"
+%$$
+This method requires that
+$cref colpack_prefix$$ was specified on the
+$cref/cmake command/cmake/CMake Command/$$ line.
+It also takes advantage of the fact that the Hessian matrix is symmetric.
+
+$subhead p$$
+If $icode work$$ is present, and it is not the first call after
+its construction or a clear,
+the sparsity pattern $icode p$$ is not used.
+This enables one to free the sparsity pattern
+and still compute corresponding sparse Hessians.
+
 $head n_sweep$$
 The return value $icode n_sweep$$ has prototype
 $codei%
 	size_t %n_sweep%
 %$$
-It is the number of first order forward sweeps 
+It is the number of first order forward sweeps
 used to compute the requested Hessian values.
-Each first forward sweep is followed by a second order reverse sweep 
+Each first forward sweep is followed by a second order reverse sweep
 so it is also the number of reverse sweeps.
-This is proportional to the total work that $code SparseHessian$$ does, 
-not counting the zero order forward sweep, 
-or the work to combine multiple columns into a single 
+This is proportional to the total work that $code SparseHessian$$ does,
+not counting the zero order forward sweep,
+or the work to combine multiple columns into a single
 forward-reverse sweep pair.
 
 $head VectorBase$$
@@ -207,11 +256,11 @@ if this is not the case.
 
 $subhead Restrictions$$
 If $icode VectorSet$$ has elements of $code std::set<size_t>$$,
-then $icode%p%[%i%]%$$ must return a reference (not a copy) to the 
+then $icode%p%[%i%]%$$ must return a reference (not a copy) to the
 corresponding set.
 According to section 26.3.2.3 of the 1998 C++ standard,
 $code std::valarray< std::set<size_t> >$$ does not satisfy
-this condition. 
+this condition.
 
 $head VectorSize$$
 The type $icode VectorSize$$ must be a $cref SimpleVector$$ class with
@@ -222,27 +271,38 @@ if this is not the case.
 
 $head Uses Forward$$
 After each call to $cref Forward$$,
-the object $icode f$$ contains the corresponding 
+the object $icode f$$ contains the corresponding
 $cref/Taylor coefficients/glossary/Taylor Coefficient/$$.
 After a call to any of the sparse Hessian routines,
 the zero order Taylor coefficients correspond to
 $icode%f%.Forward(0, %x%)%$$
 and the other coefficients are unspecified.
 
-$head Example$$
 $children%
-	example/sparse_hessian.cpp
+	example/sparse_hessian.cpp%
+	example/sub_sparse_hes.cpp%
+	example/sparse_sub_hes.cpp
 %$$
+
+$head Example$$
 The routine
-$cref sparse_hessian.cpp$$ 
+$cref sparse_hessian.cpp$$
 is examples and tests of $code sparse_hessian$$.
 It return $code true$$, if it succeeds and $code false$$ otherwise.
 
+$head Subset Hessian$$
+The routines
+$cref sub_sparse_hes.cpp$$ and $cref sparse_sub_hes.cpp$$
+are examples and tests that compute a sparse Hessian
+for a subset of the variables.
+They return $code true$$, if they succeed and $code false$$ otherwise.
 
 $end
 -----------------------------------------------------------------------------
 */
 # include <cppad/local/std_set.hpp>
+# include <cppad/local/color_general.hpp>
+# include <cppad/local/color_symmetric.hpp>
 
 namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 /*!
@@ -251,18 +311,32 @@ Sparse Hessian driver routine and helper functions.
 */
 // ===========================================================================
 /*!
-class used by SparseHessian to hold information 
+class used by SparseHessian to hold information
 so it does not need to be recomputed.
 */
 class sparse_hessian_work {
 	public:
+		/// Coloring method: "cppad", or "colpack"
+		/// (this field is set by user)
+		std::string color_method;
+		/// row and column indicies for return values
+		/// (some may be reflected by star coloring algorithm)
+		CppAD::vector<size_t> row;
+		CppAD::vector<size_t> col;
 		/// indices that sort the user row and col arrays by color
 		CppAD::vector<size_t> order;
 		/// results of the coloring algorithm
 		CppAD::vector<size_t> color;
+
+		/// constructor
+		sparse_hessian_work(void) : color_method("cppad.symmetric")
+		{ }
 		/// inform CppAD that this information needs to be recomputed
 		void clear(void)
-		{	order.clear();
+		{	color_method = "cppad.symmetric";
+			row.clear();
+			col.clear();
+			order.clear();
 			color.clear();
 		}
 };
@@ -277,7 +351,7 @@ is the base type for the recording that is stored in this ADFun<Base object.
 is a simple vector class with elements of type \a Base.
 
 \tparam VectorSet
-is a simple vector class with elements of type 
+is a simple vector class with elements of type
 \c bool or \c std::set<size_t>.
 
 \tparam VectorSize
@@ -294,24 +368,24 @@ $latex F(x)$$.
 \param sparsity [in]
 is the sparsity pattern for the Hessian that we are calculating.
 
-\param row [in]
+\param user_row [in]
 is the vector of row indices for the returned Hessian values.
 
-\param col [in]
+\param user_col [in]
 is the vector of columns indices for the returned Hessian values.
-It must have the same size are r.
+It must have the same size as user_row.
 
 \param hes [out]
 is the vector of Hessian values.
-It must have the same size are r. 
-The return value <code>hes[k]</code> is the second partial of 
+It must have the same size as user_row.
+The return value <code>hes[k]</code> is the second partial of
 \f$ w^{\rm T} F(x)\f$ with respect to the
 <code>row[k]</code> and <code>col[k]</code> component of \f$ x\f$.
 
 \param work
 This structure contains information that is computed by \c SparseHessianCompute.
 If the sparsity pattern, \c row vector, or \c col vectors
-are not the same between calls to \c SparseHessianCompute, 
+are not the same between calls to \c SparseHessianCompute,
 \c work.clear() must be called to reinitialize \c work.
 
 \return
@@ -328,14 +402,16 @@ size_t ADFun<Base>::SparseHessianCompute(
 	const VectorBase&           x           ,
 	const VectorBase&           w           ,
 	      VectorSet&            sparsity    ,
-	const VectorSize&           row         ,
-	const VectorSize&           col         ,
+	const VectorSize&           user_row    ,
+	const VectorSize&           user_col    ,
 	      VectorBase&           hes         ,
 	      sparse_hessian_work&  work        )
 {
 	using   CppAD::vectorBool;
 	size_t i, k, ell;
 
+	CppAD::vector<size_t>& row(work.row);
+	CppAD::vector<size_t>& col(work.col);
 	CppAD::vector<size_t>& color(work.color);
 	CppAD::vector<size_t>& order(work.order);
 
@@ -348,13 +424,16 @@ size_t ADFun<Base>::SparseHessianCompute(
 	// check VectorBase is Simple Vector class with Base type elements
 	CheckSimpleVector<Base, VectorBase>();
 
-	CPPAD_ASSERT_UNKNOWN( size_t(x.size()) == n );
-	CPPAD_ASSERT_UNKNOWN( color.size() == 0 || color.size() == n );
-
 	// number of components of Hessian that are required
 	size_t K = hes.size();
-	CPPAD_ASSERT_UNKNOWN( row.size() == K );
-	CPPAD_ASSERT_UNKNOWN( col.size() == K );
+	CPPAD_ASSERT_UNKNOWN( size_t( user_row.size() ) == K );
+	CPPAD_ASSERT_UNKNOWN( size_t( user_col.size() ) == K );
+
+	CPPAD_ASSERT_UNKNOWN( size_t(x.size()) == n );
+	CPPAD_ASSERT_UNKNOWN( color.size() == 0 || color.size() == n );
+	CPPAD_ASSERT_UNKNOWN( row.size() == 0   || row.size() == K );
+	CPPAD_ASSERT_UNKNOWN( col.size() == 0   || col.size() == K );
+
 
 	// Point at which we are evaluating the Hessian
 	Forward(0, x);
@@ -370,9 +449,38 @@ size_t ADFun<Base>::SparseHessianCompute(
 		CPPAD_ASSERT_UNKNOWN( sparsity.n_set() ==  n );
 		CPPAD_ASSERT_UNKNOWN( sparsity.end() ==  n );
 
+		// copy user rwo and col to work space
+		row.resize(K);
+		col.resize(K);
+		for(k = 0; k < K; k++)
+		{	row[k] = user_row[k];
+			col[k] = user_col[k];
+		}
+
 		// execute coloring algorithm
 		color.resize(n);
-		color_general_cppad(sparsity, row, col, color);
+		if( work.color_method == "cppad.general" )
+			color_general_cppad(sparsity, row, col, color);
+		else if( work.color_method == "cppad.symmetric" )
+			color_symmetric_cppad(sparsity, row, col, color);
+		else if( work.color_method == "colpack.star" )
+		{
+# if CPPAD_HAS_COLPACK
+			color_symmetric_colpack(sparsity, row, col, color);
+# else
+			CPPAD_ASSERT_KNOWN(
+				false,
+				"SparseHessian: work.color_method = colpack.star"
+				"and colpack_prefix missing from cmake command line."
+			);
+# endif
+		}
+		else
+		{	CPPAD_ASSERT_KNOWN(
+				false,
+				"SparseHessian: work.color_method is not valid."
+			);
+		}
 
 		// put sorting indices in color order
 		VectorSize key(K);
@@ -414,7 +522,7 @@ size_t ADFun<Base>::SparseHessianCompute(
 		ddw = Reverse(2, w);
 
 		// set the corresponding components of the result
-		while( k < K && color[ row[ order[k] ] ] == ell ) 
+		while( k < K && color[ row[ order[k] ] ] == ell )
 		{	hes[ order[k] ] = ddw[ col[ order[k] ] * 2 + 1 ];
 			k++;
 		}
@@ -439,7 +547,7 @@ is the base type for the recording that is stored in this ADFun<Base object.
 is a simple vector class with elements of type \a Base.
 
 \tparam VectorSet
-is a simple vector class with elements of type 
+is a simple vector class with elements of type
 \c bool or \c std::set<size_t>.
 
 \tparam VectorSize
@@ -465,15 +573,15 @@ It must have the same size are r.
 
 \param hes [out]
 is the vector of Hessian values.
-It must have the same size are r. 
-The return value <code>hes[k]</code> is the second partial of 
+It must have the same size are r.
+The return value <code>hes[k]</code> is the second partial of
 \f$ w^{\rm T} F(x)\f$ with respect to the
 <code>row[k]</code> and <code>col[k]</code> component of \f$ x\f$.
 
 \param work
 This structure contains information that is computed by \c SparseHessianCompute.
 If the sparsity pattern, \c row vector, or \c col vectors
-are not the same between calls to \c SparseHessian, 
+are not the same between calls to \c SparseHessian,
 \c work.clear() must be called to reinitialize \c work.
 
 \return
@@ -496,16 +604,17 @@ size_t ADFun<Base>::SparseHessian(
 	sparse_hessian_work&  work )
 {
 	size_t n    = Domain();
+	size_t K    = hes.size();
 # ifndef NDEBUG
-	size_t k, K = hes.size();
+	size_t k;
 	CPPAD_ASSERT_KNOWN(
 		size_t(x.size()) == n ,
 		"SparseHessian: size of x not equal domain dimension for f."
-	); 
+	);
 	CPPAD_ASSERT_KNOWN(
 		size_t(row.size()) == K && size_t(col.size()) == K ,
 		"SparseHessian: either r or c does not have the same size as ehs."
-	); 
+	);
 	CPPAD_ASSERT_KNOWN(
 		work.color.size() == 0 || work.color.size() == n,
 		"SparseHessian: invalid value in work."
@@ -526,6 +635,11 @@ size_t ADFun<Base>::SparseHessian(
 			"SparseHessian: invalid value in work."
 	);
 # endif
+	// check for case where there is nothing to compute
+	size_t n_sweep = 0;
+	if( K == 0 )
+		return n_sweep;
+
 	typedef typename VectorSet::value_type Set_type;
 	typedef typename internal_sparsity<Set_type>::pattern_type Pattern_type;
 	Pattern_type s;
@@ -533,7 +647,7 @@ size_t ADFun<Base>::SparseHessian(
 	{	bool transpose = false;
 		sparsity_user2internal(s, p, n, n, transpose);
 	}
-	size_t n_sweep = SparseHessianCompute(x, w, s, row, col, hes, work);
+	n_sweep = SparseHessianCompute(x, w, s, row, col, hes, work);
 	return n_sweep;
 }
 /*!
@@ -569,7 +683,7 @@ It must have size equal to the range dimension for this ADFun<Base> object.
 is a sparsity pattern for the Hessian.
 
 \return
-Will be a vector of size \c n * n containing the Hessian of 
+Will be a vector of size \c n * n containing the Hessian of
 at the point specified by \a x
 (where \c n is the domain dimension for this ADFun<Base> object).
 */
@@ -600,7 +714,7 @@ VectorBase ADFun<Base>::SparseHessian(
 	// arguments to SparseHessianCompute
 	Pattern_type          s;
 	CppAD::vector<size_t> row;
-	CppAD::vector<size_t> col; 
+	CppAD::vector<size_t> col;
 	sparse_hessian_work   work;
 	bool transpose = false;
 	sparsity_user2internal(s, p, n, n, transpose);
@@ -653,7 +767,7 @@ The argument \a w specifies the weights for each component.
 It must have size equal to the range dimension for this ADFun<Base> object.
 
 \return
-Will be a vector of size \c n * n containing the Hessian of 
+Will be a vector of size \c n * n containing the Hessian of
 at the point specified by \a x
 (where \c n is the domain dimension for this ADFun<Base> object).
 */
