@@ -1,12 +1,12 @@
-/* $Id: sparse_jacobian.hpp 3301 2014-05-24 05:20:21Z bradbell $ */
-# ifndef CPPAD_SPARSE_JACOBIAN_INCLUDED
-# define CPPAD_SPARSE_JACOBIAN_INCLUDED
+// $Id: sparse_jacobian.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_SPARSE_JACOBIAN_HPP
+# define CPPAD_SPARSE_JACOBIAN_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -31,13 +31,13 @@ $spell
 	Bool
 	jac
 	Jacobian
+	Jacobians
 	const
 	Taylor
 $$
 
 $section Sparse Jacobian: Easy Driver$$
-$index SparseJacobian$$
-$index jacobian, sparse$$
+$mindex SparseJacobian$$
 
 $head Syntax$$
 $icode%jac% = %f%.SparseJacobian(%x%)
@@ -51,10 +51,10 @@ We use $latex n$$ for the $cref/domain/seq_property/Domain/$$ size,
 and $latex m$$ for the $cref/range/seq_property/Range/$$ size of $icode f$$.
 We use $latex F : \B{R}^n \rightarrow \B{R}^m$$ do denote the
 $cref/AD function/glossary/AD Function/$$
-corresponding to $icode f$$. 
-The syntax above sets $icode jac$$ to the Jacobian 
+corresponding to $icode f$$.
+The syntax above sets $icode jac$$ to the Jacobian
 $latex \[
-	jac = F^{(1)} (x) 
+	jac = F^{(1)} (x)
 \] $$
 This routine takes advantage of the sparsity of the Jacobian
 in order to reduce the amount of computation necessary.
@@ -79,7 +79,7 @@ $codei%
 	const %VectorBase%& %x%
 %$$
 (see $cref/VectorBase/sparse_jacobian/VectorBase/$$ below)
-and its size 
+and its size
 must be equal to $icode n$$, the dimension of the
 $cref/domain/seq_property/Domain/$$ space for $icode f$$.
 It specifies
@@ -96,19 +96,25 @@ its size is $latex m * n$$.
 If it has elements of type $code std::set<size_t>$$,
 its size is $latex m$$ and all its set elements are between
 zero and $latex n - 1$$.
-It specifies a 
-$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
+It specifies a
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$
 for the Jacobian $latex F^{(1)} (x)$$.
 $pre
 
 $$
-If this sparsity pattern does not change between calls to 
-$codei SparseJacobian$$, it should be faster to calculate $icode p$$ once 
+If this sparsity pattern does not change between calls to
+$codei SparseJacobian$$, it should be faster to calculate $icode p$$ once
 (using $cref ForSparseJac$$ or $cref RevSparseJac$$)
 and then pass $icode p$$ to $codei SparseJacobian$$.
+Furthermore, if you specify $icode work$$ in the calling sequence,
+it is not necessary to keep the sparsity pattern; see the heading
+$cref/p/sparse_jacobian/work/p/$$ under the $icode work$$ description.
+$pre
+
+$$
 In addition,
 if you specify $icode p$$, CppAD will use the same
-type of sparsity representation 
+type of sparsity representation
 (vectors of $code bool$$ or vectors of $code std::set<size_t>$$)
 for its internal calculations.
 Otherwise, the representation
@@ -148,7 +154,7 @@ $pre
 
 $$
 In the case where the arguments $icode row$$ and $icode col$$ are present,
-we use $latex K$$ to denote the size of $icode jac$$. 
+we use $latex K$$ to denote the size of $icode jac$$.
 The input value of its elements does not matter.
 Upon return, for $latex k = 0 , \ldots , K - 1$$,
 $latex \[
@@ -165,11 +171,11 @@ If this argument is present, it has prototype
 $codei%
 	sparse_jacobian_work& %work%
 %$$
-This object can only be used with the routines 
+This object can only be used with the routines
 $code SparseJacobianForward$$ and $code SparseJacobianReverse$$.
 During its the first use, information is stored in $icode work$$.
 This is used to reduce the work done by future calls to the same mode
-(forward or reverse), 
+(forward or reverse),
 the same $icode f$$, $icode p$$, $icode row$$, and $icode col$$.
 If a future call is for a different mode,
 or any of these values have changed,
@@ -183,26 +189,34 @@ This field has prototype
 $codep%
 	std::string %work%.color_method
 %$$
-and its default value (after a constructor or $code clear()$$) 
+and its default value (after a constructor or $code clear()$$)
 is $code "cppad"$$.
 If $cref colpack_prefix$$ is specified on the
 $cref/cmake command/cmake/CMake Command/$$ line,
 you can set this method to $code "colpack"$$.
 This value only matters on the first call to $code sparse_jacobian$$
-after the $icode work$$ constructor or a call to $code clear$$.
+that follows the $icode work$$ constructor or a call to
+$icode%work%.clear()%$$.
+
+$subhead p$$
+If $icode work$$ is present, and it is not the first call after
+its construction or a clear,
+the sparsity pattern $icode p$$ is not used.
+This enables one to free the sparsity pattern
+and still compute corresponding sparse Jacobians.
 
 $head n_sweep$$
 The return value $icode n_sweep$$ has prototype
 $codei%
 	size_t %n_sweep%
 %$$
-If $code SparseJacobianForward$$ ($code SparseJacobianReverse$$) is used, 
-$icode n_sweep$$ is the number of first order forward (reverse) sweeps 
-used to compute the requested Jacobian values. 
+If $code SparseJacobianForward$$ ($code SparseJacobianReverse$$) is used,
+$icode n_sweep$$ is the number of first order forward (reverse) sweeps
+used to compute the requested Jacobian values.
 (This is also the number of colors determined by the coloring method
 mentioned above).
-This is proportional to the total work that $code SparseJacobian$$ does, 
-not counting the zero order forward sweep, 
+This is proportional to the total work that $code SparseJacobian$$ does,
+not counting the zero order forward sweep,
 or the work to combine multiple columns (rows) into a single sweep.
 
 $head VectorBase$$
@@ -223,11 +237,11 @@ if this is not the case.
 
 $subhead Restrictions$$
 If $icode VectorSet$$ has elements of $code std::set<size_t>$$,
-then $icode%p%[%i%]%$$ must return a reference (not a copy) to the 
+then $icode%p%[%i%]%$$ must return a reference (not a copy) to the
 corresponding set.
 According to section 26.3.2.3 of the 1998 C++ standard,
 $code std::valarray< std::set<size_t> >$$ does not satisfy
-this condition. 
+this condition.
 
 $head VectorSize$$
 The type $icode VectorSize$$ must be a $cref SimpleVector$$ class with
@@ -238,7 +252,7 @@ if this is not the case.
 
 $head Uses Forward$$
 After each call to $cref Forward$$,
-the object $icode f$$ contains the corresponding 
+the object $icode f$$ contains the corresponding
 $cref/Taylor coefficients/glossary/Taylor Coefficient/$$.
 After a call to any of the sparse Jacobian routines,
 the zero order Taylor coefficients correspond to
@@ -270,19 +284,19 @@ Sparse Jacobian driver routine and helper functions.
 */
 // ===========================================================================
 /*!
-class used by SparseJacobian to hold information so it does not need to be 
+class used by SparseJacobian to hold information so it does not need to be
 recomputed.
 */
 class sparse_jacobian_work {
 	public:
-		/// Coloring method: color_general_cppad or color_general_colpack
+		/// Coloring method: "cppad", or "colpack"
 		/// (this field is set by user)
 		std::string color_method;
-		/// indices that sort the user row and col arrays by color 
+		/// indices that sort the user row and col arrays by color
 		CppAD::vector<size_t> order;
 		/// results of the coloring algorithm
 		CppAD::vector<size_t> color;
-	
+
 		/// constructor
 		sparse_jacobian_work(void) : color_method("cppad")
 		{ }
@@ -315,7 +329,7 @@ is a simple vector class with elements of type \c size_t.
 is a vector specifing the point at which to compute the Jacobian.
 
 \param p_transpose [in]
-If <code>work.color.size() != 0</code>, 
+If <code>work.color.size() != 0</code>,
 then \c p_transpose is not used.
 Otherwise, it is a
 sparsity pattern for the transpose of the Jacobian of this ADFun<Base> object.
@@ -339,7 +353,7 @@ the the <code>col[k]</code> domain component of its argument.
 <code>work.color_method</code> is an input. The rest of
 this structure contains information that is computed by \c SparseJacobainFor.
 If the sparsity pattern, \c row vector, or \c col vectors
-are not the same between calls to \c SparseJacobianFor, 
+are not the same between calls to \c SparseJacobianFor,
 \c work.clear() must be called to reinitialize \c work.
 
 \return
@@ -378,8 +392,8 @@ size_t ADFun<Base>::SparseJacobianFor(
 
 	// number of components of Jacobian that are required
 	size_t K = size_t(jac.size());
-	CPPAD_ASSERT_UNKNOWN( row.size() == K );
-	CPPAD_ASSERT_UNKNOWN( col.size() == K );
+	CPPAD_ASSERT_UNKNOWN( size_t( row.size() ) == K );
+	CPPAD_ASSERT_UNKNOWN( size_t( col.size() ) == K );
 
 	// Point at which we are evaluating the Jacobian
 	Forward(0, x);
@@ -448,7 +462,7 @@ size_t ADFun<Base>::SparseJacobianFor(
 		dy = Forward(1, dx);
 
 		// set the corresponding components of the result
-		while( k < K && color[ col[order[k]] ] == ell ) 
+		while( k < K && color[ col[order[k]] ] == ell )
 		{	jac[ order[k] ] = dy[row[order[k]]];
 			k++;
 		}
@@ -468,7 +482,7 @@ size_t ADFun<Base>::SparseJacobianFor(
 		VectorBase dx(n * r), dy(m * r);
 
 		// loop over colors we will do this tme
-		for(ell = 0; ell < r; ell++) 	
+		for(ell = 0; ell < r; ell++)
 		{	// combine all columns with this color
 			for(j = 0; j < n; j++)
 			{	dx[j * r + ell] = zero;
@@ -480,9 +494,9 @@ size_t ADFun<Base>::SparseJacobianFor(
 		dy = Forward(q, r, dx);
 
 		// store results
-		for(ell = 0; ell < r; ell++) 	
+		for(ell = 0; ell < r; ell++)
 		{	// set the components of the result for this color
-			while( k < K && color[ col[order[k]] ] == ell + count_color ) 
+			while( k < K && color[ col[order[k]] ] == ell + count_color )
 			{	jac[ order[k] ] = dy[ row[order[k]] * r + ell ];
 				k++;
 			}
@@ -527,7 +541,7 @@ It must have the same size as \c row.
 
 \param jac [out]
 is the vector of Jacobian values.
-It must have the same size as \c row. 
+It must have the same size as \c row.
 The return value <code>jac[k]</code> is the partial of the
 <code>row[k]</code> range component of the function with respect
 the the <code>col[k]</code> domain component of its argument.
@@ -536,7 +550,7 @@ the the <code>col[k]</code> domain component of its argument.
 <code>work.color_method</code> is an input. The rest of
 This structure contains information that is computed by \c SparseJacobainRev.
 If the sparsity pattern, \c row vector, or \c col vectors
-are not the same between calls to \c SparseJacobianRev, 
+are not the same between calls to \c SparseJacobianRev,
 \c work.clear() must be called to reinitialize \c work.
 
 \return
@@ -575,8 +589,8 @@ size_t ADFun<Base>::SparseJacobianRev(
 
 	// number of components of Jacobian that are required
 	size_t K = size_t(jac.size());
-	CPPAD_ASSERT_UNKNOWN( row.size() == K );
-	CPPAD_ASSERT_UNKNOWN( col.size() == K );
+	CPPAD_ASSERT_UNKNOWN( size_t( size_t( row.size() ) ) == K );
+	CPPAD_ASSERT_UNKNOWN( size_t( size_t( col.size() ) ) == K );
 
 	// Point at which we are evaluating the Jacobian
 	Forward(0, x);
@@ -619,7 +633,7 @@ size_t ADFun<Base>::SparseJacobianRev(
 		index_sort(key, order);
 	}
 	size_t n_color = 1;
-	for(i = 0; i < m; i++) if( color[i] < m ) 
+	for(i = 0; i < m; i++) if( color[i] < m )
 		n_color = std::max(n_color, color[i] + 1);
 
 	// weighting vector for calls to reverse
@@ -647,7 +661,7 @@ size_t ADFun<Base>::SparseJacobianRev(
 		dw = Reverse(1, w);
 
 		// set the corresponding components of the result
-		while( k < K && color[ row[order[k]] ]  == ell ) 
+		while( k < K && color[ row[order[k]] ]  == ell )
 		{	jac[ order[k] ] = dw[col[order[k]]];
 			k++;
 		}
@@ -673,7 +687,7 @@ is the base type for the recording that is stored in this
 is a simple vector class with elements of type \a Base.
 
 \tparam VectorSet
-is a simple vector class with elements of type 
+is a simple vector class with elements of type
 \c bool or \c std::set<size_t>.
 
 \tparam VectorSize
@@ -694,15 +708,15 @@ It must have the same size as \c row.
 
 \param jac [out]
 is the vector of Jacobian values.
-It must have the same size as \c row. 
+It must have the same size as \c row.
 The return value <code>jac[k]</code> is the partial of the
 <code>row[k]</code> range component of the function with respect
 the the <code>col[k]</code> domain component of its argument.
 
 \param work [in,out]
-this structure contains information that depends on the function object, 
+this structure contains information that depends on the function object,
 sparsity pattern, \c row vector, and \c col vector.
-If they are not the same between calls to \c SparseJacobianForward, 
+If they are not the same between calls to \c SparseJacobianForward,
 \c work.clear() must be called to reinitialize them.
 
 \return
@@ -723,17 +737,18 @@ size_t ADFun<Base>::SparseJacobianForward(
 {
 	size_t n = Domain();
 	size_t m = Range();
+	size_t K = jac.size();
 # ifndef NDEBUG
-	size_t k, K = jac.size();
+	size_t k;
 	CPPAD_ASSERT_KNOWN(
 		size_t(x.size()) == n ,
 		"SparseJacobianForward: size of x not equal domain dimension for f."
-	); 
+	);
 	CPPAD_ASSERT_KNOWN(
 		size_t(row.size()) == K && size_t(col.size()) == K ,
 		"SparseJacobianForward: either r or c does not have "
 		"the same size as jac."
-	); 
+	);
 	CPPAD_ASSERT_KNOWN(
 		work.color.size() == 0 || work.color.size() == n,
 		"SparseJacobianForward: invalid value in work."
@@ -754,6 +769,10 @@ size_t ADFun<Base>::SparseJacobianForward(
 			"SparseJacobianForward: invalid value in work."
 	);
 # endif
+	// check for case where there is nothing to compute
+	size_t n_sweep = 0;
+	if( K == 0 )
+		return n_sweep;
 
 	typedef typename VectorSet::value_type Set_type;
 	typedef typename internal_sparsity<Set_type>::pattern_type Pattern_type;
@@ -762,7 +781,7 @@ size_t ADFun<Base>::SparseJacobianForward(
 	{	bool transpose = true;
 		sparsity_user2internal(s_transpose, p, m, n, transpose);
 	}
-	size_t n_sweep = SparseJacobianFor(x, s_transpose, row, col, jac, work);
+	n_sweep = SparseJacobianFor(x, s_transpose, row, col, jac, work);
 	return n_sweep;
 }
 /*!
@@ -781,7 +800,7 @@ is the base type for the recording that is stored in this
 is a simple vector class with elements of type \a Base.
 
 \tparam VectorSet
-is a simple vector class with elements of type 
+is a simple vector class with elements of type
 \c bool or \c std::set<size_t>.
 
 \tparam VectorSize
@@ -802,15 +821,15 @@ It must have the same size as \c row.
 
 \param jac [out]
 is the vector of Jacobian values.
-It must have the same size as \c row. 
+It must have the same size as \c row.
 The return value <code>jac[k]</code> is the partial of the
 <code>row[k]</code> range component of the function with respect
 the the <code>col[k]</code> domain component of its argument.
 
 \param work [in,out]
-this structure contains information that depends on the function object, 
+this structure contains information that depends on the function object,
 sparsity pattern, \c row vector, and \c col vector.
-If they are not the same between calls to \c SparseJacobianReverse, 
+If they are not the same between calls to \c SparseJacobianReverse,
 \c work.clear() must be called to reinitialize them.
 
 \return
@@ -831,17 +850,18 @@ size_t ADFun<Base>::SparseJacobianReverse(
 {
 	size_t m = Range();
 	size_t n = Domain();
+	size_t K = jac.size();
 # ifndef NDEBUG
-	size_t k, K = jac.size();
+	size_t k;
 	CPPAD_ASSERT_KNOWN(
 		size_t(x.size()) == n ,
 		"SparseJacobianReverse: size of x not equal domain dimension for f."
-	); 
+	);
 	CPPAD_ASSERT_KNOWN(
 		size_t(row.size()) == K && size_t(col.size()) == K ,
 		"SparseJacobianReverse: either r or c does not have "
 		"the same size as jac."
-	); 
+	);
 	CPPAD_ASSERT_KNOWN(
 		work.color.size() == 0 || work.color.size() == m,
 		"SparseJacobianReverse: invalid value in work."
@@ -862,7 +882,11 @@ size_t ADFun<Base>::SparseJacobianReverse(
 			"SparseJacobianReverse: invalid value in work."
 	);
 # endif
- 
+	// check for case where there is nothing to compute
+	size_t n_sweep = 0;
+	if( K == 0 )
+		return n_sweep;
+
 	typedef typename VectorSet::value_type Set_type;
 	typedef typename internal_sparsity<Set_type>::pattern_type Pattern_type;
 	Pattern_type s;
@@ -870,7 +894,7 @@ size_t ADFun<Base>::SparseJacobianReverse(
 	{	bool transpose = false;
 		sparsity_user2internal(s, p, m, n, transpose);
 	}
-	size_t n_sweep = SparseJacobianRev(x, s, row, col, jac, work);
+	n_sweep = SparseJacobianRev(x, s, row, col, jac, work);
 	return n_sweep;
 }
 /*!
@@ -889,7 +913,7 @@ is the base type for the recording that is stored in this
 is a simple vector class with elements of type \a Base.
 
 \tparam VectorSet
-is a simple vector class with elements of type 
+is a simple vector class with elements of type
 \c bool or \c std::set<size_t>.
 
 \param x [in]
@@ -948,10 +972,10 @@ VectorBase ADFun<Base>::SparseJacobian(
 				k++;
 				i = s_transpose.next_element();
 			}
-		} 
+		}
 		size_t K = k;
 		VectorBase J(K);
-	
+
 		// now we have folded this into the following case
 		SparseJacobianFor(x, s_transpose, row, col, J, work);
 
@@ -976,7 +1000,7 @@ VectorBase ADFun<Base>::SparseJacobian(
 				k++;
 				j = s.next_element();
 			}
-		} 
+		}
 		size_t K = k;
 		VectorBase J(K);
 
@@ -989,7 +1013,7 @@ VectorBase ADFun<Base>::SparseJacobian(
 	}
 
 	return jac;
-} 
+}
 
 /*!
 Compute a sparse Jacobian.
@@ -1027,7 +1051,7 @@ VectorBase ADFun<Base>::SparseJacobian( const VectorBase& x )
 	if( n <= m )
 	{	size_t j, k;
 
-		// use forward mode 
+		// use forward mode
 		VectorBool r(n * n);
 		for(j = 0; j < n; j++)
 		{	for(k = 0; k < n; k++)
@@ -1039,7 +1063,7 @@ VectorBase ADFun<Base>::SparseJacobian( const VectorBase& x )
 	else
 	{	size_t i, k;
 
-		// use reverse mode 
+		// use reverse mode
 		VectorBool s(m * m);
 		for(i = 0; i < m; i++)
 		{	for(k = 0; k < m; k++)
