@@ -1,11 +1,11 @@
-/* $Id: sparse_unary_op.hpp 3301 2014-05-24 05:20:21Z bradbell $ */
-# ifndef CPPAD_SPARSE_UNARY_OP_INCLUDED
-# define CPPAD_SPARSE_UNARY_OP_INCLUDED
+// $Id: sparse_unary_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_SPARSE_UNARY_OP_HPP
+# define CPPAD_SPARSE_UNARY_OP_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -20,7 +20,7 @@ Forward and reverse mode sparsity patterns for unary operators.
 
 
 /*!
-Forward mode Jacobian sparsity pattern for all unary operators. 
+Forward mode Jacobian sparsity pattern for all unary operators.
 
 The C++ source code corresponding to a unary operation has the form
 \verbatim
@@ -37,8 +37,8 @@ is the type used for vectors of sets. It can be either
 \c sparse_pack, \c sparse_set or \c sparse_list.
 
 \param i_z
-variable index corresponding to the result for this operation; 
-i.e., z. 
+variable index corresponding to the result for this operation;
+i.e., z.
 
 \param i_x
 variable index corresponding to the argument for this operator;
@@ -49,17 +49,17 @@ i.e., x.
 \b Input: The set with index \a arg[0] in \a sparsity
 is the sparsity bit pattern for x.
 This identifies which of the independent variables the variable x
-depends on. 
+depends on.
 \n
 \n
 \b Output: The set with index \a i_z in \a sparsity
 is the sparsity bit pattern for z.
 This identifies which of the independent variables the variable z
-depends on. 
+depends on.
 \n
 
 \par Checked Assertions:
-\li \a i_x < \a i_z 
+\li \a i_x < \a i_z
 */
 
 template <class Vector_set>
@@ -67,15 +67,15 @@ inline void forward_sparse_jacobian_unary_op(
 	size_t            i_z           ,
 	size_t            i_x           ,
 	Vector_set&       sparsity      )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( i_x < i_z );
 
 	sparsity.assignment(i_z, i_x, sparsity);
-}	
+}
 
 /*!
-Reverse mode Jacobian sparsity pattern for all unary operators. 
+Reverse mode Jacobian sparsity pattern for all unary operators.
 
 The C++ source code corresponding to a unary operation has the form
 \verbatim
@@ -89,7 +89,7 @@ where op is a C++ bianry operator and q is a parameter.
 
 This routine is given the sparsity patterns
 for a function G(z, y, ... )
-and it uses them to compute the sparsity patterns for 
+and it uses them to compute the sparsity patterns for
 \verbatim
 	H( x , w , u , ... ) = G[ z(x) , x , w , u , ... ]
 \endverbatim
@@ -100,28 +100,28 @@ is the type used for vectors of sets. It can be either
 
 
 \param i_z
-variable index corresponding to the result for this operation; 
-i.e. the row index in sparsity corresponding to z. 
+variable index corresponding to the result for this operation;
+i.e. the row index in sparsity corresponding to z.
 
 \param i_x
 variable index corresponding to the argument for this operator;
 i.e. the row index in sparsity corresponding to x.
 
 \param sparsity
-\b Input: 
-The set with index \a i_z in \a sparsity 
-is the sparsity bit pattern for G with respect to the variable z. 
+\b Input:
+The set with index \a i_z in \a sparsity
+is the sparsity bit pattern for G with respect to the variable z.
 \n
-\b Input: 
+\b Input:
 The set with index \a i_x in \a sparsity
-is the sparsity bit pattern for G with respect to the variable x. 
+is the sparsity bit pattern for G with respect to the variable x.
 \n
-\b Output: 
-The set with index \a i_x in \a sparsity 
+\b Output:
+The set with index \a i_x in \a sparsity
 is the sparsity bit pattern for H with respect to the variable x.
 
 \par Checked Assertions:
-\li \a i_x < \a i_z 
+\li \a i_x < \a i_z
 */
 
 template <class Vector_set>
@@ -129,14 +129,14 @@ inline void reverse_sparse_jacobian_unary_op(
 	size_t     i_z                     ,
 	size_t     i_x                     ,
 	Vector_set&            sparsity    )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( i_x < i_z );
 
 	sparsity.binary_union(i_x, i_x, i_z, sparsity);
 
 	return;
-}	
+}
 
 /*!
 Reverse mode Hessian sparsity pattern for linear unary operators.
@@ -160,7 +160,7 @@ inline void reverse_sparse_hessian_linear_unary_op(
 	bool*               rev_jacobian      ,
 	Vector_set&         for_jac_sparsity  ,
 	Vector_set&         rev_hes_sparsity  )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( i_x < i_z );
 
@@ -193,7 +193,7 @@ inline void reverse_sparse_hessian_nonlinear_unary_op(
 	bool*               rev_jacobian      ,
 	Vector_set&         for_jac_sparsity  ,
 	Vector_set&         rev_hes_sparsity  )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( i_x < i_z );
 
