@@ -1,12 +1,12 @@
-// $Id: std_set.hpp 3232 2014-04-27 15:38:21Z bradbell $
-# ifndef CPPAD_STD_SET_INCLUDED
-# define CPPAD_STD_SET_INCLUDED
+// $Id: std_set.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_STD_SET_HPP
+# define CPPAD_STD_SET_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -16,7 +16,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cppad/local/define.hpp>
 
 // needed before one can use CPPAD_ASSERT_FIRST_CALL_NOT_PARALLEL
-# include <cppad/thread_alloc.hpp>
+# include <cppad/utility/thread_alloc.hpp>
 
 namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 /*!
@@ -34,7 +34,7 @@ const std::set<Scalar>& one_element_std_set(void)
 	if( one.empty() )
 		one.insert(1);
 	return one;
-}  
+}
 /*!
 A standard set with a two elements.
 */
@@ -47,7 +47,7 @@ const std::set<Scalar>& two_element_std_set(void)
 		two.insert(2);
 	}
 	return two;
-}  
+}
 
 } // END_CPPAD_NAMESPACE
 # endif
