@@ -1,12 +1,12 @@
-/* $Id: tanh_op.hpp 3320 2014-09-11 23:06:21Z bradbell $ */
-# ifndef CPPAD_TANH_OP_INCLUDED
-# define CPPAD_TANH_OP_INCLUDED
+// $Id: tanh_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_TANH_OP_HPP
+# define CPPAD_TANH_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -43,9 +43,9 @@ inline void forward_tanh_op(
 	size_t q           ,
 	size_t i_z         ,
 	size_t i_x         ,
-	size_t cap_order   , 
+	size_t cap_order   ,
 	Base*  taylor      )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(TanOp) == 1 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(TanOp) == 2 );
@@ -98,9 +98,9 @@ inline void forward_tanh_op_dir(
 	size_t r           ,
 	size_t i_z         ,
 	size_t i_x         ,
-	size_t cap_order   , 
+	size_t cap_order   ,
 	Base*  taylor      )
-{	
+{
 	// check assumptions
 	CPPAD_ASSERT_UNKNOWN( NumArg(TanOp) == 1 );
 	CPPAD_ASSERT_UNKNOWN( NumRes(TanOp) == 2 );
@@ -146,7 +146,7 @@ template <class Base>
 inline void forward_tanh_op_0(
 	size_t i_z         ,
 	size_t i_x         ,
-	size_t cap_order   , 
+	size_t cap_order   ,
 	Base*  taylor      )
 {
 	// check assumptions
@@ -184,7 +184,7 @@ inline void reverse_tanh_op(
 	size_t      d            ,
 	size_t      i_z          ,
 	size_t      i_x          ,
-	size_t      cap_order    , 
+	size_t      cap_order    ,
 	const Base* taylor       ,
 	size_t      nc_partial   ,
 	Base*       partial      )
@@ -207,6 +207,7 @@ inline void reverse_tanh_op(
 	const Base* y  = z  - cap_order; // called y in documentation
 	Base* py       = pz - nc_partial;
 
+
 	size_t j = d;
 	size_t k;
 	Base base_two(2);
@@ -215,15 +216,15 @@ inline void reverse_tanh_op(
 		px[j]   += pz[j];
 		pz[j]   /= Base(j);
 		for(k = 1; k <= j; k++)
-		{	px[k]   -= pz[j] * y[j-k] * Base(k);
-			py[j-k] -= pz[j] * x[k] * Base(k);
+		{	px[k]   -= azmul(pz[j], y[j-k]) * Base(k);
+			py[j-k] -= azmul(pz[j], x[k]) * Base(k);
 		}
 		for(k = 0; k < j; k++)
-			pz[k] += py[j-1] * z[j-k-1] * base_two;
-	
+			pz[k] += azmul(py[j-1], z[j-k-1]) * base_two;
+
 		--j;
 	}
-	px[0] += pz[0] * (Base(1) - y[0]);
+	px[0] += azmul(pz[0], Base(1) - y[0]);
 }
 
 } // END_CPPAD_NAMESPACE
