@@ -1,12 +1,12 @@
-/* $Id: tape_link.hpp 3232 2014-04-27 15:38:21Z bradbell $ */
-# ifndef CPPAD_TAPE_LINK_INCLUDED
-# define CPPAD_TAPE_LINK_INCLUDED
+// $Id: tape_link.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_TAPE_LINK_HPP
+# define CPPAD_TAPE_LINK_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -14,11 +14,11 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 # include <cppad/local/define.hpp>
-# include <cppad/thread_alloc.hpp>
+# include <cppad/utility/thread_alloc.hpp>
 # include <cppad/local/cppad_assert.hpp>
 
 // needed before one can use CPPAD_ASSERT_FIRST_CALL_NOT_PARALLEL
-# include <cppad/thread_alloc.hpp>
+# include <cppad/utility/thread_alloc.hpp>
 
 namespace CppAD { // BEGIN_CPPAD_NAMESPACE
 /*!
@@ -50,7 +50,7 @@ inline tape_id_t** AD<Base>::tape_id_handle(size_t thread)
 {	CPPAD_ASSERT_FIRST_CALL_NOT_PARALLEL;
 	static tape_id_t* tape_id_table[CPPAD_MAX_NUM_THREADS];
 	CPPAD_ASSERT_UNKNOWN(
-	(! thread_alloc::in_parallel()) || thread == thread_alloc::thread_num() 
+	(! thread_alloc::in_parallel()) || thread == thread_alloc::thread_num()
 	);
 
 	return tape_id_table + thread;
@@ -80,8 +80,8 @@ for the specified thread (it may no longer be recording).
 */
 template <class Base>
 inline tape_id_t* AD<Base>::tape_id_ptr(size_t thread)
-{	CPPAD_ASSERT_UNKNOWN( *tape_id_handle(thread) != CPPAD_NULL ) 	
-	return *tape_id_handle(thread); 
+{	CPPAD_ASSERT_UNKNOWN( *tape_id_handle(thread) != CPPAD_NULL )
+	return *tape_id_handle(thread);
 }
 
 /*!
@@ -130,11 +130,11 @@ recording AD<Base> operations for this thread.
 template <class Base>
 inline ADTape<Base>* AD<Base>::tape_ptr(void)
 {	size_t thread = thread_alloc::thread_num();
-	return *tape_handle(thread); 
+	return *tape_handle(thread);
 }
 
 /*!
-Pointer for the tape for this AD<Base> class and the specified tape 
+Pointer for the tape for this AD<Base> class and the specified tape
 identifier.
 
 \tparam Base
@@ -147,9 +147,9 @@ It must hold that the current thread is
 \code
 	thread = size_t( tape_id % CPPAD_MAX_NUM_THREADS )
 \endcode
-and that there is a tape recording AD<Base> operations 
+and that there is a tape recording AD<Base> operations
 for this thread.
-If this is not the currently executing thread, 
+If this is not the currently executing thread,
 a variable from a different thread is being recorded on the
 tape for this thread which is a user error.
 
@@ -170,7 +170,7 @@ inline ADTape<Base>* AD<Base>::tape_ptr(tape_id_t tape_id)
 	);
 	CPPAD_ASSERT_UNKNOWN( tape_id == *tape_id_ptr(thread) );
 	CPPAD_ASSERT_UNKNOWN( *tape_handle(thread) != CPPAD_NULL );
-	return *tape_handle(thread); 
+	return *tape_handle(thread);
 }
 
 /*!
@@ -189,7 +189,7 @@ is the base type corresponding to AD<Base> operations.
 This argument determines if we are creating a new tape, or deleting an
 old one.
 - \c tape_manage_new :
-Creates and a new tape. 
+Creates and a new tape.
 It is assumed that there is no tape recording AD<Base> operations
 for this thread when \c tape_manage is called.
 It the input value of <tt>*tape_id_handle(thread)</tt> is \c CPPAD_NULL,
@@ -209,46 +209,73 @@ The value of <tt>*tape_id_ptr(thread)</tt> will be advanced by
 */
 template <class Base>
 ADTape<Base>*  AD<Base>::tape_manage(tape_manage_job job)
-{	CPPAD_ASSERT_FIRST_CALL_NOT_PARALLEL
-	static ADTape<Base>* tape_table[CPPAD_MAX_NUM_THREADS];
+{	// this routine has static variables so first call cannot be in parallel
+	CPPAD_ASSERT_FIRST_CALL_NOT_PARALLEL
+
+	// The tape for the master thread
 	static ADTape<Base>  tape_zero;
+
+	// Pointer to the tape for each thread
+	static ADTape<Base>* tape_table[CPPAD_MAX_NUM_THREADS];
+
+	// The id current being used for each of the tapes
 	static tape_id_t     tape_id_save[CPPAD_MAX_NUM_THREADS];
 
+	// Thread corresponding to this call
 	size_t thread        = thread_alloc::thread_num();
+
+	// tape_manage_clear
 	if( job == tape_manage_clear )
-	{	CPPAD_ASSERT_UNKNOWN(thread == 0 && (! thread_alloc::in_parallel()));	
+	{	// This operation cannot be done in parallel
+		CPPAD_ASSERT_UNKNOWN(thread == 0 && (! thread_alloc::in_parallel()));
 		for(thread = 0; thread < CPPAD_MAX_NUM_THREADS; thread++)
-		{	if( tape_table[thread] != CPPAD_NULL )
-			{	tape_id_save[thread]    = tape_table[thread]->id_;
+		{	// if this thread has a tape
+			if( tape_table[thread] != CPPAD_NULL )
+			{	// id corresponding to this thread
+				tape_id_save[thread]    = tape_table[thread]->id_;
 				*tape_id_handle(thread) = &tape_id_save[thread];
 
+				// delete all but the master thread
 				if( thread != 0 )
 					delete( tape_table[thread] );
+
+				// set the tape pointer to null
 				tape_table[thread]   = CPPAD_NULL;
 			}
-		}  
+		}
 		return CPPAD_NULL;
 	}
+
+	// id and tape fpor this thread
 	tape_id_t** tape_id  = tape_id_handle(thread);
 	ADTape<Base>** tape  = tape_handle(thread);
 
+	// check if there is no tape currently attached to this thread
 	if( tape_table[thread] == CPPAD_NULL )
 	{	// allocate separate memroy to avoid false sharing
 		if( thread == 0 )
+		{	// mastert tape is a static in this routine
 			tape_table[thread] = &tape_zero;
-		else	tape_table[thread] = new ADTape<Base>();
+		}
+		else
+		{	// other tapes are allocated
+			tape_table[thread] = new ADTape<Base>();
+		}
+		// current id and pointer to this tape
 		tape_table[thread]->id_ = tape_id_save[thread];
 		*tape_id                = &tape_table[thread]->id_;
 
-		// init tape id > 0 and thread == tape id % CPPAD_MAX_NUM_THREADS
+		// if id is zero, initialize it so that
+		// thread == tape id % CPPAD_MAX_NUM_THREADS
 		if( **tape_id == 0 )
 			**tape_id = thread + CPPAD_MAX_NUM_THREADS;
 	}
 	// make sure tape_id_handle(thread) is pointing to the proper place
 	CPPAD_ASSERT_UNKNOWN( *tape_id == &tape_table[thread]->id_ );
+
 	// make sure tape_id value is valid for this thread
-	CPPAD_ASSERT_UNKNOWN( 
-		size_t( **tape_id % CPPAD_MAX_NUM_THREADS ) == thread 
+	CPPAD_ASSERT_UNKNOWN(
+		size_t( **tape_id % CPPAD_MAX_NUM_THREADS ) == thread
 	);
 
 	switch(job)
@@ -268,7 +295,7 @@ ADTape<Base>*  AD<Base>::tape_manage(tape_manage_job job)
 		);
 		// advance tape identfier so all AD<Base> variables become parameters
 		**tape_id  += CPPAD_MAX_NUM_THREADS;
-		// free memory corresponding to recording in the old tape 
+		// free memory corresponding to recording in the old tape
 		tape_table[thread]->Rec_.free();
 		// inform rest of CppAD that no tape recording for this thread
 		*tape = CPPAD_NULL;
@@ -301,7 +328,7 @@ recording AD<Base> operations for this thread.
 
 template <class Base>
 inline ADTape<Base> *AD<Base>::tape_this(void) const
-{	
+{
 	size_t thread = size_t( tape_id_ % CPPAD_MAX_NUM_THREADS );
 	CPPAD_ASSERT_UNKNOWN( tape_id_ == *tape_id_ptr(thread) );
 	CPPAD_ASSERT_UNKNOWN( *tape_handle(thread) != CPPAD_NULL );
