@@ -1,11 +1,11 @@
-/* $Id: cppad_ipopt_nlp.hpp 2936 2013-10-13 11:44:13Z bradbell $ */
-# ifndef CPPAD_CPPAD_IPOPT_NLP_INCLUDED
-# define CPPAD_CPPAD_IPOPT_NLP_INCLUDED
+// $Id: cppad_ipopt_nlp.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_CPPAD_IPOPT_NLP_HPP
+# define CPPAD_CPPAD_IPOPT_NLP_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -34,18 +34,13 @@ $spell
 	fg_info.eval
 	retape
 	CppAD
-	
+
 $$
 $section Nonlinear Programming Using the CppAD Interface to Ipopt$$
+$mindex AD$$
 
-$index nonlinear, programming CppAD$$
-$index deprecated, ipopt interface$$
-$index programming, nonlinear$$
-$index CppAD, nonlinear programming$$
-$index Ipopt, AD$$
-$index AD, Ipopt$$
 
-$head Deprecated$$
+$head Deprecated 2012-11-28$$
 This interface to Ipopt is deprecated, use $cref ipopt_solve$$ instead.
 
 $head Syntax$$
@@ -64,19 +59,19 @@ The class $code cppad_ipopt_nlp$$ is used to solve nonlinear programming
 problems of the form
 $latex \[
 \begin{array}{rll}
-{\rm minimize}      & f(x) 
+{\rm minimize}      & f(x)
 \\
 {\rm subject \; to} & g^l \leq g(x) \leq g^u
 \\
                     & x^l  \leq x   \leq x^u
 \end{array}
 \] $$
-This is done using 
+This is done using
 $href%
 	http://www.coin-or.org/projects/Ipopt.xml%
 	Ipopt
 %$$
-optimizer and 
+optimizer and
 $href%
 	http://www.coin-or.org/CppAD/%
 	CppAD
@@ -85,14 +80,14 @@ Algorithmic Differentiation package.
 
 $head cppad_ipopt namespace$$
 All of the declarations for these routines
-are in the $code cppad_ipopt$$ namespace 
+are in the $code cppad_ipopt$$ namespace
 (not the $code CppAD$$ namespace).
 For example; $cref/SizeVector/cppad_ipopt_nlp/SizeVector/$$ below
 actually denotes the type $code cppad_ipopt::SizeVector$$.
 
 $head ipopt_library_paths$$
 If you are linking to a shared version of the Ipopt library,
-you may have to add some paths the $code LD_LIBRARY_PATH$$ 
+you may have to add some paths the $code LD_LIBRARY_PATH$$
 shell variable using the $code export$$ command in the syntax above.
 For example, if the file the ipopt library is
 $codei%
@@ -138,8 +133,8 @@ where $latex m > \| I \|$$, we use $latex m \otimes I$$ for
 the mapping $latex ( m \otimes I ): \B{R}^{|I|} \rightarrow \B{R}^m$$ defined by
 $latex \[
 [ m \otimes I ] (y)_i = \left\{ \begin{array}{ll}
-y_k & {\rm if} \; i = I(k) \; {\rm for \; some} \; 
-	k \in \{ 0 , \cdots, |I|-1 \} 
+y_k & {\rm if} \; i = I(k) \; {\rm for \; some} \;
+	k \in \{ 0 , \cdots, |I|-1 \}
 \\
 0   & {\rm otherwise}
 \end{array} \right.
@@ -155,22 +150,22 @@ $pre
 
 $$
 We use the functions
-$latex r_k : \B{R}^{q(k)} \rightarrow \B{R}^{p(k)}$$ 
+$latex r_k : \B{R}^{q(k)} \rightarrow \B{R}^{p(k)}$$
 for $latex k = 0 , \ldots , K$$ to express our
 representation of $latex fg(x)$$ in terms of simpler functions
 as follows
 $latex \[
-fg(x) = \sum_{k=0}^{K-1} \; \sum_{\ell=0}^{L(k) - 1} 
+fg(x) = \sum_{k=0}^{K-1} \; \sum_{\ell=0}^{L(k) - 1}
 [ (m+1) \otimes I_{k,\ell} ] \; \circ
 	 \; r_k \; \circ \; [ J_{k,\ell} \otimes n ] \; (x)
 \] $$
 where $latex \circ$$ represents function composition,
 for $latex k = 0 , \ldots , K - 1$$, and $latex \ell = 0 , \ldots , L(k)$$,
 $latex I_{k,\ell}$$ and  $latex J_{k,\ell}$$ are index vectors with
-$latex | J_{k,\ell} | = q(k)$$, 
+$latex | J_{k,\ell} | = q(k)$$,
 $latex \| J_{k,\ell} \| < n$$,
 $latex | I_{k,\ell} | = p(k)$$, and
-$latex \| I_{k,\ell} \| \leq m$$. 
+$latex \| I_{k,\ell} \| \leq m$$.
 
 $head Simple Representation$$
 In the simple representation,
@@ -183,34 +178,34 @@ $latex I_{0,0} = (0 , \ldots , m)$$,
 and $latex J_{0,0} = (0 , \ldots , n-1)$$.
 
 $head SizeVector$$
-The type $codei SizeVector$$ is defined by the 
-$codei cppad_ipopt_nlp.hpp$$ include file to be a 
+The type $codei SizeVector$$ is defined by the
+$codei cppad_ipopt_nlp.hpp$$ include file to be a
 $cref SimpleVector$$ class with elements of type
 $code size_t$$.
 
 $head NumberVector$$
-The type $codei NumberVector$$ is defined by the 
-$codei cppad_ipopt_nlp.hpp$$ include file to be a 
+The type $codei NumberVector$$ is defined by the
+$codei cppad_ipopt_nlp.hpp$$ include file to be a
 $cref SimpleVector$$ class with elements of type
 $code Ipopt::Number$$.
 
 $head ADNumber$$
-The type $codei ADNumber$$ is defined by the 
-$codei cppad_ipopt_nlp.hpp$$ include file to be a 
+The type $codei ADNumber$$ is defined by the
+$codei cppad_ipopt_nlp.hpp$$ include file to be a
 an AD type that can be used to compute derivatives.
 
 $head ADVector$$
-The type $codei ADVector$$ is defined by the 
-$codei cppad_ipopt_nlp.hpp$$ include file to be a 
+The type $codei ADVector$$ is defined by the
+$codei cppad_ipopt_nlp.hpp$$ include file to be a
 $cref SimpleVector$$ class with elements of type
-$code ADNumber$$. 
+$code ADNumber$$.
 
 $head n$$
 The argument $icode n$$ has prototype
 $codei%
 	size_t %n%
 %$$
-It specifies the dimension of the argument space; 
+It specifies the dimension of the argument space;
 i.e., $latex x \in \B{R}^n$$.
 
 $head m$$
@@ -218,7 +213,7 @@ The argument $icode m$$ has prototype
 $codei%
 	size_t %m%
 %$$
-It specifies the dimension of the range space for $latex g$$; 
+It specifies the dimension of the range space for $latex g$$;
 i.e., $latex g : \B{R}^n \rightarrow \B{R}^m$$.
 
 $head x_i$$
@@ -270,9 +265,9 @@ The argument $icode fg_info$$ has prototype
 $codei%
 	%FG_info fg_info%
 %$$
-where the class $icode FG_info$$ is derived from the 
+where the class $icode FG_info$$ is derived from the
 base class $code cppad_ipopt_fg_info$$.
-Certain virtual member functions of $icode fg_info$$ are used to 
+Certain virtual member functions of $icode fg_info$$ are used to
 compute the value of $latex fg(x)$$.
 The specifications for these member functions are given below:
 
@@ -300,7 +295,7 @@ This member function has the prototype
 $codei%
 virtual ADVector cppad_ipopt_fg_info::eval_r(size_t %k%, const ADVector& %u%) = 0;
 %$$
-Thus it is a pure virtual function and must be defined in the 
+Thus it is a pure virtual function and must be defined in the
 derived class $icode FG_info$$.
 $pre
 
@@ -309,7 +304,7 @@ This function computes the value of $latex r_k (u)$$
 used in the $cref/representation/cppad_ipopt_nlp/fg(x)/Representation/$$
 for $latex fg(x)$$.
 If $icode k$$ in $latex \{0 , \ldots , K-1 \}$$ has type $code size_t$$,
-$icode u$$ is an $code ADVector$$ of size $icode q(k)$$ 
+$icode u$$ is an $code ADVector$$ of size $icode q(k)$$
 and $icode r$$ is an $code ADVector$$ of size $icode p(k)$$
 the syntax
 $codei%
@@ -329,19 +324,19 @@ $codei%
         %retape% = %fg_info%.retape(%k%)
 %$$
 sets $icode retape$$ to true or false.
-If $icode retape$$ is true, 
-$code cppad_ipopt_nlp$$ will retape the operation sequence 
+If $icode retape$$ is true,
+$code cppad_ipopt_nlp$$ will retape the operation sequence
 corresponding to $latex r_k (u)$$ for
-every value of $icode u$$. 
+every value of $icode u$$.
 An $code cppad_ipopt_nlp$$ object
 should use much less memory and run faster if $icode retape$$ is false.
-You can test both the true and false cases to make sure 
+You can test both the true and false cases to make sure
 the operation sequence does not depend on $icode u$$.
 $pre
 
 $$
 The $code cppad_ipopt_fg_info$$ implementation of this function
-sets $icode retape$$ to true 
+sets $icode retape$$ to true
 (while slower it is also safer to always retape).
 
 $subhead fg_info.domain_size$$
@@ -412,38 +407,38 @@ $codei%
 	virtual void cppad_ipopt_fg_info::index(
 		size_t %k%, size_t %ell%, SizeVector& %I%, SizeVector& %J%
 	)
-%$$ 
-The argument 
-$icode% 
+%$$
+The argument
+$icode%
 	k
 %$$
 has type $codei size_t$$
 and is a value between zero and $latex K-1$$ inclusive.
-The argument 
-$icode% 
+The argument
+$icode%
 	ell
 %$$
 has type $codei size_t$$
 and is a value between zero and $latex L(k)-1$$ inclusive.
-The argument 
+The argument
 $icode%
 	I
 %$$ is a $cref SimpleVector$$ with elements
 of type $code size_t$$ and size greater than or equal to $latex p(k)$$.
 The input value of the elements of $icode I$$ does not matter.
 The output value of
-the first $latex p(k)$$ elements of $icode I$$ 
-must be the corresponding elements of $latex I_{k,ell}$$ 
+the first $latex p(k)$$ elements of $icode I$$
+must be the corresponding elements of $latex I_{k,ell}$$
 in the $cref/representation/cppad_ipopt_nlp/fg(x)/Representation/$$ above.
-The argument 
+The argument
 $icode%
 	J
 %$$ is a $cref SimpleVector$$ with elements
 of type $code size_t$$ and size greater than or equal to $latex q(k)$$.
 The input value of the elements of $icode J$$ does not matter.
-The output value of 
-the first $latex q(k)$$ elements of $icode J$$ 
-must be the corresponding elements of $latex J_{k,ell}$$ 
+The output value of
+the first $latex q(k)$$ elements of $icode J$$
+must be the corresponding elements of $latex J_{k,ell}$$
 in the $cref/representation/cppad_ipopt_nlp/fg(x)/Representation/$$ above.
 $pre
 
@@ -464,7 +459,7 @@ The $icode status$$ field of $icode solution$$ has prototype
 $codei%
 	cppad_ipopt_solution::solution_status %solution%.status
 %$$
-It is the final Ipopt status for the optimizer. 
+It is the final Ipopt status for the optimizer.
 Here is a list of the possible values for the status:
 
 $table
@@ -479,7 +474,7 @@ The status returned by the optimizer is not defined in the Ipopt
 documentation for $code finalize_solution$$.
 $rnext
 success $cnext
-Algorithm terminated successfully at a point satisfying the convergence 
+Algorithm terminated successfully at a point satisfying the convergence
 tolerances (see Ipopt options).
 $rnext
 maxiter_exceeded $cnext
@@ -489,8 +484,8 @@ stop_at_tiny_step $cnext
 Algorithm terminated because progress was very slow.
 $rnext
 stop_at_acceptable_point $cnext
-Algorithm stopped at a point that was converged, 
-not to the 'desired' tolerances, but to 'acceptable' tolerances 
+Algorithm stopped at a point that was converged,
+not to the 'desired' tolerances, but to 'acceptable' tolerances
 (see Ipopt options).
 $rnext
 local_infeasibility $cnext
@@ -507,11 +502,11 @@ restoration_failure $cnext
 Restoration phase failed, algorithm doesn't know how to proceed.
 $rnext
 error_in_step_computation $cnext
-An unrecoverable error occurred while Ipopt tried to 
+An unrecoverable error occurred while Ipopt tried to
 compute the search direction.
 $rnext
 invalid_number_detected $cnext
-Algorithm received an invalid number (such as $code nan$$ or $code inf$$) 
+Algorithm received an invalid number (such as $code nan$$ or $code inf$$)
 from the users function $icode%fg_info%.eval%$$ or from the CppAD evaluations
 of its derivatives
 (see the Ipopt option $code check_derivatives_for_naninf$$).
@@ -535,7 +530,7 @@ $codei%
 	NumberVector %solution%.z_l
 %$$
 and its size is equal to $latex n$$.
-It is the final Lagrange multipliers for the 
+It is the final Lagrange multipliers for the
 lower bounds on $latex x$$.
 
 $subhead z_u$$
@@ -544,7 +539,7 @@ $codei%
 	NumberVector %solution%.z_u
 %$$
 and its size is equal to $latex n$$.
-It is the final Lagrange multipliers for the 
+It is the final Lagrange multipliers for the
 upper bounds on $latex x$$.
 
 $subhead g$$
@@ -561,7 +556,7 @@ $codei%
 	NumberVector %solution%.lambda
 %$$
 and its size is equal to $latex m$$.
-It is the final value for the 
+It is the final value for the
 Lagrange multipliers corresponding to the constraint function.
 
 $subhead obj_value$$
@@ -579,21 +574,21 @@ $children%
 %$$
 
 $head Example$$
-The file 
-$cref ipopt_nlp_get_started.cpp$$ is an example and test of 
-$code cppad_ipopt_nlp$$  that uses the 
+The file
+$cref ipopt_nlp_get_started.cpp$$ is an example and test of
+$code cppad_ipopt_nlp$$  that uses the
 $cref/simple representation/cppad_ipopt_nlp/Simple Representation/$$.
 It returns true if it succeeds and false otherwise.
 The section $cref ipopt_nlp_ode$$ discusses an example that
 uses a more complex representation.
 
 $head Wish List$$
-This is a list of possible future improvements to 
+This is a list of possible future improvements to
 $code cppad_ipopt_nlp$$ that would require changed to the user interface:
 $list number$$
-The routine $codei%fg_info.eval_r(%k%, %u%)%$$ should also support 
+The routine $codei%fg_info.eval_r(%k%, %u%)%$$ should also support
 $codei NumberVector$$ for the type of the argument $code u$$
-(this would certainly be more efficient when 
+(this would certainly be more efficient when
 $codei%fg_info.retape(%k%)%$$ is true and $latex L(k) > 1$$).
 It could be an option for the user to provide this as well as
 the necessary $code ADVector$$ definition.
@@ -690,7 +685,7 @@ public:
 Class that contains information about the problem solution
 
 \section Nonlinear_Programming_Problem Nonlinear Programming Problem
-We are give smooth functions 
+We are give smooth functions
 \f$ f : {\bf R}^n \rightarrow {\bf R} \f$
 and
 \f$ g : {\bf R}^n \rightarrow {\bf R}^m \f$
@@ -699,7 +694,7 @@ and wish to solve the problem
 \begin{array}{rcl}
 {\rm minimize} & f(x) & {\rm w.r.t.} \; x \in {\bf R}^n
 \\
-{\rm subject \; to} & g^l \leq g(x) \leq g^u 
+{\rm subject \; to} & g^l \leq g(x) \leq g^u
 \\
 & x^l \leq x \leq x^u
 \end{array}
@@ -707,31 +702,31 @@ and wish to solve the problem
 
 
 \section Users_Representation Users Representation
-The functions 
+The functions
 \f$ f : {\bf R}^n \rightarrow {\bf R} \f$ and
 \f$ g : {\bf R}^n \rightarrow {\bf R}^m \f$ are defined by
 \f[
 \left( \begin{array}{c} f(x) \\ g(x) \end{array} \right)
 =
-\sum_{k=0}^{K-1} \; \sum_{\ell=0}^{L(k) - 1} 
+\sum_{k=0}^{K-1} \; \sum_{\ell=0}^{L(k) - 1}
 [ (m+1) \otimes I_{k,\ell} ] \; \circ
 	 \; r_k \; \circ \; [ J_{k,\ell} \otimes n ] \; (x)
 \f]
 where for \f$ k = 0 , \ldots , K-1\f$,
 \f$ r_k : {\bf R}^{q(k)} \rightarrow {\bf R}^{p(k)} \f$.
 
-\section Evaluation_Methods Evaluation Methods
+\section Deprecated_Evaluation_Methods Evaluation Methods
 The set of evaluation methods for this class is
 \verbatim
 	{ eval_f, eval_grad_f, eval_g, eval_jac_g, eval_h }
 \endverbatim
-Note that the \c bool return flag for the evaluations methods 
+Note that the \c bool return flag for the evaluations methods
 does not appear in the Ipopt documentation.
 Looking at the code, it seems to be a flag telling Ipopt to abort
 when the flag is false.
 
 */
-class cppad_ipopt_solution 
+class cppad_ipopt_solution
 {
 public:
 	/// possible values for he solution status
@@ -769,7 +764,7 @@ public:
 	{	status = not_defined; }
 };
 
-/*! 
+/*!
 Class connects Ipopt to CppAD for derivative and sparsity pattern calculations.
 */
 class cppad_ipopt_nlp : public Ipopt::TNLP
@@ -777,9 +772,9 @@ class cppad_ipopt_nlp : public Ipopt::TNLP
 private:
 	/// A Scalar value used by Ipopt
 	typedef Ipopt::Number                         Number;
-	/// An index value used by Ipopt 
+	/// An index value used by Ipopt
 	typedef Ipopt::Index                          Index;
-	/// Indexing style used in Ipopt sparsity structure 
+	/// Indexing style used in Ipopt sparsity structure
 	typedef Ipopt::TNLP::IndexStyleEnum           IndexStyleEnum;
 	/// A simple vector of boolean values
 	typedef CppAD::vectorBool                     BoolVector;
@@ -792,7 +787,7 @@ private:
 	typedef CppAD::vector< std::map<size_t,size_t> > IndexMap;
 
 	// ------------------------------------------------------------------
- 	// Values directly passed in to constuctor
+	// Values directly passed in to constuctor
 	// ------------------------------------------------------------------
 	/// dimension of the domain space for f(x) and g(x)
 	/// (passed to ctor)
@@ -803,10 +798,10 @@ private:
 	/// dimension of the range space for g(x)
 	/// (passed to ctor)
 	const NumberVector              x_i_;
-	/// lower limit for x 
+	/// lower limit for x
 	/// (size n_), (passed to ctor)
 	const NumberVector              x_l_;
-	/// upper limit for x 
+	/// upper limit for x
 	/// (size n_) (passed to ctor)
 	const NumberVector              x_u_;
 	/// lower limit for g(x)
@@ -815,7 +810,7 @@ private:
 	/// upper limit for g(x)
 	/// (size m_) (passed to ctor)
 	const NumberVector              g_u_;
-	/// pointer to base class version of derived class object used to get 
+	/// pointer to base class version of derived class object used to get
 	/// information about the user's representation for f(x) and g(x)
 	/// (passed to ctor)
 	cppad_ipopt_fg_info* const      fg_info_;
@@ -826,7 +821,7 @@ private:
 	const Number                    infinity_;
 
 	// ------------------------------------------------------------------
-	// Effectively const values determined during constructor using calls 
+	// Effectively const values determined during constructor using calls
 	// to fg_info:
 	// ------------------------------------------------------------------
 	/// The value of \f$ K \f$ in the representation.
@@ -844,25 +839,25 @@ private:
 	/// <tt>L_[k]</tt> is number of times \f$ r_k (u) \f$ appears in
 	/// the representation summation
 	/// (size K_) (effectively const)
-	SizeVector             L_; 
+	SizeVector             L_;
 	// -------------------------------------------------------------------
 	// Other effectively const values determined by the constructor:
 	// -------------------------------------------------------------------
 	/*!
- 	CppAD sparsity patterns for \f$ \{ r_k^{(1)} (u) \} \f$ (set by ctor).
+	CppAD sparsity patterns for \f$ \{ r_k^{(1)} (u) \} \f$ (set by ctor).
 
-	For <tt>k = 0 , ... , K_-1, pattern_jac_r_[k]</tt> 
-	is a CppAD sparsity pattern for the Jacobian of \f$ r_k (u) \f$ 
+	For <tt>k = 0 , ... , K_-1, pattern_jac_r_[k]</tt>
+	is a CppAD sparsity pattern for the Jacobian of \f$ r_k (u) \f$
 	and as such it has size <tt>p_[k]*q_[k]</tt>.
 	(effectively const)
 	*/
 	BoolVectorVector                 pattern_jac_r_;
 
 	/*!
- 	CppAD sparsity patterns for \f$ \{ r_k^{(2)} (u) \} \f$ (set by ctor).
+	CppAD sparsity patterns for \f$ \{ r_k^{(2)} (u) \} \f$ (set by ctor).
 
-	For <tt>k = 0 , ... , K_-1, pattern_jac_r_[k]</tt> 
-	is a CppAD sparsity pattern for the Hessian of 
+	For <tt>k = 0 , ... , K_-1, pattern_jac_r_[k]</tt>
+	is a CppAD sparsity pattern for the Hessian of
 	\f[
 		R(u) = \sum_{i=0}^{p[k]-1}  r_k (u)_i
 	\f]
@@ -896,8 +891,8 @@ private:
 
 	For <tt>i = 0 , ... , m_-1, index_jac_g_[i]</tt>
 	is a standard map from column index values \c j to the corresponding
-	index in the Ipopt sparsity structure for the Jacobian of g(x). 
- 	*/ 
+	index in the Ipopt sparsity structure for the Jacobian of g(x).
+	*/
 	IndexMap                         index_jac_g_;
 
 	/*!
@@ -906,21 +901,21 @@ private:
 	For <tt>i = 0 , ... , n_-1, index_hes_fg_[i]</tt>
 	is a standard map from column index values \c j to the corresponding
 	index in the Ipopt sparsity structure for the Hessian of the Lagragian.
- 	*/ 
+	*/
 	IndexMap                         index_hes_fg_;
 	// -----------------------------------------------------------------
 	// Values that are changed by routine other than the constructor:
 	// -----------------------------------------------------------------
 
-	/// For <tt>k = 0 , ... , K_-1, r_fun_[k]</tt> 
+	/// For <tt>k = 0 , ... , K_-1, r_fun_[k]</tt>
 	/// is a the CppAD function object corresponding to \f$ r_k (u) \f$.
 	ADFunVector                      r_fun_;
 	/*!
- 	Is r_fun[k] OK for current x.
- 
-	For <tt>k = 0 , ... , K_-1, tape_ok_[k]</tt> 
-	is true if current operations sequence in <tt>r_fun_[k]</tt> 
-	OK for this value of \f$ x \f$. 
+	Is r_fun[k] OK for current x.
+
+	For <tt>k = 0 , ... , K_-1, tape_ok_[k]</tt>
+	is true if current operations sequence in <tt>r_fun_[k]</tt>
+	OK for this value of \f$ x \f$.
 	Note that \f$ u = [ J_{k,\ell} \otimes n ] (x) \f$ may depend on the
 	value of \f$ \ell \f$.
 	*/
@@ -929,9 +924,9 @@ private:
 	/// work space of size equal maximum of <tt>q[k]</tt> w.r.t \c k.
 	SizeVector             J_;
 	/// work space of size equal maximum of <tt>p[k]</tt> w.r.t \c k.
-	SizeVector             I_; 
+	SizeVector             I_;
 	// ------------------------------------------------------------
- 	// Private Methods
+	// Private Methods
 	// ------------------------------------------------------------
 	/// block the default constructor from use
 	cppad_ipopt_nlp(const cppad_ipopt_nlp&);
@@ -944,7 +939,7 @@ public:
 
 	/// only constructor for cppad_ipopot_nlp
 	cppad_ipopt_nlp(
-		size_t n                         , 
+		size_t n                         ,
 		size_t m                         ,
 		const NumberVector    &x_i       ,
 		const NumberVector    &x_l       ,
@@ -953,65 +948,65 @@ public:
 		const NumberVector    &g_u       ,
 		cppad_ipopt_fg_info*   fg_info   ,
 		cppad_ipopt_solution*  solution
-  	);
+	);
 
 	// use virtual so that derived class destructor gets called.
 	virtual ~cppad_ipopt_nlp();
 
 	// return info about the nlp
 	virtual bool get_nlp_info(
-		Index&          n           , 
-		Index&          m           , 
+		Index&          n           ,
+		Index&          m           ,
 		Index&          nnz_jac_g   ,
-		Index&          nnz_h_lag   , 
+		Index&          nnz_h_lag   ,
 		IndexStyleEnum& index_style
 	);
 
-	// return bounds for my problem 
+	// return bounds for my problem
 	virtual bool get_bounds_info(
-		Index           n   , 
-		Number*         x_l , 
+		Index           n   ,
+		Number*         x_l ,
 		Number*         x_u ,
-		Index           m   , 
-		Number*         g_l , 
-		Number*         g_u   
+		Index           m   ,
+		Number*         g_l ,
+		Number*         g_u
 	);
 
-	// return the starting point for the algorithm 
+	// return the starting point for the algorithm
 	virtual bool get_starting_point(
-		Index          n            , 
-		bool           init_x       , 
+		Index          n            ,
+		bool           init_x       ,
 		Number*        x            ,
-		bool           init_z       , 
-		Number*        z_L          , 
+		bool           init_z       ,
+		Number*        z_L          ,
 		Number*        z_U          ,
 		Index          m            ,
 		bool           init_lambda  ,
 		Number*        lambda
 	);
 
-	// return the objective value 
+	// return the objective value
 	virtual bool eval_f(
-		Index          n           , 
-		const Number*  x           , 
-		bool           new_x       , 
+		Index          n           ,
+		const Number*  x           ,
+		bool           new_x       ,
 		Number&        obj_value
 	);
 
-	// Method to return the gradient of the objective 
+	// Method to return the gradient of the objective
 	virtual bool eval_grad_f(
-		Index          n           , 
-		const Number*  x           , 
-		bool           new_x       , 
+		Index          n           ,
+		const Number*  x           ,
+		bool           new_x       ,
 		Number*        grad_f
-  	);
+	);
 
 	// return the constraint residuals
 	virtual bool eval_g(
-		Index          n           , 
-		const Number*  x           , 
-		bool           new_x       , 
-		Index          m           , 
+		Index          n           ,
+		const Number*  x           ,
+		bool           new_x       ,
+		Index          m           ,
 		Number*        g
 	);
 
@@ -1019,12 +1014,12 @@ public:
 	// 1) The structure of the jacobian (if "values" is NULL)
 	// 2) The values of the jacobian (if "values" is not NULL)
 	virtual bool eval_jac_g(
-		Index          n           , 
-		const Number*  x           , 
+		Index          n           ,
+		const Number*  x           ,
 		bool           new_x       ,
-		Index          m           , 
-		Index          nele_jac    , 
-		Index*         iRow        , 
+		Index          m           ,
+		Index          nele_jac    ,
+		Index*         iRow        ,
 		Index*         jCol        ,
 		Number*        values
 	);
@@ -1033,29 +1028,29 @@ public:
 	//  1) structure of hessian of the lagrangian (if "values" is NULL)
 	//  2) values of hessian of the lagrangian (if "values" is not NULL)
 	virtual bool eval_h(
-		Index          n           , 
-		const Number*  x           , 
+		Index          n           ,
+		const Number*  x           ,
 		bool           new_x       ,
-		Number         obj_factor  , 
-		Index          m           , 
+		Number         obj_factor  ,
+		Index          m           ,
 		const Number*  lambda      ,
-		bool           new_lambda  , 
-		Index          nele_hess   , 
+		bool           new_lambda  ,
+		Index          nele_hess   ,
 		Index*         iRow        ,
-		Index*         jCol        , 
+		Index*         jCol        ,
 		Number*        values
 	);
 
-	// called when the algorithm is completed so the TNLP can 
-	// store/write the solution 
+	// called when the algorithm is completed so the TNLP can
+	// store/write the solution
 	virtual void finalize_solution(
 		Ipopt::SolverReturn       status      ,
-		Index                      n          , 
-		const Number*              x          , 
-		const Number*              z_L        , 
+		Index                      n          ,
+		const Number*              x          ,
+		const Number*              z_L        ,
 		const Number*              z_U        ,
-		Index                      m          , 
-		const Number*              g          , 
+		Index                      m          ,
+		const Number*              g          ,
 		const Number*              lambda     ,
 		Number                     obj_value  ,
 		const Ipopt::IpoptData*           ip_data    ,
@@ -1064,14 +1059,14 @@ public:
 
 	virtual bool intermediate_callback(
 		Ipopt::AlgorithmMode              mode,
-		Index                             iter, 
+		Index                             iter,
 		Number                            obj_value,
-		Number                            inf_pr, 
+		Number                            inf_pr,
 		Number                            inf_du,
-		Number                            mu, 
+		Number                            mu,
 		Number                            d_norm,
 		Number                            regularization_size,
-		Number                            alpha_du, 
+		Number                            alpha_du,
 		Number                            alpha_pr,
 		Index                             ls_trials,
 		const Ipopt::IpoptData*           ip_data,
