@@ -17,7 +17,7 @@ var list_down2 = [
 'adfun.xml',
 'preprocessor.xml',
 'multi_thread.xml',
-'library.xml',
+'utility.xml',
 'ipopt_solve.xml',
 'example.xml',
 'speed.xml',
@@ -28,7 +28,7 @@ var list_down1 = [
 'cmake.xml',
 'cmake_check.xml',
 'pkgconfig.xml',
-'installunix.xml'
+'auto_tools.xml'
 ];
 var list_down0 = [
 'adolc_prefix.xml',
@@ -43,15 +43,19 @@ var list_current0 = [
 'cmake.xml#The CMake Program',
 'cmake.xml#CMake Command',
 'cmake.xml#CMake Command.Build Directory',
+'cmake.xml#cmake_verbose_makefile',
 'cmake.xml#generator',
-'cmake.xml#cmake_install_prefix',
+'cmake.xml#cppad_prefix',
+'cmake.xml#cppad_postfix',
 'cmake.xml#cmake_install_includedirs',
+'cmake.xml#cmake_install_libdirs',
 'cmake.xml#cmake_install_datadir',
 'cmake.xml#cmake_install_docdir',
-'cmake.xml#cmake_install_libdirs',
-'cmake.xml#cmake_install_postfix',
 'cmake.xml#package_prefix',
 'cmake.xml#cppad_cxx_flags',
+'cmake.xml#cppad_cxx_flags.C++11',
+'cmake.xml#cppad_profile_flag',
+'cmake.xml#cppad_profile_flag.Eigen and Fadbad',
 'cmake.xml#cppad_testvector',
 'cmake.xml#cppad_max_num_threads',
 'cmake.xml#cppad_sparse_list',
@@ -59,7 +63,7 @@ var list_current0 = [
 'cmake.xml#cppad_tape_id_type.cstdint',
 'cmake.xml#cppad_tape_addr_type',
 'cmake.xml#cppad_tape_addr_type.cstdint',
-'cmake.xml#cppad_implicit_ctor_from_any_type'
+'cmake.xml#cppad_deprecated'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
