@@ -36,7 +36,7 @@ var list_down1 = [
 'forward_order.xml',
 'forward_dir.xml',
 'size_order.xml',
-'comparechange.xml',
+'compare_change.xml',
 'capacity_order.xml',
 'number_skip.xml'
 ];
