@@ -18,7 +18,7 @@ var list_down3 = [
 'adfun.xml',
 'preprocessor.xml',
 'multi_thread.xml',
-'library.xml',
+'utility.xml',
 'ipopt_solve.xml',
 'example.xml',
 'speed.xml',
@@ -59,6 +59,7 @@ var list_current0 = [
 'sparse_jacobian.xml#jac',
 'sparse_jacobian.xml#work',
 'sparse_jacobian.xml#work.color_method',
+'sparse_jacobian.xml#work.p',
 'sparse_jacobian.xml#n_sweep',
 'sparse_jacobian.xml#VectorBase',
 'sparse_jacobian.xml#VectorSet',
