@@ -1,9 +1,9 @@
-// $Id: get_started.cpp 3160 2014-03-05 17:04:14Z bradbell $
+// $Id: get_started.cpp 3715 2015-08-30 12:20:43Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -14,9 +14,6 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 $begin atomic_get_started.cpp$$
 
 $section Getting Started with Atomic Operations: Example and Test$$
-$index get_started, atomic operation$$
-$index atomic, get_started $$
-$index operation, atomic get_started$$
 
 $head Purpose$$
 This example demonstrates the minimal amount of information
@@ -36,7 +33,8 @@ $head Constructor$$
 $codep */
 	public:
 	// constructor (could use const char* for name)
-	atomic_get_started(const std::string& name) : 
+	atomic_get_started(const std::string& name) :
+	// this example does not use any sparsity patterns
 	CppAD::atomic_base<double>(name)
 	{ }
 	private:
@@ -108,11 +106,11 @@ $codep */
 	// declare independent variables and start tape recording
 	CppAD::Independent(ax);
 
-	// range space vector 
+	// range space vector
 	size_t m = 1;
 	vector< AD<double> > ay(m);
 
-	// call user function and store get_started(x) in au[0] 
+	// call user function and store get_started(x) in au[0]
 	vector< AD<double> > au(m);
 	afun(ax, au);        // u = 1 / x
 
@@ -125,7 +123,7 @@ $codep */
 /* $$
 $subhead forward$$
 $codep */
-	// check function value 
+	// check function value
 	double check = x0;
 	ok &= NearEqual( Value(ay[0]) , check,  eps, eps);
 
