@@ -1,9 +1,9 @@
-/* $Id: cppad_vector.cpp 3127 2014-02-28 15:28:12Z bradbell $ */
+// $Id: cppad_vector.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -17,11 +17,8 @@ $spell
 $$
 
 $section CppAD::vector Template Class: Example and Test$$
+$mindex vector CppAD$$
 
-$index vector, CppAD$$
-$index CppAD::vector, example$$
-$index example, CppAD::vector$$
-$index test, CppAD::vector$$
 
 $code
 $verbatim%example/cppad_vector.cpp%0%// BEGIN C++%// END C++%1%$$
@@ -31,53 +28,56 @@ $end
 */
 // BEGIN C++
 
-# include <cppad/vector.hpp>
-# include <cppad/check_simple_vector.hpp>
+# include <cppad/utility/vector.hpp>
+# include <cppad/utility/check_simple_vector.hpp>
 # include <sstream> // sstream and string are used to test output operation
 # include <string>
 
 bool CppAD_vector(void)
 {	bool ok = true;
-	using CppAD::vector;     // so can use vector instead of CppAD::vector 
+	using CppAD::vector;     // so can use vector instead of CppAD::vector
 	typedef double Type;     // change double to test other types
 
 	// check Simple Vector specifications
 	CppAD::CheckSimpleVector< Type, vector<Type> >();
 
-	vector<Type> x;          // default constructor 
+	vector<Type> x;          // default constructor
 	ok &= (x.size() == 0);
 
 	x.resize(2);             // resize and set element assignment
 	ok &= (x.size() == 2);
-	x[0] = Type(0);
-	x[1] = Type(1);
+	x[0] = Type(1);
+	x[1] = Type(2);
 
 	vector<Type> y(2);       // sizing constructor
 	ok &= (y.size() == 2);
 
 	const vector<Type> z(x); // copy constructor and const element access
 	ok &= (z.size() == 2);
-	ok &= ( (z[0] == Type(0)) && (z[1] == Type(1)) );
+	ok &= ( (z[0] == Type(1)) && (z[1] == Type(2)) );
 
 	x[0] = Type(2);          // modify, assignment changes x
 	ok &= (x[0] == Type(2));
 
 	x = y = z;               // vector assignment
-	ok &= ( (x[0] == Type(0)) && (x[1] == Type(1)) );
-	ok &= ( (y[0] == Type(0)) && (y[1] == Type(1)) );
-	ok &= ( (z[0] == Type(0)) && (z[1] == Type(1)) );
+	ok &= ( (x[0] == Type(1)) && (x[1] == Type(2)) );
+	ok &= ( (y[0] == Type(1)) && (y[1] == Type(2)) );
+	ok &= ( (z[0] == Type(1)) && (z[1] == Type(2)) );
 
 	// test of output
-	std::string        correct= "{ 0, 1 }";
+	std::string        correct= "{ 1, 2 }";
 	std::string        str;
 	std::ostringstream buf;
 	buf << z;
 	str = buf.str();
 	ok &= (str == correct);
 
-	// test resize(0), capacity, and clear
+	// test resize(1), resize(0), capacity, and clear
 	size_t i = x.capacity();
-	ok      &= i > 0;
+	ok      &= i >= 2;
+	x.resize(1);
+	ok      &= x[0] == Type(1);
+	ok      &= i == x.capacity();
 	x.resize(0);
 	ok      &= i == x.capacity();
 	x.clear();
@@ -86,11 +86,11 @@ bool CppAD_vector(void)
 	// test of push_back scalar and capacity
 	size_t N = 100;
 	for(i = 0; i < N; i++)
-	{	size_t old_capacity = x.capacity();	
+	{	size_t old_capacity = x.capacity();
 		x.push_back( Type(i) );
 		ok &= (i+1) == x.size();
 		ok &= i < x.capacity();
-		ok &= (i == old_capacity) || old_capacity == x.capacity(); 
+		ok &= (i == old_capacity) || old_capacity == x.capacity();
 	}
 	for(i = 0; i < N; i++)
 		ok &= ( x[i] == Type(i) );
@@ -103,7 +103,7 @@ bool CppAD_vector(void)
 		ok &= x[i] == Type(N - i);
 	}
 
-	// test of push_vector 
+	// test of push_vector
 	x.push_vector(x);
 	ok &= (x.size() == 2 * N);
 	for(i = 0; i < N; i++)
