@@ -1,9 +1,9 @@
-/* $Id: example.cpp 3526 2014-12-29 21:56:45Z bradbell $ */
+// $Id: example.cpp 3768 2015-12-28 18:58:35Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -17,8 +17,6 @@ $spell
 $$
 
 $section CppAD Examples and Tests$$
-$index example, CppAD$$
-$index test, CppAD$$
 
 $head Running Tests$$
 To build this program and run its correctness tests see $cref cmake_check$$.
@@ -41,40 +39,47 @@ $end
 # include <string>
 
 // memory utility
-# include <cppad/thread_alloc.hpp>
+# include <cppad/utility/thread_alloc.hpp>
 
 // prototype external compiled tests (this line expected by bin/new_test.sh)
 extern bool abort_recording(void);
 extern bool ad_assign(void);
 extern bool ad_ctor(void);
 extern bool abs(void);
-extern bool Acos(void);
+extern bool acos(void);
+extern bool acosh(void);
 extern bool Add(void);
 extern bool AddEq(void);
 extern bool ad_fun(void);
 extern bool ad_in_c(void);
 extern bool ad_input(void);
 extern bool ad_output(void);
-extern bool Asin(void);
-extern bool Atan(void);
-extern bool Atan2(void);
+extern bool asin(void);
+extern bool asinh(void);
+extern bool atan(void);
+extern bool atanh(void);
+extern bool atan2(void);
+extern bool azmul(void);
 extern bool base_require(void);
 extern bool BenderQuad(void);
 extern bool BoolFun(void);
+extern bool bool_sparsity(void);
 extern bool capacity_order(void);
-extern bool change_const(void);
+extern bool change_param(void);
 extern bool check_for_nan(void);
 extern bool CheckNumericType(void);
 extern bool CheckSimpleVector(void);
-extern bool colpack(void);
+extern bool colpack_hes(void);
+extern bool colpack_jac(void);
 extern bool Compare(void);
-extern bool CompareChange(void);
+extern bool compare_change(void);
 extern bool complex_poly(void);
 extern bool CondExp(void);
 extern bool conj_grad(void);
 extern bool Cos(void);
 extern bool Cosh(void);
 extern bool CppAD_vector(void);
+extern bool dependency(void);
 extern bool Div(void);
 extern bool DivEq(void);
 extern bool eigen_array(void);
@@ -82,7 +87,8 @@ extern bool eigen_det(void);
 extern bool EqualOpSeq(void);
 extern bool Erf(void);
 extern bool ErrorHandler(void);
-extern bool Exp(void);
+extern bool exp(void);
+extern bool expm1(void);
 extern bool ForOne(void);
 extern bool ForTwo(void);
 extern bool ForSparseJac(void);
@@ -105,9 +111,9 @@ extern bool interp_retape(void);
 extern bool JacLuDet(void);
 extern bool JacMinorDet(void);
 extern bool Jacobian(void);
-extern bool limits(void);
-extern bool Log(void);
-extern bool Log10(void);
+extern bool log(void);
+extern bool log10(void);
+extern bool log1p(void);
 extern bool LuFactor(void);
 extern bool LuInvert(void);
 extern bool LuRatio(void);
@@ -124,18 +130,18 @@ extern bool Near_Equal(void);
 extern bool NearEqualExt(void);
 extern bool number_skip(void);
 extern bool NumericType(void);
+extern bool num_limits(void);
 extern bool OdeErrControl(void);
 extern bool OdeErrMaxabs(void);
 extern bool OdeGear(void);
 extern bool OdeGearControl(void);
 extern bool OdeStiff(void);
 extern bool ode_taylor(void);
-extern bool omp_alloc(void);
 extern bool opt_val_hes(void);
 extern bool optimize(void);
 extern bool ParVar(void);
 extern bool Poly(void);
-extern bool Pow(void);
+extern bool pow(void);
 extern bool pow_int(void);
 extern bool print_for(void);
 extern bool reverse_any(void);
@@ -158,14 +164,18 @@ extern bool Sin(void);
 extern bool Sinh(void);
 extern bool sparse_hessian(void);
 extern bool sparse_jacobian(void);
+extern bool sparse_sub_hes(void);
+extern bool sparsity_sub(void);
 extern bool Sqrt(void);
 extern bool StackMachine(void);
 extern bool Sub(void);
 extern bool SubEq(void);
+extern bool sub_sparse_hes(void);
 extern bool Tan(void);
 extern bool Tanh(void);
 extern bool TapeIndex(void);
 extern bool thread_alloc(void);
+extern bool to_string(void);
 extern bool UnaryMinus(void);
 extern bool UnaryPlus(void);
 extern bool Value(void);
@@ -179,7 +189,7 @@ namespace {
 	static size_t Run_error_count = 0;
 	bool Run(bool TestOk(void), std::string name)
 	{	bool ok      = true;
-		std::streamsize width =  20;         
+		std::streamsize width =  20;
 		std::cout.width( width );
 		std::cout.setf( std::ios_base::left );
 		std::cout << name;
@@ -209,42 +219,49 @@ int main(void)
 	ok &= Run( ad_assign,         "ad_assign"        );
 	ok &= Run( ad_ctor,           "ad_ctor"          );
 	ok &= Run( abs,               "abs"              );
-	ok &= Run( Acos,              "Acos"             );
+	ok &= Run( acos,              "acos"             );
+	ok &= Run( acosh,             "acosh"            );
 	ok &= Run( Add,               "Add"              );
 	ok &= Run( AddEq,             "AddEq"            );
 	ok &= Run( ad_fun,            "ad_fun"           );
 	ok &= Run( ad_in_c,           "ad_in_c"          );
 	ok &= Run( ad_input,          "ad_input"         );
 	ok &= Run( ad_output,         "ad_output"        );
-	ok &= Run( Asin,              "Asin"             );
-	ok &= Run( Atan,              "Atan"             );
-	ok &= Run( Atan2,             "Atan2"            );
+	ok &= Run( asin,              "asin"             );
+	ok &= Run( asinh,             "asinh"            );
+	ok &= Run( atan,              "atan"             );
+	ok &= Run( atanh,             "atanh"            );
+	ok &= Run( atan2,             "atan2"            );
+	ok &= Run( azmul,             "azmul"            );
 	ok &= Run( BenderQuad,        "BenderQuad"       );
 	ok &= Run( BoolFun,           "BoolFun"          );
+	ok &= Run( bool_sparsity,     "bool_sparsity"    );
 	ok &= Run( capacity_order,    "capacity_order"   );
-	ok &= Run( change_const,      "change_const"     );
+	ok &= Run( change_param,      "change_param"     );
 	ok &= Run( check_for_nan,     "check_for_nan"    );
 	ok &= Run( CheckNumericType,  "CheckNumericType" );
 	ok &= Run( CheckSimpleVector, "CheckSimpleVector");
 	ok &= Run( Compare,           "Compare"          );
-	ok &= Run( CompareChange,     "CompareChange"    );
+	ok &= Run( compare_change,    "compare_change"   );
 	ok &= Run( complex_poly,      "complex_poly"     );
 	ok &= Run( CondExp,           "CondExp"          );
 	ok &= Run( conj_grad,         "conj_grad"        );
 	ok &= Run( Cos,               "Cos"              );
 	ok &= Run( Cosh,              "Cosh"             );
 	ok &= Run( CppAD_vector,      "CppAD_vector"     );
+	ok &= Run( dependency,        "dependency"       );
 	ok &= Run( Div,               "Div"              );
 	ok &= Run( DivEq,             "DivEq"            );
 	ok &= Run( EqualOpSeq,        "EqualOpSeq"       );
 	ok &= Run( Erf,               "Erf"              );
 	ok &= Run( ErrorHandler,      "ErrorHandler"     );
-	ok &= Run( Exp,               "Exp"              );
+	ok &= Run( exp,               "exp"              );
+	ok &= Run( expm1,             "expm1"            );
 	ok &= Run( ForOne,            "ForOne"           );
 	ok &= Run( ForTwo,            "ForTwo"           );
-	ok &= Run( Forward,           "Forward"          ); 
-	ok &= Run( forward_dir,       "forward_dir"      ); 
-	ok &= Run( forward_order,     "forward_order"    ); 
+	ok &= Run( Forward,           "Forward"          );
+	ok &= Run( forward_dir,       "forward_dir"      );
+	ok &= Run( forward_order,     "forward_order"    );
 	ok &= Run( ForSparseJac,      "ForSparseJac"     );
 	ok &= Run( fun_assign,        "fun_assign"       );
 	ok &= Run( FunCheck,          "FunCheck"         );
@@ -262,9 +279,9 @@ int main(void)
 	ok &= Run( JacLuDet,          "JacLuDet"         );
 	ok &= Run( JacMinorDet,       "JacMinorDet"      );
 	ok &= Run( Jacobian,          "Jacobian"         );
-	ok &= Run( limits,            "limits"           );
-	ok &= Run( Log,               "Log"              );
-	ok &= Run( Log10,             "Log10"            );
+	ok &= Run( log,               "log"              );
+	ok &= Run( log10,             "log10"            );
+	ok &= Run( log1p,             "log1p"            );
 	ok &= Run( LuFactor,          "LuFactor"         );
 	ok &= Run( LuInvert,          "LuInvert"         );
 	ok &= Run( LuRatio,           "LuRatio"          );
@@ -279,18 +296,18 @@ int main(void)
 	ok &= Run( NearEqualExt,      "NearEqualExt"     );
 	ok &= Run( number_skip,       "number_skip"      );
 	ok &= Run( NumericType,       "NumericType"      );
+	ok &= Run( num_limits,        "num_limits"       );
 	ok &= Run( OdeErrControl,     "OdeErrControl"    );
 	ok &= Run( OdeErrMaxabs,      "OdeErrMaxabs"     );
 	ok &= Run( OdeGear,           "OdeGear"          );
 	ok &= Run( OdeGearControl,    "OdeGearControl"   );
 	ok &= Run( OdeStiff,          "OdeStiff"         );
 	ok &= Run( ode_taylor,        "ode_taylor"       );
-	ok &= Run( omp_alloc,         "omp_alloc"        );
 	ok &= Run( opt_val_hes,       "opt_val_hes"      );
 	ok &= Run( optimize,          "optimize"         );
 	ok &= Run( ParVar,            "ParVar"           );
-	ok &= Run( Pow,               "Poly"             );
-	ok &= Run( Pow,               "Pow"              );
+	ok &= Run( Poly,              "Poly"             );
+	ok &= Run( pow,               "pow"              );
 	ok &= Run( pow_int,           "pow_int"          );
 	ok &= Run( reverse_any,       "reverse_any"      );
 	ok &= Run( reverse_one,       "reverse_one"      );
@@ -312,14 +329,18 @@ int main(void)
 	ok &= Run( Sinh,              "Sinh"             );
 	ok &= Run( sparse_hessian,    "sparse_hessian"   );
 	ok &= Run( sparse_jacobian,   "sparse_jacobian"  );
+	ok &= Run( sparse_sub_hes,    "sparse_sub_hes"   );
+	ok &= Run( sparsity_sub,      "sparsity_sub"     );
 	ok &= Run( Sqrt,              "Sqrt"             );
 	ok &= Run( StackMachine,      "StackMachine"     );
 	ok &= Run( Sub,               "Sub"              );
 	ok &= Run( SubEq,             "SubEq"            );
+	ok &= Run( sub_sparse_hes,    "sub_sparse_hes"   );
 	ok &= Run( Tan,               "Tan"              );
 	ok &= Run( Tanh,              "Tanh"             );
 	ok &= Run( TapeIndex,         "TapeIndex"        );
 	ok &= Run( thread_alloc,      "thread_alloc"     );
+	ok &= Run( to_string,         "to_string"        );
 	ok &= Run( UnaryMinus,        "UnaryMinus"       );
 	ok &= Run( UnaryPlus,         "UnaryPlus"        );
 	ok &= Run( Value,             "Value"            );
@@ -331,7 +352,8 @@ int main(void)
 	ok &= Run( mul_level_adolc_ode,  "mul_level_adolc_ode" );
 # endif
 # ifdef CPPAD_COLPACK_EXAMPLES
-	ok &= Run( colpack,           "colpack"          );
+	ok &= Run( colpack_hes,       "colpack_hes"      );
+	ok &= Run( colpack_jac,       "colpack_jac"      );
 # endif
 # ifdef CPPAD_EIGEN_EXAMPLES
 	ok &= Run( eigen_array,       "eigen_array"      );
