@@ -1,9 +1,9 @@
-/* $Id: nan.cpp 2765 2013-03-03 15:48:35Z bradbell $ */
+// $Id: nan.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -15,9 +15,6 @@ $begin nan.cpp$$
 
 $section nan: Example and Test$$
 
-$index nan, example$$
-$index example, nan$$
-$index test, nan$$
 
 $code
 $verbatim%example/nan.cpp%0%// BEGIN C++%// END C++%1%$$
@@ -26,28 +23,17 @@ $$
 $end
 */
 
-// these definitions will be erased when nan.hpp is included
-# ifdef nan
-# else
-# define nan(z)   Error_if_this_symbol_gets_used
-# endif
-# ifdef isnan
-# else
-# define isnan(z) Error_if_this_symbol_gets_used
-# endif
-
-
-
 // BEGIN C++
-# include <cppad/nan.hpp>
+# include <cppad/utility/nan.hpp>
 # include <vector>
+# include <limits>
 
 bool nan(void)
 {	bool ok = true;
 
 	// get a nan
 	double double_zero = 0.;
-	double double_nan = CppAD::nan(double_zero);
+	double double_nan = std::numeric_limits<double>::quiet_NaN();
 
 	// create a simple vector with no nans
 	std::vector<double> v(2);
