@@ -1,9 +1,9 @@
-/* $Id: poly.cpp 2506 2012-10-24 19:36:49Z bradbell $ */
+// $Id: poly.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -15,9 +15,6 @@ $begin poly.cpp$$
 
 $section Polynomial Evaluation: Example and Test$$
 
-$index polynomial, example$$
-$index example, polynomial$$
-$index test, polynomial$$
 
 $code
 $verbatim%example/poly.cpp%0%// BEGIN C++%// END C++%1%$$
@@ -36,7 +33,7 @@ bool Poly(void)
 	// degree of the polynomial
 	size_t deg = 3;
 
-	// set the polynomial coefficients 
+	// set the polynomial coefficients
 	CPPAD_TESTVECTOR(double)   a(deg + 1);
 	size_t i;
 	for(i = 0; i <= deg; i++)
@@ -51,8 +48,8 @@ bool Poly(void)
 	// evaluate derivative
 	k = 1;
 	p = CppAD::Poly(k, a, z);
-	ok &= (p == 1 + 2.*z + 3.*z*z); 
-	
+	ok &= (p == 1 + 2.*z + 3.*z*z);
+
 	return ok;
 }
 
