@@ -1,9 +1,9 @@
-/* $Id: exp_2_for0.cpp 2506 2012-10-24 19:36:49Z bradbell $ */
+// $Id: exp_2_for0.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-07 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -20,10 +20,8 @@ $spell
 $$
 
 $section exp_2: Verify Zero Order Forward Sweep$$
+$mindex exp_2$$
 
-$index zero, order exp_2$$
-$index order, zero exp_2$$
-$index exp_2, zero order$$
 
 
 $codep */
