@@ -1,11 +1,11 @@
-/* $Id: multi_newton.hpp 2506 2012-10-24 19:36:49Z bradbell $ */
-# ifndef CPPAD_MULTI_NEWTON_INCLUDED
-# define CPPAD_MULTI_NEWTON_INCLUDED
+// $Id: multi_newton.hpp 3757 2015-11-30 12:03:07Z bradbell $
+# ifndef CPPAD_MULTI_NEWTON_HPP
+# define CPPAD_MULTI_NEWTON_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -13,12 +13,12 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 extern bool multi_newton(
-	CppAD::vector<double> &xout                , 
-	void fun(double x, double& f, double& df)  , 
-	size_t num_sub                             , 
-	double xlow                                , 
-	double xup                                 , 
-	double epsilon                             , 
+	CppAD::vector<double> &xout                ,
+	void fun(double x, double& f, double& df)  ,
+	size_t num_sub                             ,
+	double xlow                                ,
+	double xup                                 ,
+	double epsilon                             ,
 	size_t max_itr                             ,
 	size_t num_threads
 );
