@@ -1,9 +1,9 @@
-/* $Id: print_for.cpp 3114 2014-02-22 16:20:39Z bradbell $ */
+// $Id: print_for.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -32,10 +32,8 @@ $spell
 $$
 
 $section Printing During Forward Mode: Example and Test$$
+$mindex mode print$$
 
-$index forward, mode print$$
-$index example, print forward mode$$
-$index print, example forward mode$$
 
 $head Running$$
 To build this program and run its correctness test see $cref cmake_check$$.
@@ -44,7 +42,7 @@ $head Source Code$$
 $codep */
 # include <cppad/cppad.hpp>
 
-namespace { 
+namespace {
 	using std::cout;
 	using std::endl;
 	using CppAD::AD;
@@ -59,7 +57,7 @@ namespace {
 		PrintFor(y, "check_log: y == ", y , " which is <= 0\n");
 
 		return log(y);
-	} 
+	}
 }
 
 void print_for(void)
@@ -75,11 +73,11 @@ void print_for(void)
 	CppAD::VecAD<double> av(1);
 	AD<double> Zero(0);
 	av[Zero] = 0.;
-	PrintFor("v[0] = ", av[Zero]); 
+	PrintFor("v[0] = ", av[Zero]);
 
 	// Print a newline to separate this from previous output,
 	// then print an AD<double> object that is a variable.
-	PrintFor("\nv[0] + x[0] = ", av[0] + ax[0]); 
+	PrintFor("\nv[0] + x[0] = ", av[0] + ax[0]);
 
 	// A conditional print that will not generate output when x[0] = 2.
 	PrintFor(ax[0], "\n  2. + x[0] = ",   2. + ax[0], "\n");
@@ -91,25 +89,25 @@ void print_for(void)
 	AD<double> var     = 2. - ax[0];
 	AD<double> log_var = check_log(var);
 
-	// dependent variable vector 
+	// dependent variable vector
 	size_t m = 2;
 	CPPAD_TESTVECTOR(AD<double>) ay(m);
 	ay[0] = av[Zero] + ax[0];
 
 	// define f: x -> y and stop tape recording
-	CppAD::ADFun<double> f(ax, ay); 
+	CppAD::ADFun<double> f(ax, ay);
 
-	// zero order forward with x[0] = 2 
+	// zero order forward with x[0] = 2
 	CPPAD_TESTVECTOR(double) x(n);
 	x[0] = 2.;
 
-	cout << "v[0] = 0" << endl; 
-	cout << "v[0] + x[0] = 2" << endl; 
-	cout << "  3. + x[0] = 5" << endl; 
+	cout << "v[0] = 0" << endl;
+	cout << "v[0] + x[0] = 2" << endl;
+	cout << "  3. + x[0] = 5" << endl;
 	cout << "check_log: y == 0 which is <= 0" << endl;
 	// ./makefile.am expects "Test passes" at beginning of next output line
 	cout << "Test passes if four lines above repeat below:" << endl;
-	f.Forward(0, x);	
+	f.Forward(0, x);
 
 	return;
 }
