@@ -1,18 +1,18 @@
-/* $Id: adolc_alloc_mat.hpp 3275 2014-05-20 17:35:11Z bradbell $ */
+// $Id: adolc_alloc_mat.hpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
-# ifndef CPPAD_ADOLC_ALLOC_MAT_INCLUDED
-# define CPPAD_ADOLC_ALLOC_MAT_INCLUDED
+# ifndef CPPAD_ADOLC_ALLOC_MAT_HPP
+# define CPPAD_ADOLC_ALLOC_MAT_HPP
 
 double** adolc_alloc_mat(size_t m, size_t n);
 void adolc_free_mat(double** mat);
 
-# endif 
+# endif
