@@ -1,9 +1,9 @@
-/* $Id: det_lu.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: det_lu.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -30,14 +30,8 @@ $spell
 $$
 
 $section Adolc Speed: Gradient of Determinant Using Lu Factorization$$
+$mindex link_det_lu speed matrix factor$$
 
-$index link_det_lu, adolc$$
-$index adolc, link_det_lu$$
-$index speed, adolc$$
-$index adolc, speed$$
-$index lu, speed adolc$$
-$index matrix, factor speed adolc$$
-$index factor, matrix speed adolc$$
 
 $head Specifications$$
 See $cref link_det_lu$$.
@@ -48,14 +42,14 @@ $codep */
 
 # include <cppad/speed/det_by_lu.hpp>
 # include <cppad/speed/uniform_01.hpp>
-# include <cppad/track_new_del.hpp>
+# include <cppad/utility/track_new_del.hpp>
 
 // list of possible options
 extern bool global_memory, global_onetape, global_atomic, global_optimize;
 
 bool link_det_lu(
-	size_t                     size     , 
-	size_t                     repeat   , 
+	size_t                     size     ,
+	size_t                     repeat   ,
 	CppAD::vector<double>     &matrix   ,
 	CppAD::vector<double>     &gradient )
 {
@@ -89,8 +83,8 @@ bool link_det_lu(
 	// AD version of matrix
 	size_min    = n;
 	ADVector A  = thread_alloc::create_array<ADScalar>(size_min, size_out);
-	
-	// vectors of reverse mode weights 
+
+	// vectors of reverse mode weights
 	size_min    = m;
 	double* u   = thread_alloc::create_array<double>(size_min, size_out);
 	u[0] = 1.;
