@@ -1,9 +1,9 @@
-/* $Id: mat_mul.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: mat_mul.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -28,13 +28,8 @@ $spell
 $$
 
 $section Adolc Speed: Matrix Multiplication$$
+$mindex link_mat_mul speed multiply$$
 
-$index link_mat_mul, adolc$$
-$index adolc, link_mat_mul$$
-$index speed, adolc$$
-$index adolc, speed$$
-$index matrix, speed adolc$$
-$index multiply, speed adolc$$
 
 $head Specifications$$
 See $cref link_mat_mul$$.
@@ -43,17 +38,17 @@ $head Implementation$$
 
 $codep */
 # include <adolc/adolc.h>
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 # include <cppad/speed/mat_sum_sq.hpp>
 # include <cppad/speed/uniform_01.hpp>
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 
 // list of possible options
 extern bool global_memory, global_onetape, global_atomic, global_optimize;
 
 bool link_mat_mul(
-	size_t                           size     , 
-	size_t                           repeat   , 
+	size_t                           size     ,
+	size_t                           repeat   ,
 	CppAD::vector<double>&           x        ,
 	CppAD::vector<double>&           z        ,
 	CppAD::vector<double>&           dz       )
@@ -139,7 +134,7 @@ bool link_mat_mul(
 
 			// evaluate the determinant at the new matrix value
 			keep = 1; // keep this forward mode result
-			zos_forward(tag, m, n, keep, mat, &f); 
+			zos_forward(tag, m, n, keep, mat, &f);
 
 			// evaluate and return gradient using reverse mode
 			fos_reverse(tag, m, n, u, grad);
