@@ -1,9 +1,9 @@
-/* $Id: ode.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: ode.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -26,12 +26,8 @@ $spell
 $$
 
 $section Adolc Speed: Ode$$
+$mindex link_ode speed$$
 
-$index link_ode, adolc$$
-$index adolc, link_ode$$
-$index speed, adolc$$
-$index adolc, speed$$
-$index ode, speed adolc$$
 
 $head Specifications$$
 See $cref link_ode$$.
@@ -41,7 +37,7 @@ $head Implementation$$
 $codep */
 # include <adolc/adolc.h>
 
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 # include <cppad/speed/ode_evaluate.hpp>
 # include <cppad/speed/uniform_01.hpp>
 
@@ -94,7 +90,7 @@ bool link_ode(
 
 	// -------------------------------------------------------------
 	if( ! global_onetape ) while(repeat--)
-	{ 	// choose next x value
+	{	// choose next x value
 		uniform_01(n, x);
 
 		// declare independent variables
@@ -116,7 +112,7 @@ bool link_ode(
 		jacobian(tag, m, n, x_raw, jac_ptr);
 	}
 	else
-	{ 	// choose next x value
+	{	// choose next x value
 		uniform_01(n, x);
 
 		// declare independent variables
