@@ -1,9 +1,9 @@
-/* $Id: poly.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: poly.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -35,12 +35,8 @@ $spell
 $$
 
 $section Adolc Speed: Second Derivative of a Polynomial$$
+$mindex link_poly speed$$
 
-$index link_poly, adolc$$
-$index adolc, link_poly$$
-$index speed, adolc$$
-$index adolc, speed$$
-$index polynomial, speed adolc$$
 
 $head Specifications$$
 See $cref link_poly$$.
@@ -52,20 +48,20 @@ $codep */
 # include <adolc/adolc.h>
 
 # include <cppad/speed/uniform_01.hpp>
-# include <cppad/poly.hpp>
-# include <cppad/vector.hpp>
-# include <cppad/thread_alloc.hpp>
+# include <cppad/utility/poly.hpp>
+# include <cppad/utility/vector.hpp>
+# include <cppad/utility/thread_alloc.hpp>
 # include "adolc_alloc_mat.hpp"
 
 // list of possible options
 extern bool global_memory, global_onetape, global_atomic, global_optimize;
 
 bool link_poly(
-	size_t                     size     , 
-	size_t                     repeat   , 
+	size_t                     size     ,
+	size_t                     repeat   ,
 	CppAD::vector<double>     &a        ,  // coefficients of polynomial
 	CppAD::vector<double>     &z        ,  // polynomial argument value
-	CppAD::vector<double>     &ddp      )  // second derivative w.r.t z  
+	CppAD::vector<double>     &ddp      )  // second derivative w.r.t z
 {
 	if( global_atomic )
 		return false;
@@ -78,7 +74,7 @@ bool link_poly(
 	int keep = 0;  // do not keep forward mode results in buffer
 	int m    = 1;  // number of dependent variables
 	int n    = 1;  // number of independent variables
-	int d    = 2;  // highest derivative degree 
+	int d    = 2;  // highest derivative degree
 	double f;      // function value
 
 	// set up for thread_alloc memory allocator (fast and checks for leaks)
@@ -113,9 +109,9 @@ bool link_poly(
 
 		// declare independent variables
 		trace_on(tag, keep);
-		Z <<= z[0]; 
+		Z <<= z[0];
 
-		// AD computation of the function value 
+		// AD computation of the function value
 		P = CppAD::Poly(0, A, Z);
 
 		// create function object f : Z -> P
@@ -138,9 +134,9 @@ bool link_poly(
 
 		// declare independent variables
 		trace_on(tag, keep);
-		Z <<= z[0]; 
+		Z <<= z[0];
 
-		// AD computation of the function value 
+		// AD computation of the function value
 		P = CppAD::Poly(0, A, Z);
 
 		// create function object f : Z -> P
