@@ -1,9 +1,9 @@
-/* $Id: sparse_hessian.cpp 3136 2014-03-02 11:54:07Z bradbell $ */
+// $Id: sparse_hessian.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -16,7 +16,7 @@ $spell
 	boolsparsity
 	onetape
 	hess
-	int int_n
+	int
 	nnz
 	cind
 	const
@@ -34,13 +34,8 @@ $spell
 $$
 
 $section Adolc Speed: Sparse Hessian$$
+$mindex link_sparse_hessian speed$$
 
-$index link_sparse_hessian, adolc$$
-$index adolc, link_sparse_hessian$$
-$index speed, adolc$$
-$index adolc, speed$$
-$index sparse, speed adolc$$
-$index hessian, speed adolc$$
 
 $head Specifications$$
 See $cref link_sparse_hessian$$.
@@ -50,9 +45,9 @@ $head Implementation$$
 $codep */
 # include <adolc/adolc.h>
 # include <adolc/adolc_sparse.h>
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 # include <cppad/speed/uniform_01.hpp>
-# include <cppad/thread_alloc.hpp>
+# include <cppad/utility/thread_alloc.hpp>
 # include <cppad/speed/sparse_hes_fun.hpp>
 
 // list of possible options
@@ -60,15 +55,16 @@ extern bool global_memory, global_onetape, global_atomic, global_optimize;
 extern bool global_colpack, global_boolsparsity;
 
 bool link_sparse_hessian(
-	size_t                           size     , 
-	size_t                           repeat   , 
+	size_t                           size     ,
+	size_t                           repeat   ,
 	const CppAD::vector<size_t>&     row      ,
 	const CppAD::vector<size_t>&     col      ,
-	      CppAD::vector<double>&     x_return ,
-	      CppAD::vector<double>&     hessian  )
+	CppAD::vector<double>&           x_return ,
+	CppAD::vector<double>&           hessian  ,
+	size_t&                          n_sweep )
 {
 	if( global_atomic || (! global_colpack) )
-		return false; 
+		return false;
 	if( global_memory || global_optimize || global_boolsparsity )
 		return false;
 	// -----------------------------------------------------
@@ -79,7 +75,7 @@ bool link_sparse_hessian(
 	typedef ADScalar*        ADVector;
 
 
-	size_t i, j;         // temporary indices
+	size_t i, j, k;         // temporary indices
 	size_t order = 0;    // derivative order corresponding to function
 	size_t m = 1;        // number of dependent variables
 	size_t n = size;     // number of independent variables
@@ -94,9 +90,9 @@ bool link_sparse_hessian(
 	ADVector a_x = thread_alloc::create_array<ADScalar>(n, capacity);
 	// AD range space vector
 	ADVector a_y = thread_alloc::create_array<ADScalar>(m, capacity);
-	// double argument value 
+	// double argument value
 	DblVector x = thread_alloc::create_array<double>(n, capacity);
-	// double function value 
+	// double function value
 	double f;
 
 	// options that control sparse_hess
@@ -110,26 +106,21 @@ bool link_sparse_hessian(
 	SizeVector cind   = CPPAD_NULL;   // column indices
 	DblVector  values = CPPAD_NULL;   // Hessian values
 
-	// initialize all entries as zero
-	for(i = 0; i < m; i++)
-	{	for(j = 0; j < n; j++)
-			hessian[ i * n + j ] = 0.;
-	}
 	// ----------------------------------------------------------------------
 	if( ! global_onetape ) while(repeat--)
 	{	// choose a value for x
 		CppAD::uniform_01(n, x);
 
 		// declare independent variables
-		int keep = 0; // keep forward mode results 
+		int keep = 0; // keep forward mode results
 		trace_on(tag, keep);
 		for(j = 0; j < n; j++)
 			a_x[j] <<= x[j];
 
-		// AD computation of f (x) 
+		// AD computation of f (x)
 		CppAD::sparse_hes_fun<ADScalar>(n, a_x, row, col, order, a_y);
 
-		// create function object f : x -> y 
+		// create function object f : x -> y
 		a_y[0] >>= f;
 		trace_off();
 
@@ -140,13 +131,20 @@ bool link_sparse_hessian(
 		rind   = CPPAD_NULL;
 		cind   = CPPAD_NULL;
 		values = CPPAD_NULL;
-		sparse_hess(tag, int(n), 
+		sparse_hess(tag, int(n),
 			same_pattern, x, &nnz, &rind, &cind, &values, options
 		);
-		int int_n = int(n);
-		for(int k = 0; k < nnz; k++)
-		{	hessian[ rind[k] * int_n + cind[k] ] = values[k];
-			hessian[ cind[k] * int_n + rind[k] ] = values[k];
+		// only needed last time through loop
+		if( repeat == 0 )
+		{	size_t K = row.size();
+			for(int ell = 0; ell < nnz; ell++)
+			{	i = size_t(rind[ell]);
+				j = size_t(cind[ell]);
+				for(k = 0; k < K; k++)
+				{	if( (row[k]==i && col[k]==j) || (row[k]==j && col[k]==i) )
+						hessian[k] = values[ell];
+				}
+			}
 		}
 
 		// free raw memory allocated by sparse_hess
@@ -159,12 +157,12 @@ bool link_sparse_hessian(
 		CppAD::uniform_01(n, x);
 
 		// declare independent variables
-		int keep = 0; // keep forward mode results 
+		int keep = 0; // keep forward mode results
 		trace_on(tag, keep);
 		for(j = 0; j < n; j++)
 			a_x[j] <<= x[j];
 
-		// AD computation of f (x) 
+		// AD computation of f (x)
 		CppAD::sparse_hes_fun<ADScalar>(n, a_x, row, col, order, a_y);
 
 		// create function object f : x -> y
@@ -179,27 +177,33 @@ bool link_sparse_hessian(
 			CppAD::uniform_01(n, x);
 
 			// calculate the hessian at this x
-			sparse_hess(tag, int(n), 
+			sparse_hess(tag, int(n),
 				same_pattern, x, &nnz, &rind, &cind, &values, options
 			);
 			same_pattern = 1;
 		}
-		int int_n = int(n);
-		for(int k = 0; k < nnz; k++)
-		{	hessian[ rind[k] * int_n + cind[k] ] = values[k];
-			hessian[ cind[k] * int_n + rind[k] ] = values[k];
+		size_t K = row.size();
+		for(int ell = 0; ell < nnz; ell++)
+		{	i = size_t(rind[ell]);
+			j = size_t(cind[ell]);
+			for(k = 0; k < K; k++)
+			{	if( (row[k]==i && col[k]==j) || (row[k]==j && col[k]==i) )
+					hessian[k] = values[ell];
+			}
 		}
-
 		// free raw memory allocated by sparse_hessian
 		free(rind);
 		free(cind);
 		free(values);
 	}
 	// --------------------------------------------------------------------
-	// return argument 
+	// return argument
 	for(j = 0; j < n; j++)
 		x_return[j] = x[j];
 
+	// do not know how to return number of sweeps used
+	n_sweep = 0;
+
 	// tear down
 	thread_alloc::delete_array(a_x);
 	thread_alloc::delete_array(a_y);
