@@ -1,16 +1,16 @@
-/* $Id: sparse_jacobian.cpp 3320 2014-09-11 23:06:21Z bradbell $ */
+// $Id: sparse_jacobian.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 # include <cstring>
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 
 /*
 $begin adolc_sparse_jacobian.cpp$$
@@ -35,13 +35,8 @@ $spell
 $$
 
 $section adolc Speed: Sparse Jacobian$$
+$mindex link_sparse_jacobian speed$$
 
-$index link_sparse_jacobian, adolc$$
-$index adolc, link_sparse_jacobian$$
-$index speed, adolc$$
-$index adolc, speed$$
-$index sparse, speed adolc$$
-$index jacobian, speed adolc$$
 
 $head Specifications$$
 See $cref link_sparse_jacobian$$.
@@ -51,7 +46,7 @@ $head Implementation$$
 $codep */
 # include <adolc/adolc.h>
 # include <adolc/adolc_sparse.h>
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 # include <cppad/speed/uniform_01.hpp>
 # include <cppad/speed/sparse_jac_fun.hpp>
 
@@ -60,8 +55,8 @@ extern bool global_memory, global_onetape, global_atomic, global_optimize;
 extern bool global_colpack, global_boolsparsity;
 
 bool link_sparse_jacobian(
-	size_t                           size     , 
-	size_t                           repeat   , 
+	size_t                           size     ,
+	size_t                           repeat   ,
 	size_t                           m        ,
 	const CppAD::vector<size_t>&     row      ,
 	const CppAD::vector<size_t>&     col      ,
@@ -70,9 +65,9 @@ bool link_sparse_jacobian(
 	      size_t&                    n_sweep  )
 {
 	if( global_atomic || (! global_colpack) )
-		return false; 
+		return false;
 	if( global_memory || global_optimize )
-		return false; 
+		return false;
 	// -----------------------------------------------------
 	// setup
 	typedef unsigned int*    SizeVector;
@@ -80,8 +75,8 @@ bool link_sparse_jacobian(
 	typedef adouble          ADScalar;
 	typedef ADScalar*        ADVector;
 
-	size_t i, j;                // temporary indices
-	size_t n = size;            // number of independent variables
+	size_t i, j, k;            // temporary indices
+	size_t n = size;           // number of independent variables
 	size_t order = 0;          // derivative order corresponding to function
 
 	// set up for thread_alloc memory allocator (fast and checks for leaks)
@@ -99,7 +94,7 @@ bool link_sparse_jacobian(
 	// function value in double
 	DblVector y = thread_alloc::create_array<double>(m, capacity);
 
-	
+
 	// options that control sparse_jac
 	int        options[4];
 	extern bool global_boolsparsity;
@@ -117,22 +112,16 @@ bool link_sparse_jacobian(
 	SizeVector cind   = CPPAD_NULL;   // column indices
 	DblVector  values = CPPAD_NULL;   // Jacobian values
 
-	// initialize all entries as zero
-	for(i = 0; i < m; i++)
-	{	for(j = 0; j < n; j++)
-			jacobian[ i * n + j ] = 0.;
-	}
-
 	// choose a value for x
 	CppAD::uniform_01(n, x);
 
 	// declare independent variables
-	int keep = 0; // keep forward mode results 
+	int keep = 0; // keep forward mode results
 	trace_on(tag, keep);
 	for(j = 0; j < n; j++)
 		a_x[j] <<= x[j];
 
-	// AD computation of f (x) 
+	// AD computation of f (x)
 	CppAD::sparse_jac_fun<ADScalar>(m, n, a_x, row, col, order, a_y);
 
 	// create function object f : x -> y
@@ -143,7 +132,7 @@ bool link_sparse_jacobian(
 	// Retrieve n_sweep using undocumented feature of sparsedrivers.cpp
 	int same_pattern = 0;
 	options[2]       = -1;
-	n_sweep = sparse_jac(tag, int(m), int(n), 
+	n_sweep = sparse_jac(tag, int(m), int(n),
 		same_pattern, x, &nnz, &rind, &cind, &values, options
 	);
 	options[2]       = 0;
@@ -157,10 +146,10 @@ bool link_sparse_jacobian(
 		for(j = 0; j < n; j++)
 			a_x[j] <<= x[j];
 
-		// AD computation of f (x) 
+		// AD computation of f (x)
 		CppAD::sparse_jac_fun<ADScalar>(m, n, a_x, row, col, order, a_y);
 
-		// create function object f : x -> y 
+		// create function object f : x -> y
 		for(i = 0; i < m; i++)
 			a_y[i] >>= y[i];
 		trace_off();
@@ -172,12 +161,21 @@ bool link_sparse_jacobian(
 		rind   = CPPAD_NULL;
 		cind   = CPPAD_NULL;
 		values = CPPAD_NULL;
-		sparse_jac(tag, int(m), int(n), 
+		sparse_jac(tag, int(m), int(n),
 			same_pattern, x, &nnz, &rind, &cind, &values, options
 		);
-		int int_n = int(n);
-		for(int k = 0; k < nnz; k++)
-			jacobian[ rind[k] * int_n + cind[k] ] = values[k];
+		// only needed last time through loop
+		if( repeat == 0 )
+		{	size_t K = row.size();
+			for(int ell = 0; ell < nnz; ell++)
+			{	i = size_t(rind[ell]);
+				j = size_t(cind[ell]);
+				for(k = 0; k < K; k++)
+				{	if( row[k]==i && col[k]==j )
+						jacobian[k] = values[ell];
+				}
+			}
+		}
 
 		// free raw memory allocated by sparse_jac
 		free(rind);
@@ -190,14 +188,20 @@ bool link_sparse_jacobian(
 			CppAD::uniform_01(n, x);
 
 			// calculate the jacobian at this x
-			sparse_jac(tag, int(m), int(n), 
+			sparse_jac(tag, int(m), int(n),
 				same_pattern, x, &nnz, &rind, &cind, &values, options
 			);
 			same_pattern = 1;
 		}
-		int int_n = int(n);
-		for(int k = 0; k < nnz; k++)
-			jacobian[ rind[k] * int_n + cind[k] ] = values[k];
+		size_t K = row.size();
+		for(int ell = 0; ell < nnz; ell++)
+		{	i = size_t(rind[ell]);
+			j = size_t(cind[ell]);
+			for(k = 0; k < K; k++)
+			{	if( row[k]==i && col[k]==j )
+					jacobian[k] = values[ell];
+			}
+		}
 
 		// free raw memory allocated by sparse_jac
 		free(rind);
@@ -205,7 +209,7 @@ bool link_sparse_jacobian(
 		free(values);
 	}
 	// --------------------------------------------------------------------
-	// return argument 
+	// return argument
 	for(j = 0; j < n; j++)
 		x_return[j] = x[j];
 
