@@ -1,9 +1,9 @@
-/* $Id: det_lu.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: det_lu.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -30,21 +30,15 @@ $spell
 $$
 
 $section CppAD Speed: Gradient of Determinant Using Lu Factorization$$
+$mindex link_det_lu speed matrix factor$$
 
-$index link_det_lu, cppad$$
-$index cppad, link_det_lu$$
-$index speed, cppad$$
-$index cppad, speed$$
-$index lu, speed cppad$$
-$index matrix, factor speed cppad$$
-$index factor, matrix speed cppad$$
 
 $head Specifications$$
 See $cref link_det_lu$$.
 
 $head Implementation$$
 $codep */
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 # include <cppad/speed/det_by_lu.hpp>
 # include <cppad/speed/uniform_01.hpp>
 
@@ -53,8 +47,8 @@ extern bool
 	global_onetape, global_atomic, global_optimize;
 
 bool link_det_lu(
-	size_t                           size     , 
-	size_t                           repeat   , 
+	size_t                           size     ,
+	size_t                           repeat   ,
 	CppAD::vector<double>           &matrix   ,
 	CppAD::vector<double>           &gradient )
 {
@@ -64,8 +58,8 @@ bool link_det_lu(
 
 	// -----------------------------------------------------
 	// setup
-	typedef CppAD::AD<double>           ADScalar; 
-	typedef CppAD::vector<ADScalar>     ADVector; 
+	typedef CppAD::AD<double>           ADScalar;
+	typedef CppAD::vector<ADScalar>     ADVector;
 	CppAD::det_by_lu<ADScalar>          Det(size);
 
 	size_t i;               // temporary index
@@ -74,8 +68,8 @@ bool link_det_lu(
 	ADVector   A(n);        // AD domain space vector
 	ADVector   detA(m);     // AD range space vector
 	CppAD::ADFun<double> f; // AD function object
-	
-	// vectors of reverse mode weights 
+
+	// vectors of reverse mode weights
 	CppAD::vector<double> w(1);
 	w[0] = 1.;
 
@@ -97,6 +91,9 @@ bool link_det_lu(
 		if( global_optimize )
 			f.optimize();
 
+		// skip comparison operators
+		f.compare_change_count(0);
+
 		// evaluate and return gradient using reverse mode
 		f.Forward(0, matrix);
 		gradient = f.Reverse(1, w);
