@@ -1,9 +1,9 @@
-/* $Id: det_minor.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: det_minor.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -31,20 +31,15 @@ $spell
 $$
 
 $section CppAD Speed: Gradient of Determinant by Minor Expansion$$
+$mindex link_det_minor speed$$
 
-$index link_det_minor, cppad$$
-$index cppad, link_det_minor$$
-$index speed, cppad$$
-$index cppad, speed$$
-$index minor, speed cppad$$
-$index determinant, speed cppad$$
 
 $head Specifications$$
 See $cref link_det_minor$$.
 
 $head Implementation$$
 $codep */
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 # include <cppad/speed/det_by_minor.hpp>
 # include <cppad/speed/uniform_01.hpp>
 
@@ -53,8 +48,8 @@ extern bool
 	global_onetape, global_atomic, global_optimize;
 
 bool link_det_minor(
-	size_t                     size     , 
-	size_t                     repeat   , 
+	size_t                     size     ,
+	size_t                     repeat   ,
 	CppAD::vector<double>     &matrix   ,
 	CppAD::vector<double>     &gradient )
 {
@@ -66,8 +61,8 @@ bool link_det_minor(
 	// setup
 
 	// object for computing determinant
-	typedef CppAD::AD<double>       ADScalar; 
-	typedef CppAD::vector<ADScalar> ADVector; 
+	typedef CppAD::AD<double>       ADScalar;
+	typedef CppAD::vector<ADScalar> ADVector;
 	CppAD::det_by_minor<ADScalar>   Det(size);
 
 	size_t i;               // temporary index
@@ -75,8 +70,8 @@ bool link_det_minor(
 	size_t n = size * size; // number of independent variables
 	ADVector   A(n);        // AD domain space vector
 	ADVector   detA(m);     // AD range space vector
-	
-	// vectors of reverse mode weights 
+
+	// vectors of reverse mode weights
 	CppAD::vector<double> w(1);
 	w[0] = 1.;
 
@@ -90,22 +85,25 @@ bool link_det_minor(
 		CppAD::uniform_01(n, matrix);
 		for( i = 0; i < size * size; i++)
 			A[i] = matrix[i];
-	
+
 		// declare independent variables
 		Independent(A);
-	
+
 		// AD computation of the determinant
 		detA[0] = Det(A);
-	
+
 		// create function object f : A -> detA
 		f.Dependent(A, detA);
 
 		if( global_optimize )
 			f.optimize();
-	
+
+		// skip comparison operators
+		f.compare_change_count(0);
+
 		// evaluate the determinant at the new matrix value
 		f.Forward(0, matrix);
-	
+
 		// evaluate and return gradient using reverse mode
 		gradient = f.Reverse(1, w);
 	}
@@ -115,27 +113,30 @@ bool link_det_minor(
 		CppAD::uniform_01(n, matrix);
 		for( i = 0; i < size * size; i++)
 			A[i] = matrix[i];
-	
+
 		// declare independent variables
 		Independent(A);
-	
+
 		// AD computation of the determinant
 		detA[0] = Det(A);
-	
+
 		// create function object f : A -> detA
 		f.Dependent(A, detA);
 
 		if( global_optimize )
 			f.optimize();
-	
+
+		// skip comparison operators
+		f.compare_change_count(0);
+
 		// ------------------------------------------------------
 		while(repeat--)
 		{	// get the next matrix
 			CppAD::uniform_01(n, matrix);
-	
+
 			// evaluate the determinant at the new matrix value
 			f.Forward(0, matrix);
-	
+
 			// evaluate and return gradient using reverse mode
 			gradient = f.Reverse(1, w);
 		}
