@@ -1,9 +1,9 @@
-/* $Id: det_minor.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: det_minor.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -22,13 +22,8 @@ $spell
 $$
 
 $section Double Speed: Determinant by Minor Expansion$$
+$mindex link_det_minor speed$$
 
-$index link_det_minor, double$$
-$index double, link_det_minor$$
-$index speed, double$$
-$index double, speed$$
-$index minor, speed double$$
-$index determinant, speed double$$
 
 $head Specifications$$
 See $cref link_det_minor$$.
@@ -36,7 +31,7 @@ See $cref link_det_minor$$.
 $head Implementation$$
 
 $codep */
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 # include <cppad/speed/det_by_minor.hpp>
 # include <cppad/speed/uniform_01.hpp>
 
@@ -45,8 +40,8 @@ extern bool
 	global_onetape, global_atomic, global_optimize;
 
 bool link_det_minor(
-	size_t                     size     , 
-	size_t                     repeat   , 
+	size_t                     size     ,
+	size_t                     repeat   ,
 	CppAD::vector<double>     &matrix   ,
 	CppAD::vector<double>     &det      )
 {
@@ -56,7 +51,7 @@ bool link_det_minor(
 	// setup
 	CppAD::det_by_minor<double>   Det(size);
 	size_t n = size * size; // number of independent variables
-	
+
 	// ------------------------------------------------------
 	while(repeat--)
 	{	// get the next matrix
