@@ -1,9 +1,9 @@
-/* $Id: poly.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: poly.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -21,13 +21,9 @@ $spell
 $$
 
 $section Double Speed: Evaluate a Polynomial$$
+$mindex link_poly speed$$
 
 
-$index link_poly, double$$
-$index double, link_poly$$
-$index speed, double$$
-$index double, speed$$
-$index polynomial, speed double$$
 
 $head Specifications$$
 See $cref link_poly$$.
@@ -43,11 +39,11 @@ extern bool
 	global_onetape, global_atomic, global_optimize;
 
 bool link_poly(
-	size_t                     size     , 
-	size_t                     repeat   , 
+	size_t                     size     ,
+	size_t                     repeat   ,
 	CppAD::vector<double>     &a        ,  // coefficients of polynomial
 	CppAD::vector<double>     &z        ,  // polynomial argument value
-	CppAD::vector<double>     &p        )  // second derivative w.r.t z  
+	CppAD::vector<double>     &p        )  // second derivative w.r.t z
 {
 	if(global_onetape||global_atomic||global_optimize)
 		return false;
