@@ -1,9 +1,9 @@
-/* $Id: det_lu.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: det_lu.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -28,14 +28,8 @@ $spell
 $$
 
 $section Fadbad Speed: Gradient of Determinant Using Lu Factorization$$
+$mindex link_det_lu speed matrix factor$$
 
-$index link_det_lu, fadbad$$
-$index fadbad, link_det_lu$$
-$index speed, fadbad$$
-$index fadbad, speed$$
-$index lu, speed fadbad$$
-$index matrix, factor speed fadbad$$
-$index factor, matrix speed fadbad$$
 
 $head Specifications$$
 See $cref link_det_lu$$.
@@ -45,14 +39,14 @@ $codep */
 # include <FADBAD++/badiff.h>
 # include <cppad/speed/det_by_lu.hpp>
 # include <cppad/speed/uniform_01.hpp>
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 
 // list of possible options
 extern bool global_memory, global_onetape, global_atomic, global_optimize;
 
 bool link_det_lu(
-	size_t                     size     , 
-	size_t                     repeat   , 
+	size_t                     size     ,
+	size_t                     repeat   ,
 	CppAD::vector<double>     &matrix   ,
 	CppAD::vector<double>     &gradient )
 {
@@ -65,16 +59,16 @@ bool link_det_lu(
 	// setup
 	//
 	// object for computing determinant
-	typedef fadbad::B<double>       ADScalar; 
-	typedef CppAD::vector<ADScalar> ADVector; 
+	typedef fadbad::B<double>       ADScalar;
+	typedef CppAD::vector<ADScalar> ADVector;
 	CppAD::det_by_lu<ADScalar>      Det(size);
 
 	size_t i;                // temporary index
 	size_t m = 1;            // number of dependent variables
 	size_t n = size * size;  // number of independent variables
 	ADScalar   detA;         // AD value of the determinant
-	ADVector   A(n);         // AD version of matrix 
-	
+	ADVector   A(n);         // AD version of matrix
+
 	// ------------------------------------------------------
 	while(repeat--)
        {	// get the next matrix
