@@ -1,9 +1,9 @@
-/* $Id: det_lu.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: det_lu.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -30,14 +30,8 @@ $spell
 $$
 
 $section Sacado Speed: Gradient of Determinant Using Lu Factorization$$
+$mindex link_det_lu speed matrix factor$$
 
-$index link_det_lu, sacado$$
-$index sacado, link_det_lu$$
-$index speed, sacado$$
-$index sacado, speed$$
-$index lu, speed sacado$$
-$index matrix, factor speed sacado$$
-$index factor, matrix speed sacado$$
 
 $head Specifications$$
 See $cref link_det_lu$$.
@@ -47,14 +41,14 @@ $codep */
 # include <Sacado.hpp>
 # include <cppad/speed/det_by_lu.hpp>
 # include <cppad/speed/uniform_01.hpp>
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 
 // list of possible options
 extern bool global_memory, global_onetape, global_atomic, global_optimize;
 
 bool link_det_lu(
-	size_t                     size     , 
-	size_t                     repeat   , 
+	size_t                     size     ,
+	size_t                     repeat   ,
 	CppAD::vector<double>     &matrix   ,
 	CppAD::vector<double>     &gradient )
 {
@@ -67,15 +61,15 @@ bool link_det_lu(
 	// setup
 	//
 	// object for computing determinant
-	typedef Sacado::Rad::ADvar<double>   ADScalar; 
-	typedef CppAD::vector<ADScalar>      ADVector; 
+	typedef Sacado::Rad::ADvar<double>   ADScalar;
+	typedef CppAD::vector<ADScalar>      ADVector;
 	CppAD::det_by_lu<ADScalar>           Det(size);
 
 	size_t i;                // temporary index
 	size_t n = size * size;  // number of independent variables
 	ADScalar   detA;         // AD value of the determinant
-	ADVector   A(n);         // AD version of matrix 
-	
+	ADVector   A(n);         // AD version of matrix
+
 	// ------------------------------------------------------
 	while(repeat--)
 	{	// get the next matrix
