@@ -1,9 +1,9 @@
-/* $Id: det_minor.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: det_minor.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -27,13 +27,8 @@ $spell
 $$
 
 $section Sacado Speed: Gradient of Determinant by Minor Expansion$$
+$mindex link_det_minor speed$$
 
-$index link_det_minor, sacado$$
-$index sacado, link_det_minor$$
-$index speed, sacado$$
-$index sacado, speed$$
-$index minor, speed sacado$$
-$index determinant, speed sacado$$
 
 $head Specifications$$
 See $cref link_det_minor$$.
@@ -44,35 +39,35 @@ $codep */
 # include <Sacado.hpp>
 # include <cppad/speed/det_by_minor.hpp>
 # include <cppad/speed/uniform_01.hpp>
-# include <cppad/vector.hpp>
+# include <cppad/utility/vector.hpp>
 
 // list of possible options
 extern bool global_memory, global_onetape, global_atomic, global_optimize;
 
 bool link_det_minor(
-	size_t                     size     , 
-	size_t                     repeat   , 
+	size_t                     size     ,
+	size_t                     repeat   ,
 	CppAD::vector<double>     &matrix   ,
 	CppAD::vector<double>     &gradient )
 {
 	// speed test global option values
 	if( global_atomic )
-		return false; 
+		return false;
 	if( global_memory || global_onetape || global_optimize )
-		return false; 
+		return false;
 	// -----------------------------------------------------
 	// setup
 
 	// object for computing determinant
-	typedef Sacado::Rad::ADvar<double>    ADScalar; 
-	typedef CppAD::vector<ADScalar>       ADVector; 
+	typedef Sacado::Rad::ADvar<double>    ADScalar;
+	typedef CppAD::vector<ADScalar>       ADVector;
 	CppAD::det_by_minor<ADScalar>         Det(size);
 
 	size_t i;                // temporary index
 	size_t n = size * size;  // number of independent variables
 	ADScalar   detA;         // AD value of the determinant
-	ADVector   A(n);         // AD version of matrix 
-	
+	ADVector   A(n);         // AD version of matrix
+
 	// ------------------------------------------------------
 	while(repeat--)
 	{	// get the next matrix
@@ -88,7 +83,7 @@ bool link_det_minor(
 		// reverse mode compute gradient of last computed value; i.e., detA
 		ADScalar::Gradcomp();
 
-		// return gradient 
+		// return gradient
 		for(i =0; i < n; i++)
 			gradient[i] = A[i].adj(); // partial detA w.r.t A[i]
 	}
