@@ -1,9 +1,9 @@
-/* $Id: poly.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: poly.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -36,12 +36,8 @@ $spell
 $$
 
 $section Sacado Speed: Second Derivative of a Polynomial$$
+$mindex link_poly speed$$
 
-$index link_poly, sacado$$
-$index sacado, link_poly$$
-$index speed, sacado$$
-$index sacado, speed$$
-$index polynomial, speed sacado$$
 
 $head Specifications$$
 See $cref link_poly$$.
@@ -50,8 +46,8 @@ $head Implementation$$
 
 
 $codep */
-# include <cppad/vector.hpp>
-# include <cppad/poly.hpp>
+# include <cppad/utility/vector.hpp>
+# include <cppad/utility/poly.hpp>
 # include <cppad/speed/uniform_01.hpp>
 # include <Sacado.hpp>
 
@@ -59,11 +55,11 @@ $codep */
 extern bool global_memory, global_onetape, global_atomic, global_optimize;
 
 bool link_poly(
-	size_t                     size     , 
-	size_t                     repeat   , 
+	size_t                     size     ,
+	size_t                     repeat   ,
 	CppAD::vector<double>     &a        ,  // coefficients of polynomial
 	CppAD::vector<double>     &z        ,  // polynomial argument value
-	CppAD::vector<double>     &ddp      )  // second derivative w.r.t z  
+	CppAD::vector<double>     &ddp      )  // second derivative w.r.t z
 {
 	if( global_atomic )
 		return false;
@@ -74,9 +70,9 @@ bool link_poly(
 	typedef Sacado::Tay::Taylor<double>  ADScalar;
 	CppAD::vector<ADScalar>              A(size);
 
-	size_t i;               // temporary index     
+	size_t i;               // temporary index
 	ADScalar   Z;           // domain space AD value
-	ADScalar   P;           // range space AD value 
+	ADScalar   P;           // range space AD value
 	unsigned int order = 2; // order of Taylor coefficients
 	Z.resize(order+1, false);
 	P.resize(order+1, false);
