@@ -1,9 +1,9 @@
-/* $Id: link_sparse_hessian.cpp 3223 2014-03-19 15:13:26Z bradbell $ */
+// $Id: link_sparse_hessian.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -16,14 +16,13 @@ $spell
 	const
 	bool
 	CppAD
+	cppad
+	colpack
 $$
 
-$index link_sparse_hessian$$
-$index sparse, speed test$$
-$index speed, test sparse$$
-$index test, sparse speed$$
 
 $section Speed Testing Sparse Hessian$$
+$mindex link_sparse_hessian test$$
 
 $head Prototype$$
 $codei%extern bool link_sparse_hessian(
@@ -31,18 +30,19 @@ $codei%extern bool link_sparse_hessian(
 	size_t                        %repeat%    ,
 	CppAD::vector<double>&        %x%         ,
 	const CppAD::vector<size_t>&  %row%       ,
-	const CppAD::vector<size_t>&  %col%       , 
-	CppAD::vector<double>&        %hessian%
+	const CppAD::vector<size_t>&  %col%       ,
+	CppAD::vector<double>&        %hessian%   ,
+	size_t                        %n_sweep%
 );
 %$$
 
 $head Method$$
 Given a row index vector $latex row$$
 and a second column vector $latex col$$,
-the corresponding function 
-$latex f : \B{R}^n \rightarrow \B{R} $$ 
+the corresponding function
+$latex f : \B{R}^n \rightarrow \B{R} $$
 is defined by $cref sparse_hes_fun$$.
-The non-zero entries in the Hessian of this function have 
+The non-zero entries in the Hessian of this function have
 one of the following forms:
 $latex \[
 	\DD{f}{x[row[k]]}{x[row[k]]}
@@ -93,53 +93,52 @@ $codei%
 	const CppAD::vector<size_t> %col%
 %$$
 Its size must be the same as $icode row$$; i.e., $latex K$$.
-It contains the column indices for the corresponding function 
+It contains the column indices for the corresponding function
 $latex f(x)$$.
 All the elements of $icode col$$ are between zero and $latex n-1$$.
-$pre
-
-$$
-There are no duplicate row and column entires; i.e., if $icode%j% != %k%$$,
+There are no duplicated entries requested, to be specific,
+if $icode%k1% != %k2%$$ then
 $codei%
-	%row%[%j%] != %row%[%k%] || %col%[%j%] != %col%[%k%]
+	( %row%[%k1%] , %col%[%k1%] ) != ( %row%[%k2%] , %col%[%k2%] )
 %$$
-Only the lower triangle of the Hessian is included in the indices; i.e.,
-$codei%row%[%k%] >= %col%[%k%]%$$.
-Furthermore, for all the non-zero entries in the lower triangle
-are included; i.e., if $latex i \geq j$$ and
-$latex \DD{f}{x[i]}{x[j]} \neq 0$$,
-there is an index $icode k$$ such that
-$icode%i% = %row%[%k%]%$$ and
-$icode%j% = %col%[%k%]%$$.
 
 $head hessian$$
 The argument $icode hessian$$ has prototype
 $codei%
 	CppAD::vector<double>&  hessian
 %$$
-and its size is $latex n \times n$$.
-The input value of its elements does not matter. 
+and its size is $icode K$$.
+The input value of its elements does not matter.
 The output value of its elements is the Hessian of the function $latex f(x)$$.
 To be more specific, for
-$latex i = 0 , \ldots , n-1$$,
-$latex j = 0 , \ldots , n-1$$,
+$latex k = 0 , \ldots , K-1$$,
 $latex \[
-	\DD{f}{x[i]}{x[j]} (x) = hessian [ i * n + j ]
+	\DD{f}{ x[ \R{row}[k] ] }{ x[ \R{col}[k] ]} = \R{hessian} [k]
 \] $$
 
+$head n_sweep$$
+The input value of $icode n_sweep$$ does not matter. On output,
+it is the value $cref/n_sweep/sparse_hessian/n_sweep/$$ corresponding
+to the evaluation of $icode hessian$$.
+This is also the number of colors corresponding to the
+$cref/coloring method/sparse_hessian/work/color_method/$$,
+which can be set to $cref/colpack/speed_main/Sparsity Options/colpack/$$,
+and is otherwise $code cppad$$.
+
+
 $subhead double$$
 In the case where $icode package$$ is $code double$$,
-only the first element of $icode hessian$$ is used and it is actually 
+only the first element of $icode hessian$$ is used and it is actually
 the value of $latex f(x)$$ (derivatives are not computed).
 
-$end 
+$end
 -----------------------------------------------------------------------------
 */
-# include <cppad/vector.hpp>
-# include <cppad/near_equal.hpp>
+# include <cppad/utility/vector.hpp>
+# include <cppad/utility/near_equal.hpp>
 # include <cppad/speed/sparse_hes_fun.hpp>
 # include <cppad/speed/uniform_01.hpp>
-# include <cppad/index_sort.hpp>
+# include <cppad/utility/index_sort.hpp>
 
 /*!
 \{
@@ -150,7 +149,7 @@ namespace {
 	using CppAD::vector;
 
 	/*!
- 	Class used by choose_row_col to determin order of row and column indices
+	Class used by choose_row_col to determin order of row and column indices
 	*/
 	class Key {
 	public:
@@ -162,19 +161,19 @@ namespace {
 		Key(void)
 		{ }
 		/*!
- 		Construct from a value for row and col
+		Construct from a value for row and col
 
 		\param row
 		row value for this key
 
 		\param col
 		column value for this key
- 		*/
+		*/
 		Key(size_t row, size_t col)
 		: row_(row), col_(col)
 		{ }
 		/*!
- 		Compare this key with another key using < operator
+		Compare this key with another key using < operator
 
 		\param other
 		the other key.
@@ -202,51 +201,31 @@ namespace {
 	*/
 	void choose_row_col(
 		size_t          n   ,
-		vector<size_t>& row , 
+		vector<size_t>& row ,
 		vector<size_t>& col )
-	{	size_t r, c, k, K = 5 * n;
+	{	size_t i, j, k, ell;
+		size_t max_per_row = 5;
 
-		// get the random indices
-		vector<double>  random(2 * K);
-		CppAD::uniform_01(2 * K, random);
-
-		// sort the temporary row and colunn choices
-		vector<Key>   keys(K + n);
-		vector<size_t> ind(K + n);
-		for(k = 0; k < K; k++)
-		{	r = size_t( n * random[k] );
-			r = std::min(n-1, r);
-			//
-			c = size_t( n * random[k + K] );
-			c = std::min(n-1, c);
-			//
-			// force to lower triangle
-			if( c > r )
-				std::swap(r, c);
-			//
-			keys[k] = Key(r, c);
-		}
-		// include the diagonal
-		for(k = 0; k < n; k++)
-			keys[k + K] = Key(k, k);  
-		CppAD::index_sort(keys, ind);
-
-		// remove duplicates while setting the return value for row and col
+		// generate the row and column indices
 		row.resize(0);
 		col.resize(0);
-		size_t r_previous = keys[ ind[0] ].row_;
-		size_t c_previous = keys[ ind[0] ].col_;
-		row.push_back(r_previous);
-		col.push_back(c_previous);
-		for(k = 1; k < K; k++)
-		{	r = keys[ ind[k] ].row_;
-			c = keys[ ind[k] ].row_;
-			if( r != r_previous || c != c_previous)
-			{	row.push_back(r);
-				col.push_back(c);
+		for(i = 0; i < n; i++)
+		{	// generate max_per_row random column indices between 0 and i
+			vector<double> random(max_per_row);
+			CppAD::uniform_01(max_per_row, random);
+
+			// set the indices for this row
+			size_t k_start = col.size();
+			for(ell = 0; ell < max_per_row; ell++)
+			{	j = std::min(i, size_t(random[ell] * i) );
+				bool ok = true;
+				for(k = k_start; k < col.size(); k++)
+					ok &= j != col[k];
+				if( ok )
+				{	row.push_back(i);
+					col.push_back(j);
+				}
 			}
-			r_previous = r;
-			c_previous = c;
 		}
 	}
 }
@@ -268,13 +247,19 @@ the argument at which the Hessian was evaluated during the last repetition.
 is the row indices correpsonding to non-zero Hessian entries.
 
 \param col [in]
-is the column indices corresponding to non-zero Hessian entries.
+is the column indices corresponding to non-zero Hessian entries;
+col.size() == row.size().
 
 \param hessian [out]
-is a vector with size <code>n * n</code> 
-containing the value of the Hessian of f(x) 
+is a vector, with hessian.size() == row.size(),
+containing the value of the Hessian of f(x)
 corresponding to the last repetition.
 
+\param n_sweep [out]
+The input value of this parameter does not matter.
+Upon return, it is the number of sweeps (colors) corresponding
+to the sparse hessian claculation.
+
 \return
 is true, if the sparse Hessian speed test is implemented for this package,
 and false otherwise.
@@ -283,9 +268,10 @@ extern bool link_sparse_hessian(
 	size_t                           size      ,
 	size_t                           repeat    ,
 	const CppAD::vector<size_t>&     row       ,
-	const CppAD::vector<size_t>&     col       , 
-	      CppAD::vector<double>&     x         ,
-	      CppAD::vector<double>&     hessian
+	const CppAD::vector<size_t>&     col       ,
+	CppAD::vector<double>&           x         ,
+	CppAD::vector<double>&           hessian   ,
+	size_t&                          n_sweep
 );
 
 /*!
@@ -295,16 +281,17 @@ Is sparse Hessian test avaialable.
 true, if spare Hessian available for this package, and false otherwise.
 */
 bool available_sparse_hessian(void)
-{	
+{
 	size_t n      = 2;
 	size_t repeat = 1;
 	vector<double> x(n);
-	vector<double> hessian(n * n);
-	vector<size_t> row, col; 
+	vector<size_t> row, col;
 	choose_row_col(n, row, col);
+	size_t K = row.size();
+	vector<double> hessian(K);
 
-	return link_sparse_hessian(n, repeat, row, col, x, hessian);
-	exit(0);
+	size_t n_sweep;
+	return link_sparse_hessian(n, repeat, row, col, x, hessian, n_sweep);
 }
 /*!
 Does final sparse Hessian value pass correctness test.
@@ -316,15 +303,19 @@ if true, we are checking function values instead of derivatives.
 true, if correctness test passes, and false otherwise.
 */
 bool correct_sparse_hessian(bool is_package_double)
-{	
+{
 	size_t n      = 10;
 	size_t repeat = 1;
 	vector<double> x(n);
-	vector<double> hessian(n * n);
 	vector<size_t> row, col;
 	choose_row_col(n, row, col);
+	size_t K = row.size();
+	vector<double> hessian(K);
 
-	link_sparse_hessian(n, repeat, row, col, x, hessian);
+	// The double package assumes hessian.size() >= 1
+	CPPAD_ASSERT_UNKNOWN( K >= 1 );
+	size_t n_sweep;
+	link_sparse_hessian(n, repeat, row, col, x, hessian, n_sweep);
 
 	size_t order, size;
 	if( is_package_double)
@@ -333,13 +324,13 @@ bool correct_sparse_hessian(bool is_package_double)
 	}
 	else
 	{	order = 2;     // check hessian value
-		size  = n * n;
+		size  = K;
 	}
 	CppAD::vector<double> check(size);
 	CppAD::sparse_hes_fun<double>(n, x, row, col, order, check);
 	bool ok = true;
 	size_t k;
-	for( k = 0; k < size; k++)
+	for(k = 0; k < size; k++)
 		ok &= CppAD::NearEqual(check[k], hessian[k], 1e-10, 1e-10);
 
 	return ok;
@@ -355,14 +346,47 @@ is the dimension of the argument space for this speed test.
 is the number of times to repeate the speed test.
 */
 void speed_sparse_hessian(size_t size, size_t repeat)
-{	size_t n = size;	
+{	CPPAD_ASSERT_UNKNOWN( size > 0 );
+	static size_t previous_size = 0;
+	static vector<size_t> row, col;
+
+	size_t n = size;
 	vector<double> x(n);
-	vector<double> hessian(n * n);
-	vector<size_t> row, col;
-	choose_row_col(n, row, col);
+	if( size != previous_size )
+	{	choose_row_col(n, row, col);
+		previous_size = size;
+	}
+	size_t K = row.size();
+	vector<double> hessian(K);
 
 	// note that cppad/sparse_hessian.cpp assumes that x.size() == size
-	link_sparse_hessian(n, repeat, row, col, x, hessian);
+	size_t n_sweep;
+	link_sparse_hessian(n, repeat, row, col, x, hessian, n_sweep);
 	return;
 }
 
+/*!
+Sparse Hessian speed test information.
+
+\param size [in]
+is the \c size parameter in the corresponding call to speed_sparse_hessian.
+
+\param n_sweep [out]
+The input value of this parameter does not matter.
+Upon return, it is the value \c n_sweep retruned by the corresponding
+call to \c link_sparse_hessian.
+*/
+void info_sparse_hessian(size_t size, size_t& n_sweep)
+{	size_t n      = size;
+	size_t repeat = 1;
+	vector<size_t> row, col;
+	choose_row_col(n, row, col);
+
+	// note that cppad/speed/sparse_hessian.cpp assumes that x.size()
+	// is the size corresponding to this test
+	vector<double> x(n);
+	size_t K = row.size();
+	vector<double> hessian(K);
+	link_sparse_hessian(n, repeat, row, col, x, hessian, n_sweep);
+	return;
+}
