@@ -1,9 +1,9 @@
-/* $Id: link_sparse_jacobian.cpp 3311 2014-05-28 16:21:08Z bradbell $ */
+// $Id: link_sparse_jacobian.cpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-14 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
@@ -21,12 +21,9 @@ $spell
 	Jacobian
 $$
 
-$index link_sparse_jacobian$$
-$index sparse, speed test$$
-$index speed, test sparse$$
-$index test, sparse speed$$
 
 $section Speed Testing Sparse Jacobian$$
+$mindex link_sparse_jacobian test$$
 
 $head Prototype$$
 $codei%extern bool link_sparse_jacobian(
@@ -34,7 +31,7 @@ $codei%extern bool link_sparse_jacobian(
 	size_t                       %repeat%    ,
 	size_t                       %m%         ,
 	const CppAD::vector<size_t>& %row%       ,
-	const CppAD::vector<size_t>& %col%       , 
+	const CppAD::vector<size_t>& %col%       ,
 	      CppAD::vector<double>& %x%         ,
 	      CppAD::vector<double>& %jacobian%  ,
 	      size_t&                %n_sweep%
@@ -44,7 +41,7 @@ $codei%extern bool link_sparse_jacobian(
 $head Method$$
 Given a range space dimension $icode m$$
 the row index vector $latex row$$, and column index vector $latex col$$,
-a corresponding function $latex f : \B{R}^n \rightarrow \B{R}^m $$ 
+a corresponding function $latex f : \B{R}^n \rightarrow \B{R}^m $$
 is defined by $cref sparse_jac_fun$$.
 The non-zero entries in the Jacobian of this function have the form
 $latex \[
@@ -59,11 +56,10 @@ The argument $icode size$$, referred to as $latex n$$ below,
 is the dimension of the domain space for $latex f(x)$$.
 
 $head repeat$$
-The argument $icode repeat$$ is the number of different functions
-$latex f(x)$$ for which the Jacobian is computed for.
-Each function corresponds to a randomly chosen index vectors, i.e.,
-for each repetition a random choice is made for
-$latex row[k]$$ and $latex col[k]$$ for $latex k = 0 , \ldots , K-1$$.
+The argument $icode repeat$$ is the number of times
+to repeat the test
+(with a different value for $icode x$$ corresponding to
+each repetition).
 
 $head m$$
 Is the dimension of the range space for the function $latex f(x)$$.
@@ -78,9 +74,6 @@ The input value of its elements does not matter.
 On output, it has been set the column index vector
 for the last repetition.
 All the elements of $icode col$$ are between zero and $latex n-1$$.
-$pre
-
-$$
 There are no duplicate row and column entires; i.e., if $icode%j% != %k%$$,
 $codei%
 	%row%[%j%] != %row%[%k%] || %col%[%j%] != %col%[%k%]
@@ -93,47 +86,48 @@ $codei%
 %$$
 and its size is $latex n$$; i.e., $icode%x%.size() == %size%$$.
 The input value of the elements of $icode x$$ does not matter.
-On output, it has been set to the 
+On output, it has been set to the
 argument value for which the function,
 or its derivative, is being evaluated and placed in $icode jacobian$$.
 The value of this vector need not change with each repetition.
 
 $head jacobian$$
-The argument $icode jacobian$$ is a vector with 
-$latex m \times n$$ elements.
-The input value of its elements does not matter. 
-The output value of its elements is the Jacobian of the function $latex f(x)$$
-that corresponds to output values of $icode x$$.
+The argument $icode jacobian$$ has prototype
+$codei%
+        CppAD::vector<double>& %jacobian%
+%$$
+and its size is $icode K$$.
+The input value of its elements does not matter.
+The output value of its elements is the Jacobian of the function $latex f(x)$$.
 To be more specific, for
-$latex i = 0 , \ldots , m - 1$$,
-$latex j = 0 , \ldots , n-1$$,
+$latex k = 0 , \ldots , K - 1$$,
 $latex \[
-	\D{f[i]}{x[j]} (x) = jacobian [ i * n + j ]
+	\D{f[ \R{row}[k] ]}{x[ \R{col}[k] ]} (x) = \R{jacobian} [k]
 \] $$
 
 $head n_sweep$$
 The input value of $icode n_sweep$$ does not matter. On output,
 it is the value $cref/n_sweep/sparse_jacobian/n_sweep/$$ corresponding
 to the evaluation of $icode jacobian$$.
-This is also the number of colors corresponding to the 
-$cref/coloring method/sparse_jacobian/work/color_method/$$
-which can be set to $cref/colpack/speed_main/Sparsity Options/colpack/$$
+This is also the number of colors corresponding to the
+$cref/coloring method/sparse_jacobian/work/color_method/$$,
+which can be set to $cref/colpack/speed_main/Sparsity Options/colpack/$$,
 and is otherwise $code cppad$$.
 
 $subhead double$$
 In the case where $icode package$$ is $code double$$,
-only the first $latex m$$ 
+only the first $latex m$$
 elements of $icode jacobian$$ are used and they are set to
 the value of $latex f(x)$$.
 
-$end 
+$end
 -----------------------------------------------------------------------------
 */
-# include <cppad/vector.hpp>
-# include <cppad/near_equal.hpp>
+# include <cppad/utility/vector.hpp>
+# include <cppad/utility/near_equal.hpp>
 # include <cppad/speed/sparse_jac_fun.hpp>
 # include <cppad/speed/uniform_01.hpp>
-# include <cppad/index_sort.hpp>
+# include <cppad/utility/index_sort.hpp>
 
 /*!
 \{
@@ -144,7 +138,7 @@ namespace {
 	using CppAD::vector;
 
 	/*!
- 	Class used by choose_row_col to determine order of row and column indices
+	Class used by choose_row_col to determine order of row and column indices
 	*/
 	class Key {
 	public:
@@ -156,19 +150,19 @@ namespace {
 		Key(void)
 		{ }
 		/*!
- 		Construct from a value for row and col
+		Construct from a value for row and col
 
 		\param row
 		row value for this key
 
 		\param col
 		column value for this key
- 		*/
+		*/
 		Key(size_t row, size_t col)
 		: row_(row), col_(col)
 		{ }
 		/*!
- 		Compare this key with another key using < operator
+		Compare this key with another key using < operator
 
 		\param other
 		the other key.
@@ -200,7 +194,7 @@ namespace {
 	void choose_row_col(
 		size_t          n   ,
 		size_t          m   ,
-		vector<size_t>& row , 
+		vector<size_t>& row ,
 		vector<size_t>& col )
 	{	size_t r, c, k, K = 5 * std::max(m, n);
 
@@ -267,8 +261,8 @@ is a vector of size \c n containing
 the argument at which the Jacobian was evaluated during the last repetition.
 
 \param jacobian [out]
-is a vector with size <code>m * n</code> 
-containing the value of the Jacobian of f(x) 
+is a vector with size <code>row.size()</code>
+containing the value of the Jacobian of f(x)
 corresponding to the last repetition.
 
 \param n_sweep [out]
@@ -285,7 +279,7 @@ extern bool link_sparse_jacobian(
 	size_t                            repeat    ,
 	size_t                            m         ,
 	const CppAD::vector<size_t>&      row       ,
-	const CppAD::vector<size_t>&      col       , 
+	const CppAD::vector<size_t>&      col       ,
 	      CppAD::vector<double>&      x         ,
 	      CppAD::vector<double>&      jacobian  ,
 	      size_t&                     n_sweep
@@ -301,11 +295,12 @@ bool available_sparse_jacobian(void)
 {	size_t n      = 10;
 	size_t m      = 2 * n;
 	size_t repeat = 1;
-	vector<size_t> row, col; 
+	vector<size_t> row, col;
 	choose_row_col(n, m, row, col);
 
 	vector<double> x(n);
-	vector<double> jacobian(m * n);
+	size_t K = row.size();
+	vector<double> jacobian(K);
 	size_t         n_sweep;
 	return link_sparse_jacobian(n, repeat, m, row, col, x, jacobian, n_sweep);
 }
@@ -319,7 +314,7 @@ if true, we are checking function values instead of derivatives.
 true, if correctness test passes, and false otherwise.
 */
 bool correct_sparse_jacobian(bool is_package_double)
-{	size_t i, j;
+{	size_t i, k;
 	bool ok       = true;
 	double eps    = 10. * CppAD::numeric_limits<double>::epsilon();
 	size_t n      = 5;
@@ -328,35 +323,32 @@ bool correct_sparse_jacobian(bool is_package_double)
 	vector<size_t> row, col;
 	choose_row_col(n, m, row, col);
 
+	size_t K = row.size();
+	// The double package assumes jacobian.size() >= m
+	CPPAD_ASSERT_UNKNOWN( K >= m );
 	vector<double> x(n);
-	vector<double> jacobian(m * n);
+	vector<double> jacobian(K);
 	size_t         n_sweep;
 	link_sparse_jacobian(n, repeat, m, row, col, x, jacobian, n_sweep);
 
 	if( is_package_double)
-	{	// check f(x)
+	{
+		// check f(x)
 		size_t order = 0;
 		vector<double> check(m);
 		CppAD::sparse_jac_fun<double>(m, n, x, row, col, order, check);
 		for(i = 0; i < m; i++)
-		{	double u = check[i];
-			double v = jacobian[i];
-			ok &= CppAD::NearEqual(u, v, eps, eps);
-		}
+			ok &= CppAD::NearEqual(check[i], jacobian[i], eps, eps);
+
 		return ok;
 	}
-     // check f'(x) 
+    // check f'(x)
 	size_t order = 1;
-	size_t size  = m * n;
-	vector<double> check(size);
+	vector<double> check(K);
 	CppAD::sparse_jac_fun<double>(m, n, x, row, col, order, check);
-	for(i = 0; i < m; i++)
-	{	for(j = 0; j < n; j++)
-		{	double u = check[ i * n + j ];
-			double v = jacobian[ i * n + j ];
-			ok &= CppAD::NearEqual(u, v, eps, eps);
-		}
-	}
+	for(k = 0; k < K; k++)
+		ok &= CppAD::NearEqual(check[k], jacobian[k], eps, eps);
+
 	return ok;
 }
 /*!
@@ -369,15 +361,22 @@ is the dimension of the argument space for this speed test.
 is the number of times to repeate the speed test.
 */
 void speed_sparse_jacobian(size_t size, size_t repeat)
-{	size_t n   = size;	
+{	CPPAD_ASSERT_UNKNOWN( size > 0 );
+	static size_t previous_size = 0;
+	static vector<size_t> row, col;
+
+	size_t n   = size;
 	size_t m   = 2 * n;
-	vector<size_t> row, col;
-	choose_row_col(n, m, row, col);
+	if( size != previous_size)
+	{	choose_row_col(n, m, row, col);
+		previous_size = size;
+	}
 
 	// note that cppad/sparse_jacobian.cpp assumes that x.size()
 	// is the size corresponding to this test
 	vector<double> x(n);
-	vector<double> jacobian(m * n);
+	size_t K = row.size();
+	vector<double> jacobian(K);
 	size_t         n_sweep;
 	link_sparse_jacobian(n, repeat, m, row, col, x, jacobian, n_sweep);
 	return;
@@ -394,7 +393,7 @@ Upon return, it is the value \c n_sweep retruned by the corresponding
 call to \c link_sparse_jacobian.
 */
 void info_sparse_jacobian(size_t size, size_t& n_sweep)
-{	size_t n      = size;	
+{	size_t n      = size;
 	size_t m      = 2 * n;
 	size_t repeat = 1;
 	vector<size_t> row, col;
@@ -403,9 +402,8 @@ void info_sparse_jacobian(size_t size, size_t& n_sweep)
 	// note that cppad/sparse_jacobian.cpp assumes that x.size()
 	// is the size corresponding to this test
 	vector<double> x(n);
-	vector<double> jacobian(m * n);
+	size_t K = row.size();
+	vector<double> jacobian(K);
 	link_sparse_jacobian(n, repeat, m, row, col, x, jacobian, n_sweep);
 	return;
 }
-
-
