@@ -1,16 +1,19 @@
-/* $Id: extern_value.hpp 2756 2013-02-27 18:49:28Z bradbell $ */
+// $Id: extern_value.hpp 3757 2015-11-30 12:03:07Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
-the terms of the 
+the terms of the
                     GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
-template <class Type> 
+# ifndef CPPAD_EXTERN_VALUE_HPP
+# define CPPAD_EXTERN_VALUE_HPP
+
+template <class Type>
 class extern_value  {
 private:
 	Type value_;
@@ -19,3 +22,5 @@ public:
 	void set(Type value);
 	Type get(void);
 };
+
+# endif
